package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TPredictConf;
import com.slibra.business.service.ITPredictConfService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 机理模型预测配置Controller
 * 
 * @author slibra
 * @date 2025-02-11
 */
@RestController
@RequestMapping("/business/predictConf")
public class TPredictConfController extends BaseController
{
    @Autowired
    private ITPredictConfService tPredictConfService;

    /**
     * 查询机理模型预测配置列表
     */
    @PreAuthorize("@ss.hasPermi('business:conf:list')")
    @GetMapping("/list")
    public TableDataInfo list(TPredictConf tPredictConf)
    {
        startPage();
        List<TPredictConf> list = tPredictConfService.selectTPredictConfList(tPredictConf);
        return getDataTable(list);
    }

    /**
     * 导出机理模型预测配置列表
     */
    @PreAuthorize("@ss.hasPermi('business:conf:export')")
    @Log(title = "机理模型预测配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TPredictConf tPredictConf)
    {
        List<TPredictConf> list = tPredictConfService.selectTPredictConfList(tPredictConf);
        ExcelUtil<TPredictConf> util = new ExcelUtil<TPredictConf>(TPredictConf.class);
        util.exportExcel(response, list, "机理模型预测配置数据");
    }

    /**
     * 获取机理模型预测配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:conf:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tPredictConfService.selectTPredictConfById(id));
    }

    /**
     * 新增机理模型预测配置
     */
    @PreAuthorize("@ss.hasPermi('business:conf:add')")
    @Log(title = "机理模型预测配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TPredictConf tPredictConf)
    {
        tPredictConf.setCreateBy(getUsername());
        return toAjax(tPredictConfService.insertTPredictConf(tPredictConf));
    }

    /**
     * 修改机理模型预测配置
     */
    @PreAuthorize("@ss.hasPermi('business:conf:edit')")
    @Log(title = "机理模型预测配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TPredictConf tPredictConf)
    {
        tPredictConf.setUpdateBy(getUsername());
        return toAjax(tPredictConfService.updateTPredictConf(tPredictConf));
    }

    /**
     * 删除机理模型预测配置
     */
    @PreAuthorize("@ss.hasPermi('business:conf:remove')")
    @Log(title = "机理模型预测配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tPredictConfService.deleteTPredictConfByIds(ids));
    }
}
