package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiBigTableDay;
import com.slibra.business.service.ITXinyiBigTableDayService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义大天维度统计Controller
 * 
 * @author slibra
 * @date 2024-09-10
 */
@RestController
@RequestMapping("/business/day")
public class TXinyiBigTableDayController extends BaseController
{
    @Autowired
    private ITXinyiBigTableDayService tXinyiBigTableDayService;

    /**
     * 查询信义大天维度统计列表
     */
    @PreAuthorize("@ss.hasPermi('business:day:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiBigTableDay tXinyiBigTableDay)
    {
        startPage();
        List<TXinyiBigTableDay> list = tXinyiBigTableDayService.selectTXinyiBigTableDayList(tXinyiBigTableDay);
        return getDataTable(list);
    }

    /**
     * 导出信义大天维度统计列表
     */
    @PreAuthorize("@ss.hasPermi('business:day:export')")
    @Log(title = "信义大天维度统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiBigTableDay tXinyiBigTableDay)
    {
        List<TXinyiBigTableDay> list = tXinyiBigTableDayService.selectTXinyiBigTableDayList(tXinyiBigTableDay);
        ExcelUtil<TXinyiBigTableDay> util = new ExcelUtil<TXinyiBigTableDay>(TXinyiBigTableDay.class);
        util.exportExcel(response, list, "信义大天维度统计数据");
    }

    /**
     * 获取信义大天维度统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:day:query')")
    @GetMapping(value = "/{ID}")
    public AjaxResult getInfo(@PathVariable("ID") Long ID)
    {
        return success(tXinyiBigTableDayService.selectTXinyiBigTableDayByID(ID));
    }

    /**
     * 新增信义大天维度统计
     */
    @PreAuthorize("@ss.hasPermi('business:day:add')")
    @Log(title = "信义大天维度统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiBigTableDay tXinyiBigTableDay)
    {
        tXinyiBigTableDay.setCreateBy(getUsername());
        return toAjax(tXinyiBigTableDayService.insertTXinyiBigTableDay(tXinyiBigTableDay));
    }

    /**
     * 修改信义大天维度统计
     */
    @PreAuthorize("@ss.hasPermi('business:day:edit')")
    @Log(title = "信义大天维度统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiBigTableDay tXinyiBigTableDay)
    {
        tXinyiBigTableDay.setUpdateBy(getUsername());
        return toAjax(tXinyiBigTableDayService.updateTXinyiBigTableDay(tXinyiBigTableDay));
    }

    /**
     * 删除信义大天维度统计
     */
    @PreAuthorize("@ss.hasPermi('business:day:remove')")
    @Log(title = "信义大天维度统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable Long[] IDs)
    {
        return toAjax(tXinyiBigTableDayService.deleteTXinyiBigTableDayByIDs(IDs));
    }
}
