package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiBigTableHour;
import com.slibra.business.service.ITXinyiBigTableHourService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义大小时维度统计Controller
 * 
 * @author slibra
 * @date 2024-09-10
 */
@RestController
@RequestMapping("/business/hour")
public class TXinyiBigTableHourController extends BaseController
{
    @Autowired
    private ITXinyiBigTableHourService tXinyiBigTableHourService;

    /**
     * 查询信义大小时维度统计列表
     */
    @PreAuthorize("@ss.hasPermi('business:hour:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiBigTableHour tXinyiBigTableHour)
    {
        startPage();
        List<TXinyiBigTableHour> list = tXinyiBigTableHourService.selectTXinyiBigTableHourList(tXinyiBigTableHour);
        return getDataTable(list);
    }

    /**
     * 导出信义大小时维度统计列表
     */
    @PreAuthorize("@ss.hasPermi('business:hour:export')")
    @Log(title = "信义大小时维度统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiBigTableHour tXinyiBigTableHour)
    {
        List<TXinyiBigTableHour> list = tXinyiBigTableHourService.selectTXinyiBigTableHourList(tXinyiBigTableHour);
        ExcelUtil<TXinyiBigTableHour> util = new ExcelUtil<TXinyiBigTableHour>(TXinyiBigTableHour.class);
        util.exportExcel(response, list, "信义大小时维度统计数据");
    }

    /**
     * 获取信义大小时维度统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:hour:query')")
    @GetMapping(value = "/{ID}")
    public AjaxResult getInfo(@PathVariable("ID") Long ID)
    {
        return success(tXinyiBigTableHourService.selectTXinyiBigTableHourByID(ID));
    }

    /**
     * 新增信义大小时维度统计
     */
    @PreAuthorize("@ss.hasPermi('business:hour:add')")
    @Log(title = "信义大小时维度统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiBigTableHour tXinyiBigTableHour)
    {
        tXinyiBigTableHour.setCreateBy(getUsername());
        return toAjax(tXinyiBigTableHourService.insertTXinyiBigTableHour(tXinyiBigTableHour));
    }

    /**
     * 修改信义大小时维度统计
     */
    @PreAuthorize("@ss.hasPermi('business:hour:edit')")
    @Log(title = "信义大小时维度统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiBigTableHour tXinyiBigTableHour)
    {
        tXinyiBigTableHour.setUpdateBy(getUsername());
        return toAjax(tXinyiBigTableHourService.updateTXinyiBigTableHour(tXinyiBigTableHour));
    }

    /**
     * 删除信义大小时维度统计
     */
    @PreAuthorize("@ss.hasPermi('business:hour:remove')")
    @Log(title = "信义大小时维度统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable Long[] IDs)
    {
        return toAjax(tXinyiBigTableHourService.deleteTXinyiBigTableHourByIDs(IDs));
    }
}
