package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiBigTableMonth;
import com.slibra.business.service.ITXinyiBigTableMonthService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义大月维度统计Controller
 * 
 * @author slibra
 * @date 2024-09-10
 */
@RestController
@RequestMapping("/business/month")
public class TXinyiBigTableMonthController extends BaseController
{
    @Autowired
    private ITXinyiBigTableMonthService tXinyiBigTableMonthService;

    /**
     * 查询信义大月维度统计列表
     */
    @PreAuthorize("@ss.hasPermi('business:month:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiBigTableMonth tXinyiBigTableMonth)
    {
        startPage();
        List<TXinyiBigTableMonth> list = tXinyiBigTableMonthService.selectTXinyiBigTableMonthList(tXinyiBigTableMonth);
        return getDataTable(list);
    }

    /**
     * 导出信义大月维度统计列表
     */
    @PreAuthorize("@ss.hasPermi('business:month:export')")
    @Log(title = "信义大月维度统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiBigTableMonth tXinyiBigTableMonth)
    {
        List<TXinyiBigTableMonth> list = tXinyiBigTableMonthService.selectTXinyiBigTableMonthList(tXinyiBigTableMonth);
        ExcelUtil<TXinyiBigTableMonth> util = new ExcelUtil<TXinyiBigTableMonth>(TXinyiBigTableMonth.class);
        util.exportExcel(response, list, "信义大月维度统计数据");
    }

    /**
     * 获取信义大月维度统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:month:query')")
    @GetMapping(value = "/{ID}")
    public AjaxResult getInfo(@PathVariable("ID") Long ID)
    {
        return success(tXinyiBigTableMonthService.selectTXinyiBigTableMonthByID(ID));
    }

    /**
     * 新增信义大月维度统计
     */
    @PreAuthorize("@ss.hasPermi('business:month:add')")
    @Log(title = "信义大月维度统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiBigTableMonth tXinyiBigTableMonth)
    {
        tXinyiBigTableMonth.setCreateBy(getUsername());
        return toAjax(tXinyiBigTableMonthService.insertTXinyiBigTableMonth(tXinyiBigTableMonth));
    }

    /**
     * 修改信义大月维度统计
     */
    @PreAuthorize("@ss.hasPermi('business:month:edit')")
    @Log(title = "信义大月维度统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiBigTableMonth tXinyiBigTableMonth)
    {
        tXinyiBigTableMonth.setUpdateBy(getUsername());
        return toAjax(tXinyiBigTableMonthService.updateTXinyiBigTableMonth(tXinyiBigTableMonth));
    }

    /**
     * 删除信义大月维度统计
     */
    @PreAuthorize("@ss.hasPermi('business:month:remove')")
    @Log(title = "信义大月维度统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable Long[] IDs)
    {
        return toAjax(tXinyiBigTableMonthService.deleteTXinyiBigTableMonthByIDs(IDs));
    }
}
