package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiCalculate;
import com.slibra.business.service.ITXinyiCalculateService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义计算数据Controller
 * 
 * @author slibra
 * @date 2024-09-10
 */
@RestController
@RequestMapping("/business/calculate")
public class TXinyiCalculateController extends BaseController
{
    @Autowired
    private ITXinyiCalculateService tXinyiCalculateService;

    /**
     * 查询信义计算数据列表
     */
    @PreAuthorize("@ss.hasPermi('business:calculate:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiCalculate tXinyiCalculate)
    {
        startPage();
        List<TXinyiCalculate> list = tXinyiCalculateService.selectTXinyiCalculateList(tXinyiCalculate);
        return getDataTable(list);
    }

    /**
     * 导出信义计算数据列表
     */
    @PreAuthorize("@ss.hasPermi('business:calculate:export')")
    @Log(title = "信义计算数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiCalculate tXinyiCalculate)
    {
        List<TXinyiCalculate> list = tXinyiCalculateService.selectTXinyiCalculateList(tXinyiCalculate);
        ExcelUtil<TXinyiCalculate> util = new ExcelUtil<TXinyiCalculate>(TXinyiCalculate.class);
        util.exportExcel(response, list, "信义计算数据数据");
    }

    /**
     * 获取信义计算数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:calculate:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tXinyiCalculateService.selectTXinyiCalculateById(id));
    }

    /**
     * 新增信义计算数据
     */
    @PreAuthorize("@ss.hasPermi('business:calculate:add')")
    @Log(title = "信义计算数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiCalculate tXinyiCalculate)
    {
        tXinyiCalculate.setCreateBy(getUsername());
        return toAjax(tXinyiCalculateService.insertTXinyiCalculate(tXinyiCalculate));
    }

    /**
     * 修改信义计算数据
     */
    @PreAuthorize("@ss.hasPermi('business:calculate:edit')")
    @Log(title = "信义计算数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiCalculate tXinyiCalculate)
    {
        tXinyiCalculate.setUpdateBy(getUsername());
        return toAjax(tXinyiCalculateService.updateTXinyiCalculate(tXinyiCalculate));
    }

    /**
     * 删除信义计算数据
     */
    @PreAuthorize("@ss.hasPermi('business:calculate:remove')")
    @Log(title = "信义计算数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tXinyiCalculateService.deleteTXinyiCalculateByIds(ids));
    }
}
