package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiCarbonMajor;
import com.slibra.business.service.ITXinyiCarbonMajorService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 碳排放主Controller
 * 
 * @author slibra
 * @date 2024-08-24
 */
@RestController
@RequestMapping("/business/major")
public class TXinyiCarbonMajorController extends BaseController
{
    @Autowired
    private ITXinyiCarbonMajorService tXinyiCarbonMajorService;

    /**
     * 查询碳排放主列表
     */
    @PreAuthorize("@ss.hasPermi('business:major:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiCarbonMajor tXinyiCarbonMajor)
    {
        startPage();
        List<TXinyiCarbonMajor> list = tXinyiCarbonMajorService.selectTXinyiCarbonMajorList(tXinyiCarbonMajor);
        return getDataTable(list);
    }

    /**
     * 导出碳排放主列表
     */
    @PreAuthorize("@ss.hasPermi('business:major:export')")
    @Log(title = "碳排放主", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiCarbonMajor tXinyiCarbonMajor)
    {
        List<TXinyiCarbonMajor> list = tXinyiCarbonMajorService.selectTXinyiCarbonMajorList(tXinyiCarbonMajor);
        ExcelUtil<TXinyiCarbonMajor> util = new ExcelUtil<TXinyiCarbonMajor>(TXinyiCarbonMajor.class);
        util.exportExcel(response, list, "碳排放主数据");
    }

    /**
     * 获取碳排放主详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:major:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tXinyiCarbonMajorService.selectTXinyiCarbonMajorById(id));
    }

    /**
     * 新增碳排放主
     */
    @PreAuthorize("@ss.hasPermi('business:major:add')")
    @Log(title = "碳排放主", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiCarbonMajor tXinyiCarbonMajor)
    {
        tXinyiCarbonMajor.setCreateBy(getUsername());
        return toAjax(tXinyiCarbonMajorService.insertTXinyiCarbonMajor(tXinyiCarbonMajor));
    }

    /**
     * 修改碳排放主
     */
    @PreAuthorize("@ss.hasPermi('business:major:edit')")
    @Log(title = "碳排放主", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiCarbonMajor tXinyiCarbonMajor)
    {
        tXinyiCarbonMajor.setUpdateBy(getUsername());
        return toAjax(tXinyiCarbonMajorService.updateTXinyiCarbonMajor(tXinyiCarbonMajor));
    }

    /**
     * 删除碳排放主
     */
    @PreAuthorize("@ss.hasPermi('business:major:remove')")
    @Log(title = "碳排放主", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tXinyiCarbonMajorService.deleteTXinyiCarbonMajorByIds(ids));
    }
}
