package com.slibra.web.controller.business;

import java.util.List;
import java.util.Objects;
import javax.servlet.http.HttpServletResponse;

import com.slibra.common.core.domain.entity.SysUser;
import com.slibra.system.mapper.SysUserMapper;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiChatRecord;
import com.slibra.business.service.ITXinyiChatRecordService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义大模型问答记录Controller
 * 
 * @author slibra
 * @date 2024-05-15
 */
@RestController
@RequestMapping("/business/chatRecord")
public class TXinyiChatRecordController extends BaseController
{
    @Autowired
    private ITXinyiChatRecordService tXinyiChatRecordService;

    @Autowired
    private SysUserMapper sysUserMapper;

    /**
     * 查询信义大模型问答记录列表
     */
    @PreAuthorize("@ss.hasPermi('business:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiChatRecord tXinyiChatRecord)
    {
        startPage();
        List<TXinyiChatRecord> list = tXinyiChatRecordService.selectTXinyiChatRecordList(tXinyiChatRecord);
        //2024年7月1日14:43:48 额外出来2个关联的字段
        if(!CollectionUtils.isEmpty(list))
            this.addExtra(list);
        return getDataTable(list);
    }

    /**
     * 导出信义大模型问答记录列表
     */
    @PreAuthorize("@ss.hasPermi('business:record:export')")
    @Log(title = "信义大模型问答记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiChatRecord tXinyiChatRecord)
    {
        List<TXinyiChatRecord> list = tXinyiChatRecordService.selectTXinyiChatRecordList(tXinyiChatRecord);
        if(!CollectionUtils.isEmpty(list))
            this.addExtra(list);
        ExcelUtil<TXinyiChatRecord> util = new ExcelUtil<TXinyiChatRecord>(TXinyiChatRecord.class);
        util.exportExcel(response, list, "信义大模型问答记录数据");
    }

    private void addExtra(List<TXinyiChatRecord> list) {
        for (TXinyiChatRecord xinyiChatRecord : list) {
            SysUser sysUser = this.sysUserMapper.selectUserById(Long.valueOf(xinyiChatRecord.getUserId()));
            if(!Objects.isNull(sysUser)){
                xinyiChatRecord.setUserName(sysUser.getUserName());
                xinyiChatRecord.setPhonenumber(sysUser.getPhonenumber());
            }
        }
    }

    /**
     * 获取信义大模型问答记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:record:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tXinyiChatRecordService.selectTXinyiChatRecordById(id));
    }

    /**
     * 新增信义大模型问答记录
     */
//    @PreAuthorize("@ss.hasPermi('business:record:add')")
    @Log(title = "信义大模型问答记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiChatRecord tXinyiChatRecord)
    {
        tXinyiChatRecord.setCreateBy(getUsername());
        return toAjax(tXinyiChatRecordService.insertTXinyiChatRecord(tXinyiChatRecord));
    }

    /**
     * 修改信义大模型问答记录
     */
    @PreAuthorize("@ss.hasPermi('business:record:edit')")
    @Log(title = "信义大模型问答记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiChatRecord tXinyiChatRecord)
    {
        tXinyiChatRecord.setUpdateBy(getUsername());
        return toAjax(tXinyiChatRecordService.updateTXinyiChatRecord(tXinyiChatRecord));
    }

    /**
     * 删除信义大模型问答记录
     */
    @PreAuthorize("@ss.hasPermi('business:record:remove')")
    @Log(title = "信义大模型问答记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tXinyiChatRecordService.deleteTXinyiChatRecordByIds(ids));
    }
}
