package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONWriter;
import com.slibra.common.core.domain.TXinyiDaily;
import com.slibra.business.mapper.TXinyiDailyMapper;
import com.slibra.business.service.ITXinyiDailyService;
import com.slibra.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义日报数据Controller
 * 
 * @author slibra
 * @date 2024-04-13
 */
@RestController
@RequestMapping("/business/daily")
public class TXinyiDailyController extends BaseController
{
    @Autowired
    private ITXinyiDailyService tXinyiDailyService;

    @Autowired
    private TXinyiDailyMapper xinyiDailyMapper;

    /**
     * 查询信义日报数据列表
     */
//    @PreAuthorize("@ss.hasPermi('system:daily:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiDaily tXinyiDaily)
    {
        startPage();
        List<TXinyiDaily> list = tXinyiDailyService.selectTXinyiDailyList(tXinyiDaily);
        return getDataTable(list);
    }

    /**
     * 导出信义日报数据列表
     */
//    @PreAuthorize("@ss.hasPermi('system:daily:export')")
    @Log(title = "信义日报数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiDaily tXinyiDaily)
    {
        List<TXinyiDaily> list = tXinyiDailyService.selectTXinyiDailyList(tXinyiDaily);
        ExcelUtil<TXinyiDaily> util = new ExcelUtil<TXinyiDaily>(TXinyiDaily.class);
        util.exportExcel(response, list, "信义日报数据数据");
    }

    /**
     * 获取信义日报数据详细信息
     */
//    @PreAuthorize("@ss.hasPermi('system:daily:query')")
    @GetMapping(value = "/{ID}")
    public String getInfo(@PathVariable("ID") Long ID)
    {
        return JSON.toJSONString(success(tXinyiDailyService.selectTXinyiDailyByID(ID)), JSONWriter.Feature.WriteNulls);
    }

    /**
     * 新增信义日报数据
     */
//    @PreAuthorize("@ss.hasPermi('system:daily:add')")
    @Log(title = "信义日报数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody String json)
    {
        TXinyiDaily tXinyiDaily = JSON.parseObject(json, TXinyiDaily.class);
        return toAjax(tXinyiDailyService.insertTXinyiDaily(tXinyiDaily));
    }

    /**
     * 修改信义日报数据
     */
//    @PreAuthorize("@ss.hasPermi('system:daily:edit')")
    @Log(title = "信义日报数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiDaily tXinyiDaily)
    {
        return toAjax(tXinyiDailyService.updateTXinyiDaily(tXinyiDaily));
    }

    /**
     * 删除信义日报数据
     */
//    @PreAuthorize("@ss.hasPermi('system:daily:remove')")
    @Log(title = "信义日报数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable Long[] IDs)
    {
        return toAjax(tXinyiDailyService.deleteTXinyiDailyByIDs(IDs));
    }


    //---------------下面是手动新增的接口---------------

    /**
     *
     * 通过化验日期获取当天的日报信息
     * @param testDate
     * @return
     */
    @GetMapping(value = "/getDetailByDay")
    public String getDetailByDay(@RequestParam String testDate)
    {
        //改成用SQL处理
//        return success(xinyiDailyMapper.getDetailByDay(testDate));
        return JSON.toJSONString(success(xinyiDailyMapper.getDetailByDay(testDate)), JSONWriter.Feature.WriteNulls);
    }


    /**
     * 获取最近30天的日期，并返回是否已经填写了日报
     * @return
     */
    @GetMapping(value = "/getRecently30CountInfo")
    public AjaxResult getRecently30CountInfo()
    {
        //改成用SQL处理
        return success(tXinyiDailyService.getRecently30CountInfo());
    }
}
