package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiFeedback;
import com.slibra.business.service.ITXinyiFeedbackService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义意见反馈Controller
 * 
 * @author slibra
 * @date 2024-05-27
 */
@RestController
@RequestMapping("/business/feedback")
public class TXinyiFeedbackController extends BaseController
{
    @Autowired
    private ITXinyiFeedbackService tXinyiFeedbackService;

    /**
     * 查询信义意见反馈列表
     */
//    @PreAuthorize("@ss.hasPermi('business:feedback:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiFeedback tXinyiFeedback)
    {
        startPage();
        List<TXinyiFeedback> list = tXinyiFeedbackService.selectTXinyiFeedbackList(tXinyiFeedback);
        return getDataTable(list);
    }

    /**
     * 导出信义意见反馈列表
     */
//    @PreAuthorize("@ss.hasPermi('business:feedback:export')")
    @Log(title = "信义意见反馈", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiFeedback tXinyiFeedback)
    {
        List<TXinyiFeedback> list = tXinyiFeedbackService.selectTXinyiFeedbackList(tXinyiFeedback);
        ExcelUtil<TXinyiFeedback> util = new ExcelUtil<TXinyiFeedback>(TXinyiFeedback.class);
        util.exportExcel(response, list, "信义意见反馈数据");
    }

    /**
     * 获取信义意见反馈详细信息
     */
//    @PreAuthorize("@ss.hasPermi('business:feedback:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tXinyiFeedbackService.selectTXinyiFeedbackById(id));
    }

    /**
     * 新增信义意见反馈
     */
//    @PreAuthorize("@ss.hasPermi('business:feedback:add')")
    @Log(title = "信义意见反馈", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiFeedback tXinyiFeedback)
    {
        tXinyiFeedback.setCreateBy(getUsername());
        return toAjax(tXinyiFeedbackService.insertTXinyiFeedback(tXinyiFeedback));
    }

    /**
     * 修改信义意见反馈
     */
//    @PreAuthorize("@ss.hasPermi('business:feedback:edit')")
    @Log(title = "信义意见反馈", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiFeedback tXinyiFeedback)
    {
        tXinyiFeedback.setUpdateBy(getUsername());
        return toAjax(tXinyiFeedbackService.updateTXinyiFeedback(tXinyiFeedback));
    }

    /**
     * 删除信义意见反馈
     */
//    @PreAuthorize("@ss.hasPermi('business:feedback:remove')")
    @Log(title = "信义意见反馈", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tXinyiFeedbackService.deleteTXinyiFeedbackByIds(ids));
    }
}
