package com.slibra.web.controller.business;

import java.math.BigDecimal;
import java.util.List;
import java.util.Objects;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson2.JSONObject;
import com.slibra.common.DecimalUtils;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiForecastComparison;
import com.slibra.business.service.ITXinyiForecastComparisonService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

import static com.slibra.common.constant.MyConstants.*;

/**
 * 信义预测对比Controller
 * 
 * @author slibra
 * @date 2024-06-20
 */
@RestController
@RequestMapping("/business/comparison")
public class TXinyiForecastComparisonController extends BaseController
{
    @Autowired
    private ITXinyiForecastComparisonService tXinyiForecastComparisonService;

    /**
     * 查询信义预测对比列表(分页)
     */
//    @PreAuthorize("@ss.hasPermi('business:comparison:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiForecastComparison tXinyiForecastComparison)
    {
        startPage();
        List<TXinyiForecastComparison> list = tXinyiForecastComparisonService.selectTXinyiForecastComparisonList(tXinyiForecastComparison);
        this.addListExtra(list);//处理误差率 乘以100，取绝对值 保留2位小数
        return getDataTable(list);
    }


    /**
     * 图标展示接口（不分页）
     * @param tXinyiForecastComparison
     * @return
     */
    @GetMapping("/echartsList")
//    public List<TXinyiForecastComparison> echartsList(TXinyiForecastComparison tXinyiForecastComparison)
    public JSONObject echartsList(TXinyiForecastComparison tXinyiForecastComparison)
    {
        /*//请求参数
        String timeBegin = tXinyiForecastComparison.getTimeBegin();
        String timeEnd = tXinyiForecastComparison.getTimeEnd();

        //日期兜底处理
        Date nowDate = DateUtils.getNowDate();
        Date dayBefore7 = DateUtils.plusDate(-7, nowDate);
        //先用日期获取当天和前一天的数据，如果获取不到，则提示错误信息
        String nowDateStr = DateUtils.parseDateToStr(DateUtils.YYYYMMDD_TS, nowDate)  + TIME_END_23;
        String dayBefore7Str = DateUtils.parseDateToStr(DateUtils.YYYYMMDD_TS, dayBefore7)  + TIME_BEGIN_00;
        if(StringUtils.isBlank(timeBegin))
            tXinyiForecastComparison.setTimeBegin(dayBefore7Str);
        if(StringUtils.isBlank(timeEnd))
            tXinyiForecastComparison.setTimeEnd(nowDateStr);
        //        this.addListExtra(list);//处理误差率 乘以100，取绝对值 保留2位小数
        //2024年08月16日14:37:52  同一个SQL，不同排序
        tXinyiForecastComparison.setSort(SORT_ASC);
        return tXinyiForecastComparisonService.selectTXinyiForecastComparisonList(tXinyiForecastComparison);*/
        //2024年08月23日15:39:04  返回结果调整，只要3条数据：
        return this.tXinyiForecastComparisonService.echartsList(tXinyiForecastComparison);
    }

    /**
     * 导出信义预测对比列表
     */
//    @PreAuthorize("@ss.hasPermi('business:comparison:export')")
    @Log(title = "信义预测对比", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiForecastComparison tXinyiForecastComparison)
    {
        List<TXinyiForecastComparison> list = tXinyiForecastComparisonService.selectTXinyiForecastComparisonList(tXinyiForecastComparison);
        this.addListExtra(list);//处理误差率 乘以100，取绝对值 保留2位小数
        ExcelUtil<TXinyiForecastComparison> util = new ExcelUtil<TXinyiForecastComparison>(TXinyiForecastComparison.class);
        util.exportExcel(response, list, "信义预测对比数据");
    }

    private void addListExtra(List<TXinyiForecastComparison> list) {
        if(!CollectionUtils.isEmpty(list)){
            for (TXinyiForecastComparison tXinyiForecastComparison : list) {
                BigDecimal hsErrorRateOne = tXinyiForecastComparison.getHsErrorRateOne();
                if(!Objects.isNull(hsErrorRateOne))
                    tXinyiForecastComparison.setHsErrorRateOneStr(DecimalUtils.getAbsAndScale(BigDecimal_100.multiply(hsErrorRateOne), 2) + PERCENT_SYMBOL);
                BigDecimal hsErrorRateTwo = tXinyiForecastComparison.getHsErrorRateTwo();
                if(!Objects.isNull(hsErrorRateTwo))
                    tXinyiForecastComparison.setHsErrorRateTwoStr(DecimalUtils.getAbsAndScale(BigDecimal_100.multiply(hsErrorRateTwo), 2) + PERCENT_SYMBOL);
                BigDecimal hsErrorRateThree = tXinyiForecastComparison.getHsErrorRateThree();
                if(!Objects.isNull(hsErrorRateThree))
                    tXinyiForecastComparison.setHsErrorRateThreeStr(DecimalUtils.getAbsAndScale(BigDecimal_100.multiply(hsErrorRateThree), 2) + PERCENT_SYMBOL);
                BigDecimal yyErrorRateOne = tXinyiForecastComparison.getYyErrorRateOne();
                if(!Objects.isNull(yyErrorRateOne))
                    tXinyiForecastComparison.setYyErrorRateOneStr(DecimalUtils.getAbsAndScale(BigDecimal_100.multiply(yyErrorRateOne), 2) + PERCENT_SYMBOL);
                BigDecimal yyErrorRateTwo = tXinyiForecastComparison.getYyErrorRateTwo();
                if(!Objects.isNull(yyErrorRateTwo))
                    tXinyiForecastComparison.setYyErrorRateTwoStr(DecimalUtils.getAbsAndScale(BigDecimal_100.multiply(yyErrorRateTwo), 2) + PERCENT_SYMBOL);
                BigDecimal yyErrorRateThree = tXinyiForecastComparison.getYyErrorRateThree();
                if(!Objects.isNull(yyErrorRateThree))
                    tXinyiForecastComparison.setYyErrorRateThreeStr(DecimalUtils.getAbsAndScale(BigDecimal_100.multiply(yyErrorRateThree), 2) + PERCENT_SYMBOL);
                //2025年02月12日17:03:02 下面处理机理模型的百分百的
                BigDecimal jlErrorRateOne = tXinyiForecastComparison.getJlErrorRateOne();
                if(!Objects.isNull(jlErrorRateOne))
                    tXinyiForecastComparison.setJlErrorRateOneStr(DecimalUtils.getAbsAndScale(BigDecimal_100.multiply(jlErrorRateOne), 2) + PERCENT_SYMBOL);
                BigDecimal jlErrorRateTwo = tXinyiForecastComparison.getJlErrorRateTwo();
                if(!Objects.isNull(jlErrorRateTwo))
                    tXinyiForecastComparison.setJlErrorRateTwoStr(DecimalUtils.getAbsAndScale(BigDecimal_100.multiply(jlErrorRateTwo), 2) + PERCENT_SYMBOL);
                BigDecimal jlErrorRateThree = tXinyiForecastComparison.getJlErrorRateThree();
                if(!Objects.isNull(jlErrorRateThree))
                    tXinyiForecastComparison.setJlErrorRateThreeStr(DecimalUtils.getAbsAndScale(BigDecimal_100.multiply(jlErrorRateThree), 2) + PERCENT_SYMBOL);
            }
        }
    }

    /**
     * 获取信义预测对比详细信息
     */
//    @PreAuthorize("@ss.hasPermi('business:comparison:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tXinyiForecastComparisonService.selectTXinyiForecastComparisonById(id));
    }

    /**
     * 新增信义预测对比
     */
//    @PreAuthorize("@ss.hasPermi('business:comparison:add')")
    @Log(title = "信义预测对比", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiForecastComparison tXinyiForecastComparison)
    {
        tXinyiForecastComparison.setCreateBy(getUsername());
        return toAjax(tXinyiForecastComparisonService.insertTXinyiForecastComparison(tXinyiForecastComparison));
    }

    /**
     * 修改信义预测对比
     */
//    @PreAuthorize("@ss.hasPermi('business:comparison:edit')")
    @Log(title = "信义预测对比", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiForecastComparison tXinyiForecastComparison)
    {
        tXinyiForecastComparison.setUpdateBy(getUsername());
        return toAjax(tXinyiForecastComparisonService.updateTXinyiForecastComparison(tXinyiForecastComparison));
    }

    /**
     * 删除信义预测对比
     */
//    @PreAuthorize("@ss.hasPermi('business:comparison:remove')")
    @Log(title = "信义预测对比", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tXinyiForecastComparisonService.deleteTXinyiForecastComparisonByIds(ids));
    }

    public static void main(String[] args) {
        System.out.println(DateUtils.parseDateToStr(DateUtils.YYYYMMDD_TS, DateUtils.getNowDate()) + TIME_BEGIN_00);
        System.out.println(DateUtils.parseDateToStr(DateUtils.YYYYMMDD_TS, DateUtils.getNowDate()) + TIME_END_23);
    }
}
