package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiIndustry;
import com.slibra.business.service.ITXinyiIndustryService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义工业数据Controller
 * 
 * @author slibra
 * @date 2024-09-10
 */
@RestController
@RequestMapping("/business/industry")
public class TXinyiIndustryController extends BaseController
{
    @Autowired
    private ITXinyiIndustryService tXinyiIndustryService;

    /**
     * 查询信义工业数据列表
     */
    @PreAuthorize("@ss.hasPermi('business:industry:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiIndustry tXinyiIndustry)
    {
        startPage();
        List<TXinyiIndustry> list = tXinyiIndustryService.selectTXinyiIndustryList(tXinyiIndustry);
        return getDataTable(list);
    }

    /**
     * 导出信义工业数据列表
     */
    @PreAuthorize("@ss.hasPermi('business:industry:export')")
    @Log(title = "信义工业数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiIndustry tXinyiIndustry)
    {
        List<TXinyiIndustry> list = tXinyiIndustryService.selectTXinyiIndustryList(tXinyiIndustry);
        ExcelUtil<TXinyiIndustry> util = new ExcelUtil<TXinyiIndustry>(TXinyiIndustry.class);
        util.exportExcel(response, list, "信义工业数据数据");
    }

    /**
     * 获取信义工业数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:industry:query')")
    @GetMapping(value = "/{ID}")
    public AjaxResult getInfo(@PathVariable("ID") Long ID)
    {
        return success(tXinyiIndustryService.selectTXinyiIndustryByID(ID));
    }

    /**
     * 新增信义工业数据
     */
    @PreAuthorize("@ss.hasPermi('business:industry:add')")
    @Log(title = "信义工业数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiIndustry tXinyiIndustry)
    {
//        tXinyiIndustry.setCreateBy(getUsername());
        return toAjax(tXinyiIndustryService.insertTXinyiIndustry(tXinyiIndustry));
    }

    /**
     * 修改信义工业数据
     */
    @PreAuthorize("@ss.hasPermi('business:industry:edit')")
    @Log(title = "信义工业数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiIndustry tXinyiIndustry)
    {
//        tXinyiIndustry.setUpdateBy(getUsername());
        return toAjax(tXinyiIndustryService.updateTXinyiIndustry(tXinyiIndustry));
    }

    /**
     * 删除信义工业数据
     */
    @PreAuthorize("@ss.hasPermi('business:industry:remove')")
    @Log(title = "信义工业数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable Long[] IDs)
    {
        return toAjax(tXinyiIndustryService.deleteTXinyiIndustryByIDs(IDs));
    }
}
