package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiMedicineAddRecord;
import com.slibra.business.service.ITXinyiMedicineAddRecordService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义碳源投加记录Controller
 * 
 * @author slibra
 * @date 2025-05-09
 */
@RestController
@RequestMapping("/business/medicineAddRecord")
public class TXinyiMedicineAddRecordController extends BaseController
{
    @Autowired
    private ITXinyiMedicineAddRecordService tXinyiMedicineAddRecordService;

    /**
     * 查询信义碳源投加记录列表
     */
    @PreAuthorize("@ss.hasPermi('business:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiMedicineAddRecord tXinyiMedicineAddRecord)
    {
        startPage();
        List<TXinyiMedicineAddRecord> list = tXinyiMedicineAddRecordService.selectTXinyiMedicineAddRecordList(tXinyiMedicineAddRecord);
        return getDataTable(list);
    }

    /**
     * 导出信义碳源投加记录列表
     */
    @PreAuthorize("@ss.hasPermi('business:record:export')")
    @Log(title = "信义碳源投加记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiMedicineAddRecord tXinyiMedicineAddRecord)
    {
        List<TXinyiMedicineAddRecord> list = tXinyiMedicineAddRecordService.selectTXinyiMedicineAddRecordList(tXinyiMedicineAddRecord);
        ExcelUtil<TXinyiMedicineAddRecord> util = new ExcelUtil<TXinyiMedicineAddRecord>(TXinyiMedicineAddRecord.class);
        util.exportExcel(response, list, "信义碳源投加记录数据");
    }

    /**
     * 获取信义碳源投加记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:record:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tXinyiMedicineAddRecordService.selectTXinyiMedicineAddRecordById(id));
    }

    /**
     * 新增信义碳源投加记录
     */
    @PreAuthorize("@ss.hasPermi('business:record:add')")
    @Log(title = "信义碳源投加记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiMedicineAddRecord tXinyiMedicineAddRecord)
    {
        tXinyiMedicineAddRecord.setCreateBy(getUsername());
        return toAjax(tXinyiMedicineAddRecordService.insertTXinyiMedicineAddRecord(tXinyiMedicineAddRecord));
    }

    /**
     * 修改信义碳源投加记录
     */
    @PreAuthorize("@ss.hasPermi('business:record:edit')")
    @Log(title = "信义碳源投加记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiMedicineAddRecord tXinyiMedicineAddRecord)
    {
        tXinyiMedicineAddRecord.setUpdateBy(getUsername());
        return toAjax(tXinyiMedicineAddRecordService.updateTXinyiMedicineAddRecord(tXinyiMedicineAddRecord));
    }

    /**
     * 删除信义碳源投加记录
     */
    @PreAuthorize("@ss.hasPermi('business:record:remove')")
    @Log(title = "信义碳源投加记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tXinyiMedicineAddRecordService.deleteTXinyiMedicineAddRecordByIds(ids));
    }
}
