package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.slibra.business.req.MedicineParamsDetail;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiMedicineRemote;
import com.slibra.business.service.ITXinyiMedicineRemoteService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 调参逻辑设定Controller
 * 
 * @author slibra
 * @date 2025-04-23
 */
@RestController
@RequestMapping("/business/medicineRemote")
public class TXinyiMedicineRemoteController extends BaseController
{
    @Autowired
    private ITXinyiMedicineRemoteService tXinyiMedicineRemoteService;

    /**
     * 查询调参逻辑设定列表
     */
//    @PreAuthorize("@ss.hasPermi('business:remote:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiMedicineRemote tXinyiMedicineRemote)
    {
        startPage();
        List<TXinyiMedicineRemote> list = tXinyiMedicineRemoteService.selectTXinyiMedicineRemoteList(tXinyiMedicineRemote);
        return getDataTable(list);
    }

    /**
     * 导出调参逻辑设定列表
     */
//    @PreAuthorize("@ss.hasPermi('business:remote:export')")
    @Log(title = "调参逻辑设定", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiMedicineRemote tXinyiMedicineRemote)
    {
        List<TXinyiMedicineRemote> list = tXinyiMedicineRemoteService.selectTXinyiMedicineRemoteList(tXinyiMedicineRemote);
        ExcelUtil<TXinyiMedicineRemote> util = new ExcelUtil<TXinyiMedicineRemote>(TXinyiMedicineRemote.class);
        util.exportExcel(response, list, "调参逻辑设定数据");
    }

    /**
     * 获取调参逻辑设定详细信息
     */
//    @PreAuthorize("@ss.hasPermi('business:remote:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tXinyiMedicineRemoteService.selectTXinyiMedicineRemoteById(id));
    }

    /**
     * 新增调参逻辑设定
     */
//    @PreAuthorize("@ss.hasPermi('business:remote:add')")
    @Log(title = "调参逻辑设定", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiMedicineRemote tXinyiMedicineRemote)
    {
        tXinyiMedicineRemote.setCreateBy(getUsername());
        return toAjax(tXinyiMedicineRemoteService.insertTXinyiMedicineRemote(tXinyiMedicineRemote));
    }

    /**
     * 修改调参逻辑设定
     * 2025年04月23日17:50:52 请求参数改成前端传递的对象 然后拼接成最终的保存数据
     */
//    @PreAuthorize("@ss.hasPermi('business:remote:edit')")
    @Log(title = "调参逻辑设定", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MedicineParamsDetail medicineParamsDetail)
    {
        return toAjax(tXinyiMedicineRemoteService.updateTXinyiMedicineRemote(medicineParamsDetail));
    }

    /**
     * 删除调参逻辑设定
     */
//    @PreAuthorize("@ss.hasPermi('business:remote:remove')")
    @Log(title = "调参逻辑设定", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tXinyiMedicineRemoteService.deleteTXinyiMedicineRemoteByIds(ids));
    }


    //-------------------下面是新增的接口-------------------\\
    @GetMapping(value = "/getLatestRecord")
    public AjaxResult getLatestRecord()
    {
        return success(tXinyiMedicineRemoteService.getLatestRecord());
    }
}
