package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiRecommendQa;
import com.slibra.business.service.ITXinyiRecommendQaService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义推荐问答列Controller
 * 
 * @author slibra
 * @date 2024-05-17
 */
@RestController
@RequestMapping("/business/qa")
public class TXinyiRecommendQaController extends BaseController
{
    @Autowired
    private ITXinyiRecommendQaService tXinyiRecommendQaService;

    /**
     * 查询信义推荐问答列列表
     */
    @PreAuthorize("@ss.hasPermi('business:qa:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiRecommendQa tXinyiRecommendQa)
    {
        startPage();
        List<TXinyiRecommendQa> list = tXinyiRecommendQaService.selectTXinyiRecommendQaList(tXinyiRecommendQa);
        return getDataTable(list);
    }

    /**
     * 导出信义推荐问答列列表
     */
    @PreAuthorize("@ss.hasPermi('business:qa:export')")
    @Log(title = "信义推荐问答列", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiRecommendQa tXinyiRecommendQa)
    {
        List<TXinyiRecommendQa> list = tXinyiRecommendQaService.selectTXinyiRecommendQaList(tXinyiRecommendQa);
        ExcelUtil<TXinyiRecommendQa> util = new ExcelUtil<TXinyiRecommendQa>(TXinyiRecommendQa.class);
        util.exportExcel(response, list, "信义推荐问答列数据");
    }

    /**
     * 获取信义推荐问答列详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:qa:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tXinyiRecommendQaService.selectTXinyiRecommendQaById(id));
    }

    /**
     * 新增信义推荐问答列
     */
    @PreAuthorize("@ss.hasPermi('business:qa:add')")
    @Log(title = "信义推荐问答列", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiRecommendQa tXinyiRecommendQa)
    {
        tXinyiRecommendQa.setCreateBy(getUsername());
        return toAjax(tXinyiRecommendQaService.insertTXinyiRecommendQa(tXinyiRecommendQa));
    }

    /**
     * 修改信义推荐问答列
     */
    @PreAuthorize("@ss.hasPermi('business:qa:edit')")
    @Log(title = "信义推荐问答列", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiRecommendQa tXinyiRecommendQa)
    {
        tXinyiRecommendQa.setUpdateBy(getUsername());
        return toAjax(tXinyiRecommendQaService.updateTXinyiRecommendQa(tXinyiRecommendQa));
    }

    /**
     * 删除信义推荐问答列
     */
    @PreAuthorize("@ss.hasPermi('business:qa:remove')")
    @Log(title = "信义推荐问答列", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tXinyiRecommendQaService.deleteTXinyiRecommendQaByIds(ids));
    }
}
