package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiRobot;
import com.slibra.business.service.ITXinyiRobotService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义化验数据Controller
 * 
 * @author slibra
 * @date 2024-09-10
 */
@RestController
@RequestMapping("/business/robot")
public class TXinyiRobotController extends BaseController
{
    @Autowired
    private ITXinyiRobotService tXinyiRobotService;

    /**
     * 查询信义化验数据列表
     */
//    @PreAuthorize("@ss.hasPermi('business:robot:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiRobot tXinyiRobot)
    {
        startPage();
        List<TXinyiRobot> list = tXinyiRobotService.selectTXinyiRobotList(tXinyiRobot);
        return getDataTable(list);
    }

    /**
     * 导出信义化验数据列表
     */
    @PreAuthorize("@ss.hasPermi('business:robot:export')")
    @Log(title = "信义化验数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiRobot tXinyiRobot)
    {
        List<TXinyiRobot> list = tXinyiRobotService.selectTXinyiRobotList(tXinyiRobot);
        ExcelUtil<TXinyiRobot> util = new ExcelUtil<TXinyiRobot>(TXinyiRobot.class);
        util.exportExcel(response, list, "信义化验数据数据");
    }

    /**
     * 获取信义化验数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:robot:query')")
    @GetMapping(value = "/{ID}")
    public AjaxResult getInfo(@PathVariable("ID") Long ID)
    {
        return success(tXinyiRobotService.selectTXinyiRobotByID(ID));
    }

    /**
     * 新增信义化验数据
     */
    @PreAuthorize("@ss.hasPermi('business:robot:add')")
    @Log(title = "信义化验数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiRobot tXinyiRobot)
    {
//        tXinyiRobot.setCreateBy(getUsername());
        return toAjax(tXinyiRobotService.insertTXinyiRobot(tXinyiRobot));
    }

    /**
     * 修改信义化验数据
     */
    @PreAuthorize("@ss.hasPermi('business:robot:edit')")
    @Log(title = "信义化验数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiRobot tXinyiRobot)
    {
//        tXinyiRobot.setUpdateBy(getUsername());
        return toAjax(tXinyiRobotService.updateTXinyiRobot(tXinyiRobot));
    }

    /**
     * 删除信义化验数据
     */
    @PreAuthorize("@ss.hasPermi('business:robot:remove')")
    @Log(title = "信义化验数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable Long[] IDs)
    {
        return toAjax(tXinyiRobotService.deleteTXinyiRobotByIDs(IDs));
    }
}
