package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TXinyiTytjParams;
import com.slibra.business.service.ITXinyiTytjParamsService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 信义碳源投加参数配置Controller
 * 
 * @author slibra
 * @date 2025-04-23
 */
@RestController
@RequestMapping("/business/tytjParams")
public class TXinyiTytjParamsController extends BaseController
{
    @Autowired
    private ITXinyiTytjParamsService tXinyiTytjParamsService;

    /**
     * 查询信义碳源投加参数配置列表
     */
//    @PreAuthorize("@ss.hasPermi('business:params:list')")
    @GetMapping("/list")
    public TableDataInfo list(TXinyiTytjParams tXinyiTytjParams)
    {
        startPage();
        List<TXinyiTytjParams> list = tXinyiTytjParamsService.selectTXinyiTytjParamsList(tXinyiTytjParams);
        return getDataTable(list);
    }

    /**
     * 导出信义碳源投加参数配置列表
     */
//    @PreAuthorize("@ss.hasPermi('business:params:export')")
    @Log(title = "信义碳源投加参数配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TXinyiTytjParams tXinyiTytjParams)
    {
        List<TXinyiTytjParams> list = tXinyiTytjParamsService.selectTXinyiTytjParamsList(tXinyiTytjParams);
        ExcelUtil<TXinyiTytjParams> util = new ExcelUtil<TXinyiTytjParams>(TXinyiTytjParams.class);
        util.exportExcel(response, list, "信义碳源投加参数配置数据");
    }

    /**
     * 获取信义碳源投加参数配置详细信息
     */
//    @PreAuthorize("@ss.hasPermi('business:params:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tXinyiTytjParamsService.selectTXinyiTytjParamsById(id));
    }

    /**
     * 新增信义碳源投加参数配置
     */
//    @PreAuthorize("@ss.hasPermi('business:params:add')")
    @Log(title = "信义碳源投加参数配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TXinyiTytjParams tXinyiTytjParams)
    {
        tXinyiTytjParams.setCreateBy(getUsername());
        return toAjax(tXinyiTytjParamsService.insertTXinyiTytjParams(tXinyiTytjParams));
    }

    /**
     * 修改信义碳源投加参数配置
     */
//    @PreAuthorize("@ss.hasPermi('business:params:edit')")
    @Log(title = "信义碳源投加参数配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TXinyiTytjParams tXinyiTytjParams)
    {
        tXinyiTytjParams.setUpdateBy(getUsername());
        return toAjax(tXinyiTytjParamsService.updateTXinyiTytjParams(tXinyiTytjParams));
    }

    /**
     * 删除信义碳源投加参数配置
     */
//    @PreAuthorize("@ss.hasPermi('business:params:remove')")
    @Log(title = "信义碳源投加参数配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tXinyiTytjParamsService.deleteTXinyiTytjParamsByIds(ids));
    }
}
