package com.slibra.web.controller.business;

import cn.hutool.core.date.DateUtil;
import com.slibra.common.core.domain.TXinyiDaily;
import com.slibra.business.domain.TXinyiIndustry;
import com.slibra.business.domain.TXinyiNormConfig;
import com.slibra.business.mapper.TXinyiDailyMapper;
import com.slibra.business.mapper.TXinyiIndustryMapper;
import com.slibra.business.mapper.TXinyiNormConfigMapper;
import com.slibra.business.mapper.TXinyiRobotMapper;
import com.slibra.common.constant.MyConstants;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;
import java.util.List;
import java.util.Objects;

/**
 * 告警相关
 */
@RestController
@RequestMapping("/test/warning")
public class WarningController extends BaseController {


    @Autowired
    private TXinyiNormConfigMapper tXinyiNormConfigMapper;

    @Autowired
    private TXinyiRobotMapper robotMapper;

    @Autowired
    private TXinyiIndustryMapper industryMapper;

    @Autowired
    private TXinyiDailyMapper dailyMapper;

    /**
     * 处理报警规则
     * @return
     */
    @GetMapping(value = "/handle/rule")
    public AjaxResult handleWarning()
    {
        //获取配置表
        List<TXinyiNormConfig> tXinyiNormConfigs = this.tXinyiNormConfigMapper.selectTXinyiNormConfigList(null);
        if(CollectionUtils.isEmpty(tXinyiNormConfigs))
            throw new RuntimeException("未查询到配置信息");
        TXinyiNormConfig normConfig = tXinyiNormConfigs.get(0);
        this.compareData(normConfig);
        return AjaxResult.success("ok");
    }

    private void compareData(TXinyiNormConfig normConfig) {
        LocalDateTime localDateTime = LocalDateTime.now().plusMinutes(-60);
        //当前时间
        // 将 LocalDateTime 转换为 Date
        Date currentDate = Date.from(localDateTime.atZone(ZoneId.systemDefault()).toInstant());
        //获取对个格式日期字符串
        String currentDateStr = DateUtil.format(currentDate, DateUtils.YYYYMMDD_TS);
        currentDateStr = "2023/02/21";
        String currentHourStr = DateUtil.format(currentDate, DateUtils.YYYYMMDDHH_TS);
        currentHourStr = "2024/05/07 09";
        //查询工业库 日报库 机器人化验库
        List<TXinyiDaily> tXinyiDailies = this.dailyMapper.selectTXinyiDailyList(TXinyiDaily.builder().testDate(currentDateStr).build());
        List<TXinyiIndustry> tXinyiIndustries = this.industryMapper.selectTXinyiIndustryList(TXinyiIndustry.builder().testHour(currentHourStr).build());
        //获取整点的那条数据，也就是第一条
        TXinyiIndustry tXinyiIndustry = CollectionUtils.isEmpty(tXinyiIndustries) ? null : tXinyiIndustries.get(0);
        //开始核对各个指标 并打印
        if(!Objects.isNull(tXinyiIndustry)){
            //1 进水总磷超标报警
            BigDecimal jsTp = tXinyiIndustry.getJsTp();
            BigDecimal jszlSjz = normConfig.getJszlSjz();
            if(!Objects.isNull(jsTp) && !Objects.isNull(jszlSjz)){
                BigDecimal jszlSjzMax = jszlSjz.multiply(new BigDecimal(MyConstants.SCALE_VALUE));
                if(jsTp.compareTo(jszlSjz) > 0 && jsTp.compareTo(jszlSjzMax) <= 0)
                    System.out.println("进水总磷超标报警级别为 二级");
                else if (jsTp.compareTo(jszlSjzMax) > 0)
                    System.out.println("进水总磷超标报警级别为 一级");
                else
                    System.out.println("进水总磷超标报警数据正常~~~");
                System.out.println("--------------1");
            }
            //2 出水总磷超标报警
            BigDecimal csTp = tXinyiIndustry.getCsTp();
            BigDecimal cszlGkz = normConfig.getCszlGkz();
            BigDecimal cszlBzz = normConfig.getCszlBzz();
            if(!Objects.isNull(csTp) && !Objects.isNull(cszlBzz)){
                if(csTp.compareTo(cszlBzz) >= 0)
                    System.out.println("出水总磷超标报警级别为 一级");
                if(!Objects.isNull(cszlGkz)){
                    if(csTp.compareTo(cszlGkz) > 0 && csTp.compareTo(cszlBzz) <0)
                        System.out.println("出水总磷超标报警级别为 二级");
                }
                System.out.println("出水总磷超标报警数据正常~~~");
                System.out.println("--------------2");
            }
            //3 进水COD超标报警
            BigDecimal jsCod = tXinyiIndustry.getJsCod();
            BigDecimal jscodSjz = normConfig.getJscodSjz();
            if(!Objects.isNull(jsCod) && !Objects.isNull(jscodSjz)){
                BigDecimal jscodMax = jscodSjz.multiply(new BigDecimal(MyConstants.SCALE_VALUE));
                if(jsCod.compareTo(jscodSjz) > 0 && jsCod.compareTo(jscodMax) <= 0)
                    System.out.println("进水COD超标报警级别为 二级");
                else if (jsCod.compareTo(jscodMax) > 0)
                    System.out.println("进水COD超标报警级别为 一级");
                else
                    System.out.println("进水COD超标报警数据正常~~~");
                System.out.println("--------------3");
            }
            //4 出水COD超标报警
            BigDecimal csCod = tXinyiIndustry.getCsCod();
            BigDecimal cscodGkz = normConfig.getCscodGkz();
            BigDecimal cscodBzz = normConfig.getCscodBzz();
            if(!Objects.isNull(csCod) && !Objects.isNull(cscodBzz)){
                if(csCod.compareTo(cscodBzz) >= 0)
                    System.out.println("出水COD超标报警级别为 一级");
                if(!Objects.isNull(cscodGkz)){
                    if(csCod.compareTo(cscodGkz) > 0 && csCod.compareTo(cscodBzz) <0)
                        System.out.println("出水COD超标报警级别为 二级");
                }
                System.out.println("出水COD超标报警级别正常~~~");
                System.out.println("--------------4");
            }
            //5 进水总氮超标报警
            BigDecimal jsTn = tXinyiIndustry.getJsTn();
            BigDecimal jszdSjz = normConfig.getJszdSjz();
            if(!Objects.isNull(jsTn) && !Objects.isNull(jszdSjz)){
                BigDecimal jszdMax = jszdSjz.multiply(new BigDecimal(MyConstants.SCALE_VALUE));
                if(jsTn.compareTo(jszdSjz) > 0 && jsTn.compareTo(jszdMax) <= 0)
                    System.out.println("进水总氮超标报警级别为 二级");
                else if (jsTn.compareTo(jszdMax) > 0)
                    System.out.println("进水总氮超标报警级别为 一级");
                System.out.println("进水总氮超标报警数据正常~~~");
                System.out.println("--------------5");
            }
            //6 出水总氮超标报警
            BigDecimal csTn = tXinyiIndustry.getCsTn();
            BigDecimal cszzBzz = normConfig.getCszzBzz();
            if(!Objects.isNull(csTn) && !Objects.isNull(cszzBzz)){
                if(csTp.compareTo(cszzBzz) >= 0)
                    System.out.println("出水总氮超标报警级别为 一级");
                BigDecimal cszzGkz = normConfig.getCszzGkz();
                if(!Objects.isNull(cszzGkz)){
                    if(csTn.compareTo(cszzGkz) > 0 && csTn.compareTo(cszzBzz) <0)
                        System.out.println("出水总氮超标报警级别为 二级");
                }
                System.out.println("出水总氮超标报警数据正常~~~");
                System.out.println("--------------6");
            }
            //7 进水氨氮超标报警
            BigDecimal jsNh3 = tXinyiIndustry.getJsNh3();
            BigDecimal jsadSjz = normConfig.getJsadSjz();
            if(!Objects.isNull(jsNh3) && !Objects.isNull(jsadSjz)){
                BigDecimal jsadMax = jsadSjz.multiply(new BigDecimal(MyConstants.SCALE_VALUE));
                if(jsNh3.compareTo(jsadSjz) > 0 && jsNh3.compareTo(jsadMax) <= 0)
                    System.out.println("进水氨氮超标报警级别为 二级");
                else if (jsNh3.compareTo(jsadMax) > 0)
                    System.out.println("进水氨氮超标报警级别为 一级");
                System.out.println("进水氨氮超标报警数据正常~~~");
                System.out.println("--------------7");
            }
            //8 出水氨氮超标报警
            BigDecimal csNh3 = tXinyiIndustry.getCsNh3();
            BigDecimal csadBzz = normConfig.getCsadBzz();
            if(!Objects.isNull(csNh3) && !Objects.isNull(csadBzz)){
                if(csNh3.compareTo(csadBzz) >= 0)
                    System.out.println("出水氨氮超标报警级别为 一级");
                BigDecimal csadGkz = normConfig.getCsadGkz();
                if(!Objects.isNull(csadGkz)){
                    if(csNh3.compareTo(csadGkz) > 0 && csNh3.compareTo(csadBzz) <0)
                        System.out.println("出水氨氮超标报警级别为 二级");
                }
                System.out.println("出水氨氮超标报警数据正常~~~");
                System.out.println("--------------8");
            }
            //9 进水SS超标报警
            BigDecimal jsSS = tXinyiIndustry.getJsSs();
            BigDecimal jsSSSjz = normConfig.getJsssSjz();
            if(!Objects.isNull(jsSS) && !Objects.isNull(jsSSSjz)){
                BigDecimal jsssMax = jsSSSjz.multiply(new BigDecimal(MyConstants.SCALE_VALUE));
                if(jsSS.compareTo(jsSSSjz) > 0 && jsSS.compareTo(jsssMax) <= 0)
                    System.out.println("进水SS超标报警级别为 二级");
                else if (jsSS.compareTo(jsssMax) > 0)
                    System.out.println("进水SS超标报警级别为 一级");
                System.out.println("进水SS超标报警数据正常~~~");
                System.out.println("--------------9");
            }
            //10 出水SS超标报警
            BigDecimal csSS = tXinyiIndustry.getCsSs();
            BigDecimal csSSBzz = normConfig.getCsssBzz();
            if(!Objects.isNull(csSS) && !Objects.isNull(csSSBzz)){
                if(csSS.compareTo(csSSBzz) >= 0)
                    System.out.println("出水SS超标报警级别为 一级");
                BigDecimal csSSGkz = normConfig.getCsssGkz();
                if(!Objects.isNull(csSSGkz)){
                    if(csSS.compareTo(csSSGkz) > 0 && csSS.compareTo(csSSBzz) <0)
                        System.out.println("出水SS超标报警级别为 二级");
                }
                System.out.println("出水SS超标报警数据正常~~~");
                System.out.println("--------------10");
            }
            //12 厌氧区停留时间告警  厌氧区停留时间=2*[V_yan]/[Q_in]=[HRT_yan]he
            BigDecimal yyqyxcr = normConfig.getYYQYXCR();
            BigDecimal jsSlq = tXinyiIndustry.getJsSlq();
            BigDecimal yyytlsjGkz = normConfig.getYyqtlsjGkz();
            if(!Objects.isNull(jsSlq) && !Objects.isNull(yyqyxcr) && !Objects.isNull(yyytlsjGkz)){
                BigDecimal yyHrt = new BigDecimal("2").multiply(yyqyxcr).divide(jsSlq, 4, RoundingMode.HALF_UP);
                if(yyHrt.compareTo(yyytlsjGkz) < 0)
                    System.out.println("厌氧区停留时间报警级别为 一级");
                BigDecimal yyqtlsjSjz = normConfig.getYyqtlsjSjz();
                if(!Objects.isNull(yyqtlsjSjz)){
                    if(yyHrt.compareTo(yyytlsjGkz) >= 0 && yyHrt.compareTo(yyqtlsjSjz) < 0)
                        System.out.println("厌氧区停留时间报警级别为 二级");
                }
                System.out.println("厌氧区停留时间报警数据正常~~~");
                System.out.println("--------------12");
            }
            //13 内回流比报警
            BigDecimal nhlbSjz = normConfig.getNhlbSjz();
            BigDecimal nhlbnkSxz = normConfig.getNhlbnkSxz();
            BigDecimal nhlbqdsl = normConfig.getNHLBQDSL();
            BigDecimal nhlbdsjll = normConfig.getNHLBDSJLL();
            BigDecimal nhlbgzxl = normConfig.getNHLBGZXL();
            if(!Objects.isNull(jsSlq) && !Objects.isNull(nhlbSjz) && !Objects.isNull(nhlbnkSxz) && !Objects.isNull(nhlbqdsl)
                    && !Objects.isNull(nhlbdsjll) && !Objects.isNull(nhlbgzxl)){
                BigDecimal divide = nhlbqdsl.multiply(nhlbdsjll).multiply(nhlbgzxl).divide(jsSlq, 4, RoundingMode.HALF_UP);
                if(divide.compareTo(nhlbnkSxz) > 0 && divide.compareTo(nhlbSjz) <=0)
                    System.out.println("内回流比报警级别为 二级");
                if(divide.compareTo(nhlbSjz) > 0)
                    System.out.println("内回流比报警级别为 一级");
                BigDecimal nhlbnkXxz = normConfig.getNhlbnkXxz();
                if(!Objects.isNull(nhlbnkXxz) && divide.compareTo(nhlbnkXxz) < 0)
                    System.out.println("内回流比报警级别为 一级");
                System.out.println("内回流比报警数据正常~~~");
                System.out.println("--------------13");
            }
            //14 外回流比报警
            BigDecimal whlbqdsl = normConfig.getWHLBQDSL();
            BigDecimal whlbdsjll = normConfig.getWHLBDSJLL();
            BigDecimal whlbgzxl = normConfig.getWHLBGZXL();
            BigDecimal whlbnkXxz = normConfig.getWhlbnkXxz();
            BigDecimal whlbSjz = normConfig.getWhlbSjz();
            if(!Objects.isNull(whlbqdsl) && !Objects.isNull(whlbdsjll) && !Objects.isNull(whlbgzxl)){
                BigDecimal divide = whlbqdsl.multiply(whlbdsjll).multiply(whlbgzxl).divide(jsSlq, 4, RoundingMode.HALF_UP);
                if(!Objects.isNull(whlbnkXxz) && divide.compareTo(whlbnkXxz) < 0)
                    System.out.println("外回流比报警级别为 一级");
                if(!Objects.isNull(whlbSjz) && divide.compareTo(whlbSjz) > 0)
                    System.out.println("外回流比报警级别为 一级");
                System.out.println("外回流比报警数据正常~~~");
                System.out.println("--------------14");
            }
            //25.1 好氧池溶解氧报警（一池）
            BigDecimal shcHyOneDo = tXinyiIndustry.getOneHymdDo();
            BigDecimal hycrjysjzSxz = normConfig.getHycrjysjzSxz();
            BigDecimal hycrjyNkz = normConfig.getHycrjyNkz();
            if(!Objects.isNull(shcHyOneDo) && !Objects.isNull(hycrjysjzSxz)){
                if(shcHyOneDo.compareTo(hycrjysjzSxz) > 0)
                    System.out.println("好氧池溶解氧报警（一池）报警别为 一级");
                if(!Objects.isNull(hycrjyNkz) && shcHyOneDo.compareTo(hycrjyNkz) > 0 && shcHyOneDo.compareTo(hycrjysjzSxz) <= 0)
                    System.out.println("好氧池溶解氧报警（一池）报警别为 二级");
                System.out.println("好氧池溶解氧报警（一池）报警级别为数据正常~~~");
                System.out.println("--------------25.1");
            }
            //25.2 好氧池溶解氧报警（二池）
            BigDecimal shcHyTwoDo = tXinyiIndustry.getTwoHymdDo();
            if(!Objects.isNull(shcHyTwoDo) && !Objects.isNull(hycrjysjzSxz)){
                if(shcHyTwoDo.compareTo(hycrjysjzSxz) > 0)
                    System.out.println("好氧池溶解氧报警（二池）报警别为 一级");
                if(!Objects.isNull(hycrjyNkz) && shcHyTwoDo.compareTo(hycrjyNkz) > 0 && shcHyTwoDo.compareTo(hycrjysjzSxz) <= 0)
                    System.out.println("好氧池溶解氧报警（二池）报警别为 二级");
                System.out.println("好氧池溶解氧报警（二池）报警级别为数据正常~~~");
                System.out.println("--------------25.2");
            }
            //26 生化池气水比报警  生化池气水比=[g:w]m³/m³=[n_gu]*[Q_gu]:[Q_in]m³/m³
            BigDecimal gfjgzts = normConfig.getGFJGZTS();
            BigDecimal gfjckll = normConfig.getGFJCKLL();
            BigDecimal shcqbSjz = normConfig.getShcqbSjz();
            if(!Objects.isNull(gfjgzts) && !Objects.isNull(gfjckll) && !Objects.isNull(shcqbSjz) && !Objects.isNull(jsSlq)){
                BigDecimal qsb = gfjgzts.multiply(gfjckll).divide(jsSlq, 4, RoundingMode.HALF_UP);
                BigDecimal shcqbNkz = normConfig.getShcqbNkz();
                if(qsb.compareTo(shcqbSjz) > 0)
                    System.out.println("生化池气水比报警别为 一级");
                if(!Objects.isNull(shcqbNkz) && qsb.compareTo(shcqbNkz) > 0 && qsb.compareTo(shcqbSjz) <= 0)
                    System.out.println("生化池气水比报警别为 二级");
                System.out.println("生化池气水比报警级别为数据正常~~~");
                System.out.println("--------------26");
            }
            //29 二沉池表面负荷报警 二沉池表面负荷=[e]=[Q_in]/([n_er]*[A_er])m³/(m²·h)
            BigDecimal eccsl = normConfig.getECCSL();
            BigDecimal eccsjzzj = normConfig.getECCSJZZJ();
            BigDecimal eccbmfhznkzSxz = normConfig.getEccbmfhznkzSxz();
            if(!Objects.isNull(eccbmfhznkzSxz) && !Objects.isNull(jsSlq) && !Objects.isNull(eccsl) && !Objects.isNull(eccsjzzj)){
                BigDecimal eccArea = new BigDecimal(Math.PI).multiply(eccsjzzj).multiply(eccsjzzj).divide(new BigDecimal("4"), 4, RoundingMode.HALF_UP);
                BigDecimal multiply = jsSlq.divide(eccsl, 4, RoundingMode.HALF_UP).divide(new BigDecimal("24").multiply(eccArea), 4, RoundingMode.HALF_UP);
                if(multiply.compareTo(eccbmfhznkzSxz) > 0)
                    System.out.println("二沉池表面负荷报警别为 一级");
                System.out.println("二沉池表面负荷报警级别为数据正常~~~");
                System.out.println("--------------29");
            }
            //31 深度处理反冲洗水量比例报警 深度处理反冲洗水量=[j]=[Q_fan]*[n_fan]*[η_fan]/[Q_in]*100%
            BigDecimal fcxbsjll = normConfig.getFCXBSJLL();
            BigDecimal fclbsl = normConfig.getFCLBSL();
            BigDecimal fcxbgzxl = normConfig.getFCXBGZXL();
            if(!Objects.isNull(jsSlq) && !Objects.isNull(fcxbsjll) && !Objects.isNull(fclbsl) && !Objects.isNull(fcxbgzxl)){
                //如果是日报 乘以24， 工业库乘以1   乘以100是·单位是百分之多少
                BigDecimal divide = fcxbsjll.multiply(fclbsl).multiply(fcxbgzxl).divide(jsSlq, 4, RoundingMode.HALF_UP).multiply(new BigDecimal("1").multiply(new BigDecimal("100")));
                BigDecimal fcxslblsjzXxz = normConfig.getFcxslblsjzXxz();
                if(!Objects.isNull(fcxslblsjzXxz) && divide.compareTo(fcxslblsjzXxz) < 0)
                    System.out.println("深度处理反冲洗水量比例报警别为 一级");
                BigDecimal fcxslblsjzSxz = normConfig.getFcxslblsjzSxz();
                if(!Objects.isNull(fcxslblsjzSxz) && divide.compareTo(fcxslblsjzSxz) > 0)
                    System.out.println("深度处理反冲洗水量比例报警别为 一级");
                System.out.println("深度处理反冲洗水量比例报警级别为数据正常~~~");
                System.out.println("--------------31");
            }
            //32 深度处理峰值过滤速度报警 深度处理峰值过滤速度=[q]=[Q_in]/[n_sha]/[A_sha]m/h
            BigDecimal hxslcsl = normConfig.getHXSLCSL();
            BigDecimal hxslcglmj = normConfig.getHXSLCGLMJ();
            BigDecimal sdclfzglsdSjz = normConfig.getSdclfzglsdSjz();
            if(!Objects.isNull(hxslcsl) && !Objects.isNull(hxslcglmj) && !Objects.isNull(jsSlq) && !Objects.isNull(sdclfzglsdSjz)){
                //除以24是单位转换
                BigDecimal divide = jsSlq.divide(hxslcsl, 4, RoundingMode.HALF_UP).divide(hxslcglmj, 4, RoundingMode.HALF_UP).divide(new BigDecimal("24"), 4, RoundingMode.HALF_UP);
                if(divide.compareTo(sdclfzglsdSjz) >0 )
                    System.out.println("深度处理峰值过滤速度报警别为 一级");
                System.out.println("深度处理峰值过滤速度报警级别为数据正常~~~");
                System.out.println("--------------32");
            }

        }

        System.out.println("--------------------------下面的是日报相关的报警--------------------------");
        TXinyiDaily tXinyiDaily = CollectionUtils.isEmpty(tXinyiDailies) ? null : tXinyiDailies.get(0);

        //日报相关的
        if(!Objects.isNull(tXinyiDaily)){
            //1 进水总磷超标报警
            BigDecimal jsTp = tXinyiDaily.getJsTp();
            BigDecimal jszlSjz = normConfig.getJszlSjz();
            if(!Objects.isNull(jsTp) && !Objects.isNull(jszlSjz)){
                BigDecimal jszlSjzMax = jszlSjz.multiply(new BigDecimal(MyConstants.SCALE_VALUE));
                if(jsTp.compareTo(jszlSjz) > 0 && jsTp.compareTo(jszlSjzMax) <= 0)
                    System.out.println("进水总磷超标报警级别为 二级");
                else if (jsTp.compareTo(jszlSjzMax) > 0)
                    System.out.println("进水总磷超标报警级别为 一级");
                else
                    System.out.println("进水总磷超标报警数据正常~~~");
                System.out.println("--------------1");
            }
            //2 出水总磷超标报警
            BigDecimal csTp = tXinyiDaily.getCsTp();
            BigDecimal cszlGkz = normConfig.getCszlGkz();
            BigDecimal cszlBzz = normConfig.getCszlBzz();
            if(!Objects.isNull(csTp) && !Objects.isNull(cszlBzz)){
                if(csTp.compareTo(cszlBzz) >= 0)
                    System.out.println("出水总磷超标报警级别为 一级");
                if(!Objects.isNull(cszlGkz)){
                    if(csTp.compareTo(cszlGkz) > 0 && csTp.compareTo(cszlBzz) <0)
                        System.out.println("出水总磷超标报警级别为 二级");
                }
                System.out.println("出水总磷超标报警数据正常~~~");
                System.out.println("--------------2");
            }
            //3 进水COD超标报警
            BigDecimal jsCod = tXinyiDaily.getJsCod();
            BigDecimal jscodSjz = normConfig.getJscodSjz();
            if(!Objects.isNull(jsCod) && !Objects.isNull(jscodSjz)){
                BigDecimal jscodMax = jscodSjz.multiply(new BigDecimal(MyConstants.SCALE_VALUE));
                if(jsCod.compareTo(jscodSjz) > 0 && jsCod.compareTo(jscodMax) <= 0)
                    System.out.println("进水COD超标报警级别为 二级");
                else if (jsCod.compareTo(jscodMax) > 0)
                    System.out.println("进水COD超标报警级别为 一级");
                else
                    System.out.println("进水COD超标报警数据正常~~~");
                System.out.println("--------------3");
            }
            //4 出水COD超标报警
            BigDecimal csCod = tXinyiDaily.getCsCod();
            BigDecimal cscodGkz = normConfig.getCscodGkz();
            BigDecimal cscodBzz = normConfig.getCscodBzz();
            if(!Objects.isNull(csCod) && !Objects.isNull(cscodBzz)){
                if(csCod.compareTo(cscodBzz) >= 0)
                    System.out.println("出水COD超标报警级别为 一级");
                if(!Objects.isNull(cscodGkz)){
                    if(csCod.compareTo(cscodGkz) > 0 && csCod.compareTo(cscodBzz) <0)
                        System.out.println("出水COD超标报警级别为 二级");
                }
                System.out.println("出水COD超标报警级别正常~~~");
                System.out.println("--------------4");
            }
            //5 进水总氮超标报警
            BigDecimal jsTn = tXinyiDaily.getJsTn();
            BigDecimal jszdSjz = normConfig.getJszdSjz();
            if(!Objects.isNull(jsTn) && !Objects.isNull(jszdSjz)){
                BigDecimal jszdMax = jszdSjz.multiply(new BigDecimal(MyConstants.SCALE_VALUE));
                if(jsTn.compareTo(jszdSjz) > 0 && jsTn.compareTo(jszdMax) <= 0)
                    System.out.println("进水总氮超标报警级别为 二级");
                else if (jsTn.compareTo(jszdMax) > 0)
                    System.out.println("进水总氮超标报警级别为 一级");
                System.out.println("进水总氮超标报警数据正常~~~");
                System.out.println("--------------5");
            }
            //6 出水总氮超标报警
            BigDecimal csTn = tXinyiDaily.getCsTn();
            BigDecimal cszzBzz = normConfig.getCszzBzz();
            if(!Objects.isNull(csTn) && !Objects.isNull(cszzBzz)){
                if(csTp.compareTo(cszzBzz) >= 0)
                    System.out.println("出水总氮超标报警级别为 一级");
                BigDecimal cszzGkz = normConfig.getCszzGkz();
                if(!Objects.isNull(cszzGkz)){
                    if(csTn.compareTo(cszzGkz) > 0 && csTn.compareTo(cszzBzz) <0)
                        System.out.println("出水总氮超标报警级别为 二级");
                }
                System.out.println("出水总氮超标报警数据正常~~~");
                System.out.println("--------------6");
            }
            //7 进水氨氮超标报警
            BigDecimal jsNh3 = tXinyiDaily.getJsNh3();
            BigDecimal jsadSjz = normConfig.getJsadSjz();
            if(!Objects.isNull(jsNh3) && !Objects.isNull(jsadSjz)){
                BigDecimal jsadMax = jsadSjz.multiply(new BigDecimal(MyConstants.SCALE_VALUE));
                if(jsNh3.compareTo(jsadSjz) > 0 && jsNh3.compareTo(jsadMax) <= 0)
                    System.out.println("进水氨氮超标报警级别为 二级");
                else if (jsNh3.compareTo(jsadMax) > 0)
                    System.out.println("进水氨氮超标报警级别为 一级");
                System.out.println("进水氨氮超标报警数据正常~~~");
                System.out.println("--------------7");
            }
            //8 出水氨氮超标报警
            BigDecimal csNh3 = tXinyiDaily.getCsNh3();
            BigDecimal csadBzz = normConfig.getCsadBzz();
            if(!Objects.isNull(csNh3) && !Objects.isNull(csadBzz)){
                if(csNh3.compareTo(csadBzz) >= 0)
                    System.out.println("出水氨氮超标报警级别为 一级");
                BigDecimal csadGkz = normConfig.getCsadGkz();
                if(!Objects.isNull(csadGkz)){
                    if(csNh3.compareTo(csadGkz) > 0 && csNh3.compareTo(csadBzz) <0)
                        System.out.println("出水氨氮超标报警级别为 二级");
                }
                System.out.println("出水氨氮超标报警数据正常~~~");
                System.out.println("--------------8");
            }
            //9 进水SS超标报警
            BigDecimal jsSS = tXinyiDaily.getJsSs();
            BigDecimal jsSSSjz = normConfig.getJsssSjz();
            if(!Objects.isNull(jsSS) && !Objects.isNull(jsSSSjz)){
                BigDecimal jsssMax = jsSSSjz.multiply(new BigDecimal(MyConstants.SCALE_VALUE));
                if(jsSS.compareTo(jsSSSjz) > 0 && jsSS.compareTo(jsssMax) <= 0)
                    System.out.println("进水SS超标报警级别为 二级");
                else if (jsSS.compareTo(jsssMax) > 0)
                    System.out.println("进水SS超标报警级别为 一级");
                System.out.println("进水SS超标报警数据正常~~~");
                System.out.println("--------------9");
            }
            //10 出水SS超标报警
            BigDecimal csSS = tXinyiDaily.getCsSs();
            BigDecimal csSSBzz = normConfig.getCsssBzz();
            if(!Objects.isNull(csSS) && !Objects.isNull(csSSBzz)){
                if(csSS.compareTo(csSSBzz) >= 0)
                    System.out.println("出水SS超标报警级别为 一级");
                BigDecimal csSSGkz = normConfig.getCsssGkz();
                if(!Objects.isNull(csSSGkz)){
                    if(csSS.compareTo(csSSGkz) > 0 && csSS.compareTo(csSSBzz) <0)
                        System.out.println("出水SS超标报警级别为 二级");
                }
                System.out.println("出水SS超标报警数据正常~~~");
                System.out.println("--------------10");
            }

            //11 出水大肠杆菌
            BigDecimal csDcgj = tXinyiDaily.getCsDcgj();
            BigDecimal csdcgjBzz = normConfig.getCsdcgjBzz();
            if(!Objects.isNull(csDcgj) && !Objects.isNull(csdcgjBzz)){
                if(csDcgj.compareTo(csdcgjBzz) >= 0)
                    System.out.println("出水大肠杆菌超标报警级别为 一级");
                System.out.println("出水大肠杆菌超标报警数据正常~~~");
                System.out.println("--------------11");
            }
            //12 厌氧区停留时间
            BigDecimal yyHrt = tXinyiDaily.getYyHrt();
            BigDecimal yyytlsjGkz = normConfig.getYyqtlsjGkz();
            if(!Objects.isNull(yyHrt) && !Objects.isNull(yyytlsjGkz)){
                if(yyHrt.compareTo(yyytlsjGkz) < 0)
                    System.out.println("厌氧区停留时间报警级别为 一级");
                BigDecimal yyqtlsjSjz = normConfig.getYyqtlsjSjz();
                if(!Objects.isNull(yyqtlsjSjz)){
                    if(yyHrt.compareTo(yyytlsjGkz) >= 0 && yyHrt.compareTo(yyqtlsjSjz) < 0)
                        System.out.println("厌氧区停留时间报警级别为 二级");
                }
                System.out.println("厌氧区停留时间报警数据正常~~~");
                System.out.println("--------------12");
            }
            //13 内回流比报警
//            BigDecimal nhlR = tXinyiDaily.getNhlR();
            BigDecimal nhlbSjz = normConfig.getNhlbSjz();
            BigDecimal nhlbnkSxz = normConfig.getNhlbnkSxz();
            BigDecimal nhlbqdsl = normConfig.getNHLBQDSL();
            BigDecimal nhlbdsjll = normConfig.getNHLBDSJLL();
            BigDecimal nhlbgzxl = normConfig.getNHLBGZXL();
            BigDecimal jsl = tXinyiDaily.getJSL();
            if(!Objects.isNull(jsl) && !Objects.isNull(nhlbSjz) && !Objects.isNull(nhlbnkSxz) && !Objects.isNull(nhlbqdsl)
                && !Objects.isNull(nhlbdsjll) && !Objects.isNull(nhlbgzxl)){
                BigDecimal divide = nhlbqdsl.multiply(nhlbdsjll).multiply(nhlbgzxl).divide(jsl, 4, RoundingMode.HALF_UP);
                if(divide.compareTo(nhlbnkSxz) > 0 && divide.compareTo(nhlbSjz) <=0)
                    System.out.println("内回流比报警级别为 二级");
                if(divide.compareTo(nhlbSjz) > 0)
                    System.out.println("内回流比报警级别为 一级");
                BigDecimal nhlbnkXxz = normConfig.getNhlbnkXxz();
                if(!Objects.isNull(nhlbnkXxz) && divide.compareTo(nhlbnkXxz) < 0)
                    System.out.println("内回流比报警级别为 一级");
                System.out.println("内回流比报警数据正常~~~");
                System.out.println("--------------13");
            }
            //14 外回流比报警
//            BigDecimal whlR = tXinyiDaily.getWhlR();
            BigDecimal whlbqdsl = normConfig.getWHLBQDSL();
            BigDecimal whlbdsjll = normConfig.getWHLBDSJLL();
            BigDecimal whlbgzxl = normConfig.getWHLBGZXL();
            BigDecimal whlbnkXxz = normConfig.getWhlbnkXxz();
            BigDecimal whlbSjz = normConfig.getWhlbSjz();
            if(!Objects.isNull(whlbqdsl) && !Objects.isNull(whlbdsjll) && !Objects.isNull(whlbgzxl)){
                BigDecimal divide = whlbqdsl.multiply(whlbdsjll).multiply(whlbgzxl).divide(jsl, 4, RoundingMode.HALF_UP);
                if(!Objects.isNull(whlbnkXxz) && divide.compareTo(whlbnkXxz) < 0)
                    System.out.println("外回流比报警级别为 一级");
                if(!Objects.isNull(whlbSjz) && divide.compareTo(whlbSjz) > 0)
                    System.out.println("外回流比报警级别为 一级");
                System.out.println("外回流比报警数据正常~~~");
                System.out.println("--------------14");
            }
            //15 污泥负荷报警级别
            BigDecimal fm = tXinyiDaily.getFM();
            BigDecimal wnfhSjz = normConfig.getWnfhSjz();
            if(!Objects.isNull(fm) && !Objects.isNull(wnfhSjz)){
                if(fm.compareTo(wnfhSjz) >0 )
                    System.out.println("污泥负荷报警级别为 一级");
                BigDecimal wnfhnkSxz = normConfig.getWnfhnkSxz();
                if(!Objects.isNull(wnfhnkSxz)){
                    if(fm.compareTo(wnfhnkSxz) > 0 && fm.compareTo(wnfhSjz) <= 0)
                        System.out.println("污泥负荷报警级别为 二级");
                }
                System.out.println("污泥负荷报警数据正常~~~");
                System.out.println("--------------15");
            }
            //16 污泥龄报警
            BigDecimal srt = tXinyiDaily.getSRT();
            BigDecimal wnlSjz = normConfig.getWnlSjz();
            if(!Objects.isNull(srt) && !Objects.isNull(wnlSjz)){
                if(srt.compareTo(wnlSjz) < 0)
                    System.out.println("污泥龄报警级别为 一级");
                BigDecimal wnlNkz = normConfig.getWnlNkz();
                if(!Objects.isNull(wnlNkz)){
                    if(srt.compareTo(wnlNkz) < 0 && srt.compareTo(wnlSjz) >= 0)
                        System.out.println("污泥龄荷报警级别为 二级");
                }
                System.out.println("污泥龄报警数据正常~~~");
                System.out.println("--------------16");
            }
            //17 产泥率报警
            BigDecimal cnl = tXinyiDaily.getCNL();
            BigDecimal cnlSjz = normConfig.getCnlSjz();
            if(!Objects.isNull(cnl) && !Objects.isNull(cnlSjz)){
                if(cnl.compareTo(cnlSjz) < 0)
                    System.out.println("产泥率报警级别为 一级");
            }
            BigDecimal cnlnkzsx = normConfig.getCNLNKZSX();
            if(!Objects.isNull(cnl) && !Objects.isNull(cnlnkzsx)){
                if(cnl.compareTo(cnlnkzsx) > 0)
                    System.out.println("产泥率报警级别为 一级");
            }
            BigDecimal cnlnkzxx = normConfig.getCNLNKZXX();
            if(!Objects.isNull(cnl) && !Objects.isNull(cnlSjz) && !Objects.isNull(cnlnkzxx)){
                if(cnl.compareTo(cnlSjz) >= 0 && cnl.compareTo(cnlnkzxx) < 0)
                    System.out.println("产泥率报警级别为 二级");
            }
            System.out.println("产泥率报警数据正常~~~");
            System.out.println("--------------17");

            //18.1 挥发性污泥浓度占比（一池）
            //需要根据 MLVSS MLSS计算   [a]=[MLVSS]/[MLSS]
            BigDecimal shcHyOneMlss = tXinyiDaily.getShcHyOneMlss();
            BigDecimal shcHyOneMlvss = tXinyiDaily.getShcHyOneMlvss();
            BigDecimal hfxwnndzbGkz = normConfig.getHfxwnndzbGkz();
            if(!Objects.isNull(shcHyOneMlss) && !Objects.isNull(shcHyOneMlvss) && !Objects.isNull(hfxwnndzbGkz)){
                BigDecimal divide = shcHyOneMlvss.divide(shcHyOneMlss, 4, RoundingMode.HALF_UP);
                if(divide.compareTo(hfxwnndzbGkz) < 0)
                    System.out.println("挥发性污泥浓度占比（一池）报警级别为 一级");
                BigDecimal hfxwnndzbSjz = normConfig.getHfxwnndzbSjz();
                if(!Objects.isNull(hfxwnndzbSjz)){
                    if(divide.compareTo(hfxwnndzbSjz) < 0 && divide.compareTo(hfxwnndzbGkz) >= 0)
                        System.out.println("挥发性污泥浓度占比（一池）报警级别为 二级");
                }
                System.out.println("挥发性污泥浓度占比（一池）报警数据正常~~~");
                System.out.println("--------------18.1");
            }

            //18.2 挥发性污泥浓度占比（二池）
            //需要根据 MLVSS MLSS计算   [a]=[MLVSS]/[MLSS]
            BigDecimal shcHyTwoMlss = tXinyiDaily.getShcHyTwoMlss();
            BigDecimal shcHyTwoMlvss = tXinyiDaily.getShcHyTwoMlvss();
            if(!Objects.isNull(shcHyTwoMlss) && !Objects.isNull(shcHyTwoMlvss) && !Objects.isNull(hfxwnndzbGkz)){
                BigDecimal divide = shcHyTwoMlvss.divide(shcHyTwoMlss, 4, RoundingMode.HALF_UP);
                if(divide.compareTo(hfxwnndzbGkz) < 0)
                    System.out.println("挥发性污泥浓度占比（二池）报警级别为 一级");
                BigDecimal hfxwnndzbSjz = normConfig.getHfxwnndzbSjz();
                if(!Objects.isNull(hfxwnndzbSjz)){
                    if(divide.compareTo(hfxwnndzbSjz) < 0 && divide.compareTo(hfxwnndzbGkz) >= 0)
                        System.out.println("挥发性污泥浓度占比（二池）报警级别为 二级");
                }
                System.out.println("挥发性污泥浓度占比（二池）报警数据正常~~~");
                System.out.println("--------------18.2");
            }

            //19 污泥浓度报警
            //现获取温度，判断是冬季还是夏季
            BigDecimal jsSw = tXinyiDaily.getJsSw();
            BigDecimal xjwnndXxz = normConfig.getXjwnndXxz();
            BigDecimal xjwnndSxz = normConfig.getXjwnndSxz();
            BigDecimal djwnndXxz = normConfig.getDjwnndXxz();
            BigDecimal djwnndSxz = normConfig.getDjwnndSxz();
            if(!Objects.isNull(jsSw)){
                //一池
                if(jsSw.compareTo(new BigDecimal(MyConstants.TEMPERATURE_VALUE)) > 0){//按夏季计算
                    if(!Objects.isNull(xjwnndXxz)){
                        if(!Objects.isNull(shcHyOneMlss) && shcHyOneMlss.compareTo(xjwnndXxz) < 0)
                            System.out.println("污泥浓度（一池）报警级别为 一级");
                        if(!Objects.isNull(shcHyTwoMlss) && shcHyTwoMlss.compareTo(xjwnndXxz) < 0)
                            System.out.println("污泥浓度（二池）报警级别为 一级");
                    }
                    if(!Objects.isNull(xjwnndSxz)){
                        if(!Objects.isNull(shcHyOneMlss) && shcHyOneMlss.compareTo(xjwnndSxz) > 0)
                            System.out.println("污泥浓度（一池）报警级别为 一级");
                        if(!Objects.isNull(shcHyTwoMlss) && shcHyTwoMlss.compareTo(xjwnndSxz) > 0)
                            System.out.println("污泥浓度（二池）报警级别为 一级");
                    }
                }else{//按冬季计算
                    if(!Objects.isNull(djwnndXxz)){
                        if(!Objects.isNull(shcHyOneMlss) && shcHyOneMlss.compareTo(djwnndXxz) < 0)
                            System.out.println("污泥浓度（一池）报警级别为 一级");
                        if(!Objects.isNull(shcHyTwoMlss) && shcHyTwoMlss.compareTo(djwnndXxz) < 0)
                            System.out.println("污泥浓度（二池）报警级别为 一级");
                    }
                    if(!Objects.isNull(djwnndSxz)){
                        if(!Objects.isNull(shcHyOneMlss) && shcHyOneMlss.compareTo(djwnndSxz) > 0)
                            System.out.println("污泥浓度（一池）报警级别为 一级");
                        if(!Objects.isNull(shcHyTwoMlss) && shcHyTwoMlss.compareTo(djwnndSxz) > 0)
                            System.out.println("污泥浓度（二池）报警级别为 一级");
                    }
                }
            }

            //20 进水碳氮比报警  进水碳氮比=[b]=[BOD_in]/[TN_in]
            BigDecimal jsBod5 = tXinyiDaily.getJsBod5();
            if(!Objects.isNull(jsBod5) && !Objects.isNull(jsTn)){
                BigDecimal divide = jsBod5.divide(jsTn, 4, RoundingMode.HALF_UP);
                BigDecimal jstdbnkzXxz = normConfig.getJstdbnkzXxz();
                if(!Objects.isNull(jstdbnkzXxz) && divide.compareTo(jstdbnkzXxz) < 0)
                    System.out.println("进水碳氮比报警级别为 一级");
                BigDecimal jstdbnkzSxz = normConfig.getJstdbnkzSxz();
                BigDecimal cstdbSjz = normConfig.getCstdbSjz();
                if(!Objects.isNull(jstdbnkzSxz) && !Objects.isNull(cstdbSjz) && divide.compareTo(jstdbnkzSxz) >0 && divide.compareTo(cstdbSjz) <= 0)
                    System.out.println("进水碳氮比报警级别为 二级");
                System.out.println("进水碳氮比报警级别为数据正常~~~");
                System.out.println("--------------20");
            }

            //21 进水碳磷比报警 进水碳磷比=[c]=[BOD_in]/[TP_in]
            if(!Objects.isNull(jsBod5) && !Objects.isNull(jsTp)){
                BigDecimal divide = jsBod5.divide(jsTp, 4, RoundingMode.HALF_UP);
                BigDecimal jstlbNkz = normConfig.getJstlbNkz();
                if(!Objects.isNull(jstlbNkz)){
                    if(divide.compareTo(jstlbNkz) < 0)
                        System.out.println("进水碳磷比报警级别为 一级");
                    BigDecimal jstlbSjz = normConfig.getJstlbSjz();
                    if(!Objects.isNull(jstlbSjz) && divide.compareTo(jstlbNkz) >= 0 && divide.compareTo(jstlbSjz) < 0)
                        System.out.println("进水碳磷比报警级别为 二级");
                    System.out.println("进水碳磷比报警级别为数据正常~~~");
                    System.out.println("--------------21");
                }

            }

            //22 进水BOD与COD比值报警   进水BOD与COD比值数据=[d]=[BOD_in]/[COD_in]
            if(!Objects.isNull(jsBod5) && !Objects.isNull(jsCod)){
                BigDecimal jsbodycodbzSzj = normConfig.getJsbodycodbzSzj();
                BigDecimal divide = jsBod5.divide(jsCod, 4, RoundingMode.HALF_UP);
                if(!Objects.isNull(jsbodycodbzSzj) && divide.compareTo(jsbodycodbzSzj) < 0)
                    System.out.println("进水BOD与COD比值报警别为 一级");
                System.out.println("进水BOD与COD比值报警级别为数据正常~~~");
                System.out.println("--------------22");
            }

            //23.1 厌氧池溶解氧报警（一池）
            BigDecimal shcYyOneDo = tXinyiDaily.getShcYyOneDo();
            BigDecimal yycyjysjzSxz = normConfig.getYycyjysjzSxz();
            BigDecimal yycyjyNkz = normConfig.getYycyjyNkz();
            if(!Objects.isNull(shcYyOneDo) && !Objects.isNull(yycyjysjzSxz)){
                if(shcYyOneDo.compareTo(yycyjysjzSxz) > 0)
                    System.out.println("厌氧池溶解氧报警（一池）报警别为 一级");
                if(!Objects.isNull(yycyjyNkz) && shcYyOneDo.compareTo(yycyjyNkz) > 0 && shcYyOneDo.compareTo(yycyjysjzSxz) <= 0)
                    System.out.println("厌氧池溶解氧报警（一池）报警别为 二级");
                System.out.println("厌氧池溶解氧报警（一池）报警级别为数据正常~~~");
                System.out.println("--------------23.1");
            }

            //23.2 厌氧池溶解氧报警（二池）
            BigDecimal shcYyTwoDo = tXinyiDaily.getShcYyTwoDo();
            if(!Objects.isNull(shcYyTwoDo) && !Objects.isNull(yycyjysjzSxz)){
                if(shcYyTwoDo.compareTo(yycyjysjzSxz) > 0)
                    System.out.println("厌氧池溶解氧报警（二池）报警别为 一级");
                if(!Objects.isNull(yycyjyNkz) && shcYyTwoDo.compareTo(yycyjyNkz) > 0 && shcYyTwoDo.compareTo(yycyjysjzSxz) <= 0)
                    System.out.println("厌氧池溶解氧报警（二池）报警别为 二级");
                System.out.println("厌氧池溶解氧报警（二池）报警级别为数据正常~~~");
                System.out.println("--------------23.2");
            }

            //24 缺氧池溶解氧报警（一池）
            BigDecimal shcQyOneDo = tXinyiDaily.getShcQyOneDo();
            BigDecimal qycrjysjzSxz = normConfig.getQycrjysjzSxz();
            BigDecimal qycrjyNkz = normConfig.getQycrjyNkz();
            if(!Objects.isNull(shcQyOneDo) && !Objects.isNull(qycrjysjzSxz)){
                if(shcQyOneDo.compareTo(qycrjysjzSxz) > 0)
                    System.out.println("缺氧池溶解氧报警（一池）报警别为 一级");
                if(!Objects.isNull(qycrjyNkz) && shcQyOneDo.compareTo(qycrjyNkz) > 0 && shcQyOneDo.compareTo(qycrjysjzSxz) <= 0)
                    System.out.println("缺氧池溶解氧报警（一池）报警别为 二级");
                System.out.println("缺氧池溶解氧报警（一池）报警级别为数据正常~~~");
                System.out.println("--------------24.1");
            }

            //24.2 缺氧池溶解氧报警（二池）
            BigDecimal shcQyTwoDo = tXinyiDaily.getShcQyTwoDo();
            if(!Objects.isNull(shcQyTwoDo) && !Objects.isNull(qycrjysjzSxz)){
                if(shcQyTwoDo.compareTo(qycrjysjzSxz) > 0)
                    System.out.println("缺氧池溶解氧报警（二池）报警别为 一级");
                if(!Objects.isNull(qycrjyNkz) && shcQyTwoDo.compareTo(qycrjyNkz) > 0 && shcQyTwoDo.compareTo(qycrjysjzSxz) <= 0)
                    System.out.println("缺氧池溶解氧报警（二池）报警别为 二级");
                System.out.println("缺氧池溶解氧报警（二池）报警级别为数据正常~~~");
                System.out.println("--------------24.2");
            }


            //25.1 好氧池溶解氧报警（一池）
            BigDecimal shcHyOneDo = tXinyiDaily.getShcHyOneDo();
            BigDecimal hycrjysjzSxz = normConfig.getHycrjysjzSxz();
            BigDecimal hycrjyNkz = normConfig.getHycrjyNkz();
            if(!Objects.isNull(shcHyOneDo) && !Objects.isNull(hycrjysjzSxz)){
                if(shcHyOneDo.compareTo(hycrjysjzSxz) > 0)
                    System.out.println("好氧池溶解氧报警（一池）报警别为 一级");
                if(!Objects.isNull(hycrjyNkz) && shcHyOneDo.compareTo(hycrjyNkz) > 0 && shcHyOneDo.compareTo(hycrjysjzSxz) <= 0)
                    System.out.println("好氧池溶解氧报警（一池）报警别为 二级");
                System.out.println("好氧池溶解氧报警（一池）报警级别为数据正常~~~");
                System.out.println("--------------25.1");
            }

            //25.2 好氧池溶解氧报警（二池）
            BigDecimal shcHyTwoDo = tXinyiDaily.getShcHyTwoDo();
            if(!Objects.isNull(shcHyTwoDo) && !Objects.isNull(hycrjysjzSxz)){
                if(shcHyTwoDo.compareTo(hycrjysjzSxz) > 0)
                    System.out.println("好氧池溶解氧报警（二池）报警别为 一级");
                if(!Objects.isNull(hycrjyNkz) && shcHyTwoDo.compareTo(hycrjyNkz) > 0 && shcHyTwoDo.compareTo(hycrjysjzSxz) <= 0)
                    System.out.println("好氧池溶解氧报警（二池）报警别为 二级");
                System.out.println("好氧池溶解氧报警（二池）报警级别为数据正常~~~");
                System.out.println("--------------25.2");
            }

            //26 生化池气水比报警
            BigDecimal qsb = tXinyiDaily.getQSB();
            BigDecimal shcqbSjz = normConfig.getShcqbSjz();
            if(!Objects.isNull(qsb) && !Objects.isNull(shcqbSjz)){
                BigDecimal shcqbNkz = normConfig.getShcqbNkz();
                if(qsb.compareTo(shcqbSjz) > 0)
                    System.out.println("生化池气水比报警别为 一级");
                if(!Objects.isNull(shcqbNkz) && qsb.compareTo(shcqbNkz) > 0 && qsb.compareTo(shcqbSjz) <= 0)
                    System.out.println("生化池气水比报警别为 二级");
                System.out.println("生化池气水比报警级别为数据正常~~~");
                System.out.println("--------------26");
            }

            //27.1 污泥沉降比报警（一池）
            BigDecimal shcHyOneSv = tXinyiDaily.getShcHyOneSv();
            BigDecimal wncjbGkz = normConfig.getWncjbGkz();
            BigDecimal wncjbsjzSxz = normConfig.getWncjbsjzSxz();
            if(!Objects.isNull(shcHyOneSv) && !Objects.isNull(wncjbGkz)){
                if(shcHyOneSv.compareTo(wncjbGkz) > 0)
                    System.out.println("污泥沉降比（一池）报警别为 一级");
                if(!Objects.isNull(wncjbsjzSxz) && shcHyOneSv.compareTo(wncjbsjzSxz) > 0 && shcHyOneSv.compareTo(wncjbGkz) <= 0)
                    System.out.println("污泥沉降比（一池）报警别为 二级");
                System.out.println("污泥沉降比（一池）报警级别为数据正常~~~");
                System.out.println("--------------27.1");
            }

            //27.2 污泥沉降比报警（二池）
            BigDecimal shcHyTwoSv = tXinyiDaily.getShcHyTwoSv();
            if(!Objects.isNull(shcHyTwoSv) && !Objects.isNull(wncjbGkz)){
                if(shcHyTwoSv.compareTo(wncjbGkz) > 0)
                    System.out.println("污泥沉降比（二池）报警别为 一级");
                if(!Objects.isNull(wncjbsjzSxz) && shcHyTwoSv.compareTo(wncjbsjzSxz) > 0 && shcHyTwoSv.compareTo(wncjbGkz) <= 0)
                    System.out.println("污泥沉降比（二池）报警别为 二级");
                System.out.println("污泥沉降比（二池）报警级别为数据正常~~~");
                System.out.println("--------------27.2");
            }

            //28.1 污泥体积指数报警（一池）
            BigDecimal shcHyOneSvi = tXinyiDaily.getShcHyOneSvi();
            BigDecimal wntjzsGkz = normConfig.getWntjzsGkz();
            BigDecimal wntjzsSjz = normConfig.getWntjzsSjz();
            if(!Objects.isNull(shcHyOneSvi) && !Objects.isNull(wntjzsGkz)){
                if(shcHyOneSvi.compareTo(wntjzsGkz) > 0)
                    System.out.println("污泥体积指数（一池）报警别为 一级");
                if(!Objects.isNull(wntjzsSjz) && shcHyOneSvi.compareTo(wntjzsSjz) > 0 && shcHyOneSvi.compareTo(wntjzsGkz) <= 0)
                    System.out.println("污泥体积指数（一池）报警别为 二级");
                System.out.println("污泥体积指数（一池）报警级别为数据正常~~~");
                System.out.println("--------------28.1");
            }

            //28.2 污泥体积指数报警（二池）
            BigDecimal shcHyTwoSvi = tXinyiDaily.getShcHyTwoSvi();
            if(!Objects.isNull(shcHyTwoSvi) && !Objects.isNull(wntjzsGkz)){
                if(shcHyTwoSvi.compareTo(wntjzsGkz) > 0)
                    System.out.println("污泥体积指数（二池）报警别为 一级");
                if(!Objects.isNull(wntjzsSjz) && shcHyTwoSvi.compareTo(wntjzsSjz) > 0 && shcHyTwoSvi.compareTo(wntjzsGkz) <= 0)
                    System.out.println("污泥体积指数（二池）报警别为 二级");
                System.out.println("污泥体积指数（二池）报警级别为数据正常~~~");
                System.out.println("--------------28.2");
            }


            //29 二沉池表面负荷报警 二沉池表面负荷=[e]=[Q_in]/([n_er]*[A_er])m³/(m²·h)
            BigDecimal eccsl = normConfig.getECCSL();
            BigDecimal eccsjzzj = normConfig.getECCSJZZJ();
            BigDecimal eccbmfhznkzSxz = normConfig.getEccbmfhznkzSxz();
            if(!Objects.isNull(eccbmfhznkzSxz) && !Objects.isNull(jsl) && !Objects.isNull(eccsl) && !Objects.isNull(eccsjzzj)){
                BigDecimal eccArea = new BigDecimal(Math.PI).multiply(eccsjzzj).multiply(eccsjzzj).divide(new BigDecimal("4"), 4, RoundingMode.HALF_UP);
                BigDecimal multiply = jsl.divide(eccsl, 4, RoundingMode.HALF_UP).divide(new BigDecimal("24").multiply(eccArea), 4, RoundingMode.HALF_UP);
                if(multiply.compareTo(eccbmfhznkzSxz) > 0)
                    System.out.println("二沉池表面负荷报警别为 一级");
                System.out.println("二沉池表面负荷报警级别为数据正常~~~");
                System.out.println("--------------29");
            }


            //30 二沉池固体负荷报警
            //   二沉池固体负荷=[f]=(1+[R])*[Q_in]*24*[MLSS]/[n_er]/[A_er]/1000kg/（㎡·d)
            BigDecimal whlR = tXinyiDaily.getWhlR();
            BigDecimal eccglfhnkzSxz = normConfig.getEccglfhnkzSxz();
            if(!Objects.isNull(whlR) && !Objects.isNull(eccglfhnkzSxz) && !Objects.isNull(jsl)
                && !Objects.isNull(shcHyOneMlss) && !Objects.isNull(shcHyTwoMlss) && !Objects.isNull(eccsl) && !Objects.isNull(eccsjzzj)){
                BigDecimal avgMlss = shcHyOneMlss.add(shcHyTwoMlss).divide(new BigDecimal("2"), 4, RoundingMode.HALF_UP);
                BigDecimal eccArea = new BigDecimal(Math.PI).multiply(eccsjzzj).multiply(eccsjzzj).divide(new BigDecimal("4"), 4, RoundingMode.HALF_UP);
                //如果是日报 乘以1  如果是工业库，乘以24  外回流R 是百分数，要再除以100 （工业库获取不到）
                BigDecimal divide = (whlR.divide(new BigDecimal("100"), 4, RoundingMode.HALF_UP).add(new BigDecimal("1"))).multiply(jsl).multiply(new BigDecimal("1")).multiply(avgMlss).divide(eccsl, 4, RoundingMode.HALF_UP).divide(eccArea, 4, RoundingMode.HALF_UP).divide(new BigDecimal("1000"), 4, RoundingMode.HALF_UP);
                if(divide.compareTo(eccglfhnkzSxz) > 0)
                    System.out.println("二沉池固体负荷报警别为 一级");
                BigDecimal eccgtfhSjz = normConfig.getEccgtfhSjz();
                BigDecimal eccgtfhnkxxz = normConfig.getECCGTFHNKXXZ();
                // 这里的eccglfhnkzSxz要改成下限值 并且新增字段
                if(!Objects.isNull(eccgtfhSjz) && !Objects.isNull(eccgtfhnkxxz) && divide.compareTo(eccgtfhSjz) > 0 && divide.compareTo(eccgtfhnkxxz) <= 0)
                    System.out.println("二沉池固体负荷报警别为 二级");
                System.out.println("二沉池固体负荷报警级别为数据正常~~~");
                System.out.println("--------------30");
            }


            //31 深度处理反冲洗水量比例报警 深度处理反冲洗水量=[j]=[Q_fan]*[n_fan]*[η_fan]/[Q_in]*100%
            BigDecimal fcxbsjll = normConfig.getFCXBSJLL();
            BigDecimal fclbsl = normConfig.getFCLBSL();
            BigDecimal fcxbgzxl = normConfig.getFCXBGZXL();
            if(!Objects.isNull(jsl) && !Objects.isNull(fcxbsjll) && !Objects.isNull(fclbsl) && !Objects.isNull(fcxbgzxl)){
                //如果是日报 乘以24， 工业库乘以1   乘以100是·单位是百分之多少
                BigDecimal divide = fcxbsjll.multiply(fclbsl).multiply(fcxbgzxl).divide(jsl, 4, RoundingMode.HALF_UP).multiply(new BigDecimal("24").multiply(new BigDecimal("100")));
                BigDecimal fcxslblsjzXxz = normConfig.getFcxslblsjzXxz();
                if(!Objects.isNull(fcxslblsjzXxz) && divide.compareTo(fcxslblsjzXxz) < 0)
                    System.out.println("深度处理反冲洗水量比例报警别为 一级");
                BigDecimal fcxslblsjzSxz = normConfig.getFcxslblsjzSxz();
                if(!Objects.isNull(fcxslblsjzSxz) && divide.compareTo(fcxslblsjzSxz) > 0)
                    System.out.println("深度处理反冲洗水量比例报警别为 一级");
                System.out.println("深度处理反冲洗水量比例报警级别为数据正常~~~");
                System.out.println("--------------31");
            }


            //32 深度处理峰值过滤速度报警 深度处理峰值过滤速度=[q]=[Q_in]/[n_sha]/[A_sha]m/h
            BigDecimal hxslcsl = normConfig.getHXSLCSL();
            BigDecimal hxslcglmj = normConfig.getHXSLCGLMJ();
            BigDecimal sdclfzglsdSjz = normConfig.getSdclfzglsdSjz();
            if(!Objects.isNull(hxslcsl) && !Objects.isNull(hxslcglmj) && !Objects.isNull(jsl) && !Objects.isNull(sdclfzglsdSjz)){
                //除以24是单位转换
                BigDecimal divide = jsl.divide(hxslcsl, 4, RoundingMode.HALF_UP).divide(hxslcglmj, 4, RoundingMode.HALF_UP).divide(new BigDecimal("24"), 4, RoundingMode.HALF_UP);
                if(divide.compareTo(sdclfzglsdSjz) >0 )
                    System.out.println("深度处理峰值过滤速度报警别为 一级");
                System.out.println("深度处理峰值过滤速度报警级别为数据正常~~~");
                System.out.println("--------------32");
            }


        }

    }


    public static void main(String[] args) {
        /*LocalDateTime localDateTime = LocalDateTime.now().plusMinutes(-60);
        //当前时间
        // 将 LocalDateTime 转换为 Date
        Date currentDate = Date.from(localDateTime.atZone(ZoneId.systemDefault()).toInstant());
        //获取对个格式日期字符串
        String currentDateStr = DateUtil.format(currentDate, DateUtils.YYYYMMDD_TS);
        System.out.println("currentDateStr = " + currentDateStr);
        String currentHourStr = DateUtil.format(currentDate, DateUtils.YYYYMMDDHH_TS);
        System.out.println("currentHourStr = " + currentHourStr);*/
    }
}
