package com.slibra;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.slibra.business.domain.TXinyiRobot;
import com.slibra.business.mapper.TXinyiRobotMapper;
import com.slibra.common.config.ApplicationProperties;
import com.slibra.common.core.domain.entity.SysDept;
import com.slibra.common.core.domain.entity.SysUser;
import com.slibra.common.enums.DataSourceType;
import com.slibra.common.utils.third.AliSMSUtil;
import com.slibra.common.utils.third.NumUtil;
import com.slibra.common.utils.third.StringUtil;
import com.slibra.framework.datasource.DynamicDataSourceContextHolder;
import com.slibra.system.mapper.SysDeptMapper;
import com.slibra.system.mapper.SysUserMapper;
import com.wechat.pay.java.service.payments.nativepay.NativePayService;
import com.wechat.pay.java.service.payments.nativepay.model.Amount;
import com.wechat.pay.java.service.payments.nativepay.model.PrepayRequest;
import com.wechat.pay.java.service.payments.nativepay.model.PrepayResponse;
import lombok.extern.slf4j.Slf4j;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@SpringBootTest
@Slf4j
public class MyTest {

    @Resource
    private SysDeptMapper sysDeptMapper;

    /*@Autowired
    private AliSMSUtil aliSMSUtil;*/
    @Autowired
    private ApplicationProperties properties ;

//    @Autowired
    @Resource
    private NativePayService nativePayService;

    @Autowired
    private SysUserMapper userMapper;

    @Autowired
    private TXinyiRobotMapper xinyiRobotMapper;

    @Test
    void contextLoads() {
    }

    @Test
    public void testSOUT(){
        System.out.println(111);
    }

    @Test
    void testMybatisPlus(){
        PageHelper.startPage(5,1);
        QueryWrapper<SysDept> wrapper = new QueryWrapper<>();
        wrapper.like("dept_name", "部门");
        List<SysDept> sysDepts = sysDeptMapper.selectList(wrapper);
        System.out.println(JSON.toJSONString(sysDepts));
    }

    /**
     * 测试注册短信发送
     */
    @Test
    public void testSMSLogin(){
        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("login", "王苗面");
//        String result = AliSMSUtil.sendMsg(aliCloud.getTemplateRegistBuyer(), "15075275358", paramMap);
        String result = AliSMSUtil.sendMsg("SMS_462425424", "15075275358", paramMap);
        System.out.println("result = " + result);
    }


    /**
     * 测试验证码发送
     */
    @Test
    public void testSMSVerifyCode(){
        String code = NumUtil.get6Long();
        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("code", code);
        String result = AliSMSUtil.sendMsg(properties.getAliCloud().getTemplateCodeMessage(), "15075275358", paramMap);
//        String result = AliSMSUtil.sendMsg("SMS_461080515", "15075275358", paramMap);
        System.out.println("result = " + result);
    }


    /**
     * 测试微信支付获取二维码
     */
// 发起微信支付
    @Test
    public void testWeChatPay(){
        PrepayRequest request = new PrepayRequest();
        Amount amount = new Amount();
        amount.setTotal(new BigDecimal("100").multiply(BigDecimal.valueOf(100)).intValue());
        request.setAmount(amount);
        request.setAppid(properties.getWechatPay().getAppId());
        request.setMchid(properties.getWechatPay().getMerchantId());
        request.setDescription("伏羲碳惠平台-碳交易");
        request.setNotifyUrl(properties.getWechatPay().getOrderNotifyUrl());
        request.setOutTradeNo(StringUtil.createOrderId());
        PrepayResponse response = nativePayService.prepay(request);
        log.info("支付拿到的结果是:{}", response.getCodeUrl());
    }


    @Test
    public void testMultilyDataTwo(){
        //从
        DynamicDataSourceContextHolder.setDataSourceType(DataSourceType.SLAVE.name());
        List<TXinyiRobot> tXinyiRobots = xinyiRobotMapper.selectTXinyiRobotList(null);
        DynamicDataSourceContextHolder.clearDataSourceType();
        System.out.println(JSON.toJSONString(tXinyiRobots.get(0)));
        System.out.println("-------------");
        //主
        SysUser sysUser = new SysUser();
        sysUser.setUserId(31L);
        List<SysUser>  userList = userMapper.selectUserList(sysUser);
        DynamicDataSourceContextHolder.clearDataSourceType();
        System.out.println(JSON.toJSONString(userList));
    }


    @Test
    public void testSqlserverGet(){
        log.info("进入了定时同步SqlServer的任务");
        //主库获取上次最新的同步日期
        String lastTime = this.xinyiRobotMapper.selectLastTime();
        log.info("上次同步的日期是{}", lastTime);
        //从
        DynamicDataSourceContextHolder.setDataSourceType(DataSourceType.SLAVE.name());
        List<TXinyiRobot> tXinyiRobots = xinyiRobotMapper.selectTXinyiRobotListByTime(lastTime);
        DynamicDataSourceContextHolder.clearDataSourceType();
//        System.out.println(JSON.toJSONString(tXinyiRobots));
//        System.out.println("-------------");
        //主
        if(!CollectionUtils.isEmpty(tXinyiRobots)){
            for (TXinyiRobot tXinyiRobot : tXinyiRobots) {
                tXinyiRobot.setVDateTime(tXinyiRobot.getVDate() + tXinyiRobot.getVTime());
                tXinyiRobot.setCreatedTime(new Date());
                this.xinyiRobotMapper.insertTXinyiRobot(tXinyiRobot);
            }
        }
    }


}
