package com.slibra.common.utils.third;

import org.apache.commons.lang3.StringUtils;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.security.SecureRandom;
import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.function.Function;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class StringUtil {

    private static final char SEPARATOR = '_';
    /**
     * @apiNote author: zk 随机生成8位字母数字混合密码
     */
    private static final String lowStr = "abcdefghijklmnopqrstuvwxyz";

    private static final String numStr = "0123456789";

    /**
     * @Description: 生成唯一图片名称
     * @Param: fileName
     * @return: 云服务器fileName
     */
    public static String getRandomImgName(String fileName) {
        int index = fileName.lastIndexOf(".");
        if ((fileName == null || fileName.isEmpty()) || index == -1){
            throw new IllegalArgumentException();
        }
        // 获取文件后缀
        String suffix = fileName.substring(index);
        // 生成UUID
        String uuid = UUID.randomUUID().toString().replaceAll("-", "");
        // 生成上传至云服务器的路径
//        String path = "news/crush/"+ DateUtil.today() + "-" + uuid + suffix;
        String path = uuid + suffix;
        return path;
    }


    /**
     * 驼峰命名法工具
     *
     * @return camelCase(" hello_world ") == "helloWorld"
     * capCamelCase("hello_world") == "HelloWorld"
     * uncamelCase("helloWorld") = "hello_world"
     */
    public static String camelCase(String s) {
        if (s == null) {
            return null;
        }
        s = s.toLowerCase();
        StringBuilder sb = new StringBuilder(s.length());
        boolean upperCase = false;
        for (int i = 0; i < s.length(); i++) {
            char c = s.charAt(i);

            if (c == SEPARATOR) {
                upperCase = i != 1; // 不允许第二个字符是大写
            } else if (upperCase) {
                sb.append(Character.toUpperCase(c));
                upperCase = false;
            } else {
                sb.append(c);
            }
        }
        return sb.toString();
    }

    /**
     * @param selected
     * @param s
     * @return 选择且不为空, 如: null | "" | "[]"
     * @apiNote author: czz;
     */
    public static Boolean isUsed(Boolean selected, String s) {
        return selected && symbolArrayStrNotBlank(s);
    }

    //    public static Boolean cellNotEmpty(HSSFRichTextString str) {
    //        return str != null;
    //    }

    public static Boolean symbolArrayStrNotBlank(String s) {
        return !symbolArrayStrBlank(s);
    }

    public static Boolean symbolArrayStrBlank(String s) {
        return s == null || StringUtils.isBlank(s) || "[]".equals(s);
    }

    /**
     * @param s
     * @return
     * @apiNote author: czz; 判断水务年报中 数据是否为空/-  计算时使用
     */
    public static Boolean cellEmpty(String s) {
        return StringUtils.isBlank(s) || "-".equals(s);
    }

    /**
     * @param s
     * @return
     * @apiNote author: czz; not blank[null or empty], not "-"
     */
    public static Boolean cellNotEmpty(String s) {
        return !cellEmpty(s);
    }

    // 随机获取字符串字符
    private static char getRandomChar(String str) {
        SecureRandom random = new SecureRandom();
        return str.charAt(random.nextInt(str.length()));
    }

    // 随机获取小写字符
    private static char getLowChar() {
        return getRandomChar(lowStr);
    }

    // 随机获取大写字符
    private static char getUpperChar() {
        return Character.toUpperCase(getLowChar());
    }

    // 随机获取数字字符
    private static char getNumChar() {
        return getRandomChar(numStr);
    }

    // 指定调用字符函数
    private static char getRandomChar(int funNum) {
        switch (funNum) {
            case 0:
                return getLowChar();
            case 1:
                return getUpperChar();
            case 2:
                return getNumChar();
            default:
                return getNumChar();
        }
    }

    // 指定长度，随机生成复杂密码
    public static String getRandomPwd() {
        List<Character> list = new ArrayList<>(8);
        list.add(getLowChar());
        list.add(getUpperChar());
        list.add(getNumChar());

        for (int i = 3; i < 8; i++) {
            SecureRandom random = new SecureRandom();
            int funNum = random.nextInt(4);
            list.add(getRandomChar(funNum));
        }

        Collections.shuffle(list); // 打乱排序
        StringBuilder stringBuilder = new StringBuilder(list.size());
        for (Character c : list) {
            stringBuilder.append(c);
        }
        return stringBuilder.toString();
    }

    public static String getDateStr(String str) {
        /**
         * "2022-03-30 17:35:56"
         */
        return str.substring(0, 10).replaceAll("-", "");
    }

    public static List<Integer> toIntList(String str) {
        List<Integer> list = new ArrayList<>();
        split(str, ", ")
            .forEach(t -> {
                if (t.contains("-")) {
                    List<String> tList = split(t, "-");
                    for (int i = Integer.valueOf(tList.get(0)); i <= Integer.valueOf(tList.get(1)); i++) {
                        list.add(i);
                    }
                } else {
                    list.add(Integer.valueOf(t));
                }
            });
        return list;
    }

    public static List<String> split(String str) {
        List<String> list = new ArrayList<>();
        if (StringUtils.isNotBlank(str)) {
            return Arrays.asList(str.split(","));
        }
        return list;
    }

    public static List<String> split(String str, String separator) {
        List<String> list = new ArrayList<>();
        if (StringUtils.isNotBlank(str)) {
            return Arrays.asList(str.split(separator));
        }
        return list;
    }

    public static List<String> splitAndFilterBlank(String str, String separator) {
        List<String> list = new ArrayList<>();
        if (StringUtils.isNotBlank(str)) {
            String[] strs = str.split(separator);
            for (String s : strs) {
                if (StringUtils.isNotBlank(s)) {
                    list.add(s);
                }
            }
        }
        return list;
    }

    public static String getFinallyTradeType(@NotNull @NotEmpty String tradeType) {
        /**
         * CCER-15, CCER-17,CCER-16,SHEA,CCER,GDEA,TJEA21,TJEA13,TJEA15,TJEA14,TJEA19,TJEA20,TJEA17,
         * TJEA16,CEA,HBEA,BEA,CCER,PCER,SZA-2013,SZA-2014,SZA-2015,SZA-2016,SZA-2017,SZA-2020,SZA-2019,SZA-2018,
         */
        return removeNum(tradeType).replaceAll("-", "");
    }

    public static List<String> getTradeTotalPriceAndType(String str) {
        /**
         * origin: "182500.00ï¼BEAï¼"
         * -*-*-* 乱码数据，只想获取数字【价格】，和英文字母【碳交易类型】 -*-*-*
         * result: ["182500.00", "BEA"]
         */
        String notNumStr = removeNum(str);
        int notNumStartIndex = str.length() - notNumStr.length();
        String priceStr = str.substring(0, notNumStartIndex);
        String typeStr = leaveCharacter(notNumStr);
        return Arrays.asList(priceStr, typeStr);
    }

    public static String removeNum(String str) {
        /**
         * origin: "182500.00ï¼BEAï¼"
         * -*-*-* 上面转为去除数字和小数点 -*-*-*-  只有一位小数点或其他部位没有小数点 -*-*-*-
         * result: "ï¼BEAï¼"
         */
        return str.replaceAll("[0-9]", "").replaceAll("[.]", "");
    }

    public static String leaveCharacter(String str) {
        /**
         * origin: "ï¼BEAï¼"
         * -*-*-* 上面转为只保留字母 -*-*-*-
         * result: "BEA"
         */
        return str.replaceAll("[^a-zA-Z]", "");
    }

    public static String join(String separator, String... strs) {
        return StringUtils.join(Arrays.asList(strs), separator);
    }

    public static String join(List<String> list) {
        return StringUtils.join(list, ",");
    }

    public static String join(List<String> list, String separator, String defaultStr) {
        return StringUtils.join(list, separator);
    }

    public static String join(List<BigDecimal> list, String separator) {
        return StringUtils.join(list, separator);
    }

    /**
     * @param str
     * @return
     * @apiNote author: czz; 判断字符是否包含汉字
     */
    public static boolean generateJudgment(String str) {
        Pattern p = Pattern.compile("[\u4e00-\u9fa5]");
        Matcher isNum = p.matcher(str);
        if (isNum.find()) {
            return true;
        }
        return false;
    }

    public static boolean ifIn(String one, List<String> arr) {
        for (String t : arr) {
            if (t.equals(one)) {
                return true;
            }
        }
        return false;
    }

    public static boolean ifIn(String one, String... arr) {
        for (String t : arr) {
            if (t.equals(one)) {
                return true;
            }
        }
        return false;
    }

    public static boolean carbonTradeTypeUseless(String type) {
        return !carbonTradeTypeUseful(type);
    }

    public static boolean carbonTradeTypeUseful(String type) {
        return type != null && !type.equals("") && !type.equals("-");
    }

    public static String defaultCarbonValue(BigDecimal num) {
        if (num == null) {
            return "-";
        }
        return String.valueOf(num);
    }

    public static String getDefaultTradeValue(String str) {
        if (StringUtils.isBlank(str)) {
            return "-";
        }
        return str.replaceAll(",", "");
    }

    public static Boolean isNotBlank(String str) {
        return StringUtils.isNotBlank(str);
    }

    public static String blankReturn(String str, String other) {
        return isNotBlank(str) ? str : other;
    }

    public static String blankReturn(String str, Function<String, String> function) {
        return isNotBlank(str) ? str : function.apply(str);
    }

    public static String subLast(Long id, int subNum) {
        String idStr = String.valueOf(id);
        StringBuilder buffer = new StringBuilder(idStr);
        while (buffer.length() < subNum) {
            buffer.insert(0, "0");
        }
        int length = buffer.length();
        return buffer.substring(length - subNum);
    }

    /**
     * @param buyerId 买方ID
     * @param sellerId 卖方ID
     * @param lastOrderId 最新已有订单的ID
     * @return
     * @apiNote author: czz; 买方ID后2+卖方ID后2+年月日(yyMMdd)+4位系统序列号(0000-9999)
     */
    public static String newOrderCode(Long buyerId, Long sellerId, Long lastOrderId) {
        StringBuilder buffer = new StringBuilder();
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyMMdd");
        String nowStr = ZonedDateTime.now().format(formatter);
        return buffer
            .append(subLast(buyerId, 2))
            .append(subLast(sellerId, 2))
            .append(nowStr)
            .append(subLast(lastOrderId + 1, 4)) // lastOrderId + 1
            .toString();
    }

    /*public static String initByParentMenu(Menu parentMenu) {
        return Objects.requireNonNullElse(parentMenu.getParentIds(), ",") + parentMenu.getId() + ",";
    }*/

    public static String replaceChildParentIds(String child_MenuParentIds, String menuParentIds_Before, String menuParentIds_Now) {
        menuParentIds_Now = menuParentIds_Now == null ? "," : menuParentIds_Now;
        if (menuParentIds_Before == null) {
            child_MenuParentIds = menuParentIds_Now + (child_MenuParentIds.substring(1));
        } else {
            child_MenuParentIds = child_MenuParentIds.replace(menuParentIds_Before, menuParentIds_Now);
        }
        return child_MenuParentIds;
    }

    public static String createOrderId() {
        int machineId = 1; //最大支持1-9个集群机器部署
        int hashCodeV = UUID.randomUUID().toString().hashCode();
        if (hashCodeV < 0) { //有可能是负数
            hashCodeV = -hashCodeV;
        }
        // 0 代表前面补充0
        // 4 代表长度为4
        // d 代表参数为正数型
        return machineId + String.format("%015d", hashCodeV);
    }
}
