package com.slibra.business.domain;

import java.math.BigDecimal;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;

/**
 * 信义大天维度统计对象 t_xinyi_big_table_day
 * 
 * @author slibra
 * @date 2024-07-07
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class TXinyiBigTableDay extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long ID;

    /** 化验日期 示例：2022/07/01 */
    @Excel(name = "化验日期 示例：2022/07/01")
    private String testDate;

    /** 工业表-进水化学需氧量COD */
    @Excel(name = "工业表-进水化学需氧量COD")
    private BigDecimal gyJsCod;

    /** 工业表-进水酸碱度pH */
    @Excel(name = "工业表-进水酸碱度pH")
    private BigDecimal gyJsPh;

    /** 工业表-进水悬浮物SS */
    @Excel(name = "工业表-进水悬浮物SS")
    private BigDecimal gyJsSs;

    /** 工业表-进水总磷TP */
    @Excel(name = "工业表-进水总磷TP")
    private BigDecimal gyJsTp;

    /** 工业表-进水总氮TN */
    @Excel(name = "工业表-进水总氮TN")
    private BigDecimal gyJsTn;

    /** 工业表-进水氨氮NH₃-N */
    @Excel(name = "工业表-进水氨氮NH₃-N")
    private BigDecimal gyJsNh3;

    /** 工业表-进水水温/进水PH - 2个值 */
    @Excel(name = "工业表-进水水温/进水PH - 2个值")
    private BigDecimal gyJsSwPh;

    /** 工业表-进水泵房液位 （粗细格栅一提液位） */
    @Excel(name = "工业表-进水泵房液位 ", readConverterExp = "粗=细格栅一提液位")
    private BigDecimal gyJsBfyw;

    /** 工业表-出水水量Q出 */
    @Excel(name = "工业表-出水水量Q出")
    private BigDecimal gyCsSlqc;

    /** 工业表-出水化学需氧量COD */
    @Excel(name = "工业表-出水化学需氧量COD")
    private BigDecimal gyCsCod;

    /** 工业表-出水酸碱度pH */
    @Excel(name = "工业表-出水酸碱度pH")
    private BigDecimal gyCsPh;

    /** 工业表-出水悬浮物SS */
    @Excel(name = "工业表-出水悬浮物SS")
    private BigDecimal gyCsSs;

    /** 工业表-出水总氮TN */
    @Excel(name = "工业表-出水总氮TN")
    private BigDecimal gyCsTn;

    /** 工业表-出水总磷TP */
    @Excel(name = "工业表-出水总磷TP")
    private BigDecimal gyCsTp;

    /** 工业表-出水氨氮NH₃-N */
    @Excel(name = "工业表-出水氨氮NH₃-N")
    private BigDecimal gyCsNh3;

    /** 工业表-1#池好氧中段溶解氧 DO */
    @Excel(name = "工业表-1#池好氧中段溶解氧 DO")
    private BigDecimal gyOneHyzdDo;

    /** 工业表-1#池好氧末段溶解氧 DO */
    @Excel(name = "工业表-1#池好氧末段溶解氧 DO")
    private BigDecimal gyOneHymdDo;

    /** 工业表-2#池好氧中段溶解氧 DO */
    @Excel(name = "工业表-2#池好氧中段溶解氧 DO")
    private BigDecimal gyTwoHyzdDo;

    /** 工业表-2#池好氧末段溶解氧 DO */
    @Excel(name = "工业表-2#池好氧末段溶解氧 DO")
    private BigDecimal gyTwoHymdDo;

    /** 工业表-1#池污泥浓度（MLSS） */
    @Excel(name = "工业表-1#池污泥浓度", readConverterExp = "M=LSS")
    private BigDecimal gyOneMlss;

    /** 工业表-2#池污泥浓度（MLSS） */
    @Excel(name = "工业表-2#池污泥浓度", readConverterExp = "M=LSS")
    private BigDecimal gyTwoMlss;

    /** 工业表-进水溶解性总固体TDS */
    @Excel(name = "工业表-进水溶解性总固体TDS")
    private BigDecimal gyJsTds;

    /** 工业表-进水水量Q进 */
    @Excel(name = "工业表-进水水量Q进")
    private BigDecimal gyJsSlq;

    /** 工业表-内回流泵1# 1号泵 工频 */
    @Excel(name = "工业表-内回流泵1# 1号泵 工频")
    private BigDecimal gyNHlbOneGp;

    /** 工业表-内回流泵1# 2号泵 工频 */
    @Excel(name = "工业表-内回流泵1# 2号泵 工频")
    private BigDecimal gyNHlbTwoGp;

    /** 工业表-内回流泵1# 3号泵 工频 */
    @Excel(name = "工业表-内回流泵1# 3号泵 工频")
    private BigDecimal gyNHlbThreeGp;

    /** 工业表-内回流泵2# 4号泵 工频 */
    @Excel(name = "工业表-内回流泵2# 4号泵 工频")
    private BigDecimal gyNHlbFourGp;

    /** 工业表-内回流泵2# 5号泵 工频 */
    @Excel(name = "工业表-内回流泵2# 5号泵 工频")
    private BigDecimal gyNhlBFiveGp;

    /** 工业表-内回流泵2# 6号泵 工频 */
    @Excel(name = "工业表-内回流泵2# 6号泵 工频")
    private BigDecimal gyNHlbSixGp;

    /** 工业表-外回流泵1 工频 */
    @Excel(name = "工业表-外回流泵1 工频")
    private BigDecimal gyWHlbOneGp;

    /** 工业表-外回流泵2 工频 */
    @Excel(name = "工业表-外回流泵2 工频")
    private BigDecimal gyWHlbTwoGp;

    /** 工业表-外回流泵3 工频 */
    @Excel(name = "工业表-外回流泵3 工频")
    private BigDecimal gyWHlbThreeGp;

    /** 工业表-外回流泵4 工频 */
    @Excel(name = "工业表-外回流泵4 工频")
    private BigDecimal gyWHlbFourGp;

    /** 工业表-外回流泵5 工频 */
    @Excel(name = "工业表-外回流泵5 工频")
    private BigDecimal gyWHlbFiveGp;

    /** 工业表-风机1（启停） */
    @Excel(name = "工业表-风机1", readConverterExp = "启=停")
    private BigDecimal gyFjOne;

    /** 工业表-风机2（启停） */
    @Excel(name = "工业表-风机2", readConverterExp = "启=停")
    private BigDecimal gyFjTwo;

    /** 工业表-风机3（启停） */
    @Excel(name = "工业表-风机3", readConverterExp = "启=停")
    private BigDecimal gyFjThree;

    /** 工业表-风机4（启停） */
    @Excel(name = "工业表-风机4", readConverterExp = "启=停")
    private BigDecimal gyFjFour;

    /** 工业表-风机5（启停） */
    @Excel(name = "工业表-风机5", readConverterExp = "启=停")
    private BigDecimal gyFjFive;

    /** 工业表-风机6（启停） */
    @Excel(name = "工业表-风机6", readConverterExp = "启=停")
    private BigDecimal gyFjSix;

    /** 工业表-空气流量1（风机现阶段送风量） */
    @Excel(name = "工业表-空气流量1", readConverterExp = "风=机现阶段送风量")
    private BigDecimal gyKqllOne;

    /** 工业表-空气流量2（风机现阶段送风量） */
    @Excel(name = "工业表-空气流量2", readConverterExp = "风=机现阶段送风量")
    private BigDecimal gyKqllTwo;

    /** 工业表-空气流量3（风机现阶段送风量） */
    @Excel(name = "工业表-空气流量3", readConverterExp = "风=机现阶段送风量")
    private BigDecimal gyKqllThree;

    /** 工业表-空气流量4（风机现阶段送风量） */
    @Excel(name = "工业表-空气流量4", readConverterExp = "风=机现阶段送风量")
    private BigDecimal gyKqllFour;

    /** 工业表-空气流量5（风机现阶段送风量） */
    @Excel(name = "工业表-空气流量5", readConverterExp = "风=机现阶段送风量")
    private BigDecimal gyKqllFive;

    /** 工业表-空气流量6（风机现阶段送风量） */
    @Excel(name = "工业表-空气流量6", readConverterExp = "风=机现阶段送风量")
    private BigDecimal gyKqllSix;

    /** 工业表-信义污水厂实际碳源加药量 */
    @Excel(name = "工业表-信义污水厂实际碳源加药量")
    private BigDecimal gySjtyjly;

    /** 工业表-信义污水厂除磷加药瞬时流量 */
    @Excel(name = "工业表-信义污水厂除磷加药瞬时流量")
    private BigDecimal gyCljyssll;

    /** 工业表-好氧池溶解氧集合 */
    @Excel(name = "工业表-好氧池溶解氧集合")
    private String gyHycRjyAll;

    /** 工业表-好氧池中断溶解氧 */
    @Excel(name = "工业表-好氧池中断溶解氧")
    private String gyHycRjyZdAll;

    /** 工业表-好氧池污泥浓度集合 */
    @Excel(name = "工业表-好氧池污泥浓度集合")
    private String gyHycWnndAll;

    /** 工业表-信义污水厂_除磷P04预测值_ */
    @Excel(name = "工业表-信义污水厂_除磷P04预测值_")
    private BigDecimal gyClP04Ycz;

    /** 日报表-进水化学需氧量 COD */
    @Excel(name = "日报表-进水化学需氧量 COD")
    private BigDecimal rbJsCod;

    /** 日报表-进水酸碱度pH */
    @Excel(name = "日报表-进水酸碱度pH")
    private BigDecimal rbJsPh;

    /** 日报表-进水生化需氧量BOD₅ */
    @Excel(name = "日报表-进水生化需氧量BOD₅")
    private BigDecimal rbJsBod5;

    /** 日报表-进水悬浮物 SS */
    @Excel(name = "日报表-进水悬浮物 SS")
    private BigDecimal rbJsSs;

    /** 日报表-进水氨氮 NH₃-N */
    @Excel(name = "日报表-进水氨氮 NH₃-N")
    private BigDecimal rbJsNh3;

    /** 日报表-进水总氮TN */
    @Excel(name = "日报表-进水总氮TN")
    private BigDecimal rbJsTn;

    /** 日报表-进水总磷TP */
    @Excel(name = "日报表-进水总磷TP")
    private BigDecimal rbJsTp;

    /** 日报表-进水粪菌群（大肠杆菌） */
    @Excel(name = "日报表-进水粪菌群", readConverterExp = "大=肠杆菌")
    private BigDecimal rbJsDcgj;

    /** 日报表-出水化学需氧量COD */
    @Excel(name = "日报表-出水化学需氧量COD")
    private BigDecimal rbCsCod;

    /** 日报表-出水酸碱度pH */
    @Excel(name = "日报表-出水酸碱度pH")
    private BigDecimal rbCsPh;

    /** 日报表-出水生化需氧量BOD₅ */
    @Excel(name = "日报表-出水生化需氧量BOD₅")
    private BigDecimal rbCsBod5;

    /** 日报表-出水悬浮物SS */
    @Excel(name = "日报表-出水悬浮物SS")
    private BigDecimal rbCsSs;

    /** 日报表-出水氨氮 NH₃-N */
    @Excel(name = "日报表-出水氨氮 NH₃-N")
    private BigDecimal rbCsNh3;

    /** 日报表-出水总氮TN */
    @Excel(name = "日报表-出水总氮TN")
    private BigDecimal rbCsTn;

    /** 日报表-出水总磷TP */
    @Excel(name = "日报表-出水总磷TP")
    private BigDecimal rbCsTp;

    /** 日报表-出水粪菌群（大肠杆菌） */
    @Excel(name = "日报表-出水粪菌群", readConverterExp = "大=肠杆菌")
    private BigDecimal rbCsDcgj;

    /** 日报表-进水水温 */
    @Excel(name = "日报表-进水水温")
    private BigDecimal rbJsSw;

    /** 日报表-出水水温 */
    @Excel(name = "日报表-出水水温")
    private BigDecimal rbCsSw;

    /** 日报表-生化池好氧池#1 酸碱度pH */
    @Excel(name = "日报表-生化池好氧池#1 酸碱度pH")
    private BigDecimal rbShcOnePh;

    /** 日报表-生化池好氧池#2 酸碱度pH */
    @Excel(name = "日报表-生化池好氧池#2 酸碱度pH")
    private BigDecimal rbShcTwoPh;

    /** 日报表-生化池好氧池#1 污泥沉降比SV% */
    @Excel(name = "日报表-生化池好氧池#1 污泥沉降比SV%")
    private BigDecimal rbShcHyOneSv;

    /** 日报表-生化池好氧池#2 污泥沉降比SV% */
    @Excel(name = "日报表-生化池好氧池#2 污泥沉降比SV%")
    private BigDecimal rbShcHyTwoSv;

    /** 日报表-生化池好氧池#1 污泥体积指数SVI */
    @Excel(name = "日报表-生化池好氧池#1 污泥体积指数SVI")
    private BigDecimal rbShcHyOneSvi;

    /** 日报表-生化池好氧池#2 污泥体积指数SVI */
    @Excel(name = "日报表-生化池好氧池#2 污泥体积指数SVI")
    private BigDecimal rbShcHyTwoSvi;

    /** 日报表-生化池好氧池#1 污泥浓度MLSS */
    @Excel(name = "日报表-生化池好氧池#1 污泥浓度MLSS")
    private BigDecimal rbShcHyOneMlss;

    /** 日报表-生化池好氧池#2 污泥浓度MLSS */
    @Excel(name = "日报表-生化池好氧池#2 污泥浓度MLSS")
    private BigDecimal rbShcHyTwoMlss;

    /** 日报表-生化池好氧池#1 挥发性污泥浓度MLVSS */
    @Excel(name = "日报表-生化池好氧池#1 挥发性污泥浓度MLVSS")
    private BigDecimal rbShcHyOneMlvss;

    /** 日报表-生化池好氧池#2 挥发性污泥浓度MLVSS */
    @Excel(name = "日报表-生化池好氧池#2 挥发性污泥浓度MLVSS")
    private BigDecimal rbShcHyTwoMlvss;

    /** 日报表-生化池厌氧池#1 溶解氧DO */
    @Excel(name = "日报表-生化池厌氧池#1 溶解氧DO")
    private BigDecimal rbShcYyOneDo;

    /** 日报表-生化池厌氧池#2 溶解氧DO */
    @Excel(name = "日报表-生化池厌氧池#2 溶解氧DO")
    private BigDecimal rbShcYyTwoDo;

    /** 日报表-生化池缺氧池#1 溶解氧DO */
    @Excel(name = "日报表-生化池缺氧池#1 溶解氧DO")
    private BigDecimal rbShcQyOneDo;

    /** 日报表-生化池缺氧池#2 溶解氧DO */
    @Excel(name = "日报表-生化池缺氧池#2 溶解氧DO")
    private BigDecimal rbShcQyTwoDo;

    /** 日报表-生化池好氧池#1 溶解氧DO */
    @Excel(name = "日报表-生化池好氧池#1 溶解氧DO")
    private BigDecimal rbShcHyOneDo;

    /** 日报表-生化池好氧池#2 溶解氧DO */
    @Excel(name = "日报表-生化池好氧池#2 溶解氧DO")
    private BigDecimal rbShcHyTwoDo;

    /** 日报表-进水量 */
    @Excel(name = "日报表-进水量")
    private BigDecimal rbJsl;

    /** 日报表-出水量 */
    @Excel(name = "日报表-出水量")
    private BigDecimal rbCsl;

    /** 日报表-深度处理冲洗水量(m³) */
    @Excel(name = "日报表-深度处理冲洗水量(m³)")
    private BigDecimal rbSdclcxsl;

    /** 日报表-气水比 */
    @Excel(name = "日报表-气水比")
    private BigDecimal rbQsb;

    /** 日报表-F/M（污泥负荷） */
    @Excel(name = "日报表-F/M", readConverterExp = "污=泥负荷")
    private BigDecimal rbFM;

    /** 日报表-厌氧区停留时间 HRT */
    @Excel(name = "日报表-厌氧区停留时间 HRT")
    private BigDecimal rbYyHrt;

    /** 日报表-好氧区停留时间HRT */
    @Excel(name = "日报表-好氧区停留时间HRT")
    private BigDecimal rbHyHrt;

    /** 日报表-缺氧区停留时间 HRT */
    @Excel(name = "日报表-缺氧区停留时间 HRT")
    private BigDecimal rbQyHrt;

    /** 日报表-内回流r */
    @Excel(name = "日报表-内回流r")
    private BigDecimal rbNhlR;

    /** 日报表-外回流R */
    @Excel(name = "日报表-外回流R")
    private BigDecimal rbWhlR;

    /** 日报表-污泥龄SRT */
    @Excel(name = "日报表-污泥龄SRT")
    private BigDecimal rbSrt;

    /** 日报表-产泥率 */
    @Excel(name = "日报表-产泥率")
    private BigDecimal rbCnl;

    /** 日报表-投药前 BOD₅/TN */
    @Excel(name = "日报表-投药前 BOD₅/TN")
    private BigDecimal rbTyqBod5Tn;

    /** 日报表-投药后 BOD₅/TN */
    @Excel(name = "日报表-投药后 BOD₅/TN")
    private BigDecimal rbTyhBod5Tn;

    /** 日报表-好氧池溶解氧集合 */
    @Excel(name = "日报表-好氧池溶解氧集合")
    private String rbHycRjyAll;

    /** 日报表-好氧池污泥浓度集合 */
    @Excel(name = "日报表-好氧池污泥浓度集合")
    private String rbHycWnndAll;

    /** 日报表-厌氧池溶解氧集合 */
    @Excel(name = "日报表-厌氧池溶解氧集合")
    private String rbYycRjyAll;

    /** 日报表-缺氧池溶解氧集合 */
    @Excel(name = "日报表-缺氧池溶解氧集合")
    private String rbQycRjyAll;

    /** 日报表-污泥沉降比集合 */
    @Excel(name = "日报表-污泥沉降比集合")
    private String rbWncjbAll;

    /** 日报表-污泥体积指数集合 */
    @Excel(name = "日报表-污泥体积指数集合")
    private String rbWntjzsAll;

    /** 日报表-挥发性污泥浓度集合 */
    @Excel(name = "日报表-挥发性污泥浓度集合")
    private String rbHfxwnndAll;

    /** 日报表-出泥量(m³) */
    @Excel(name = "日报表-出泥量(m³)")
    private BigDecimal rbChuniliang;

    /** 日报表-出泥含水率(%) */
    @Excel(name = "日报表-出泥含水率(%)")
    private BigDecimal rbCnhsl;

    /** 日报表-干污泥量(m³) */
    @Excel(name = "日报表-干污泥量(m³)")
    private BigDecimal rbGwnl;

    /** 日报表-电费 */
    @Excel(name = "日报表-电费")
    private BigDecimal rbDf;

    /** 日报表-絮凝剂费 */
    @Excel(name = "日报表-絮凝剂费")
    private BigDecimal rbXnjf;

    /** 日报表-除磷费 */
    @Excel(name = "日报表-除磷费")
    private BigDecimal rbClf;

    /** 日报表-碳源费 */
    @Excel(name = "日报表-碳源费")
    private BigDecimal rbTyf;

    /** 日报表-消毒剂费 */
    @Excel(name = "日报表-消毒剂费")
    private BigDecimal rbXdjf;

    /** 日报表-其他药剂费 */
    @Excel(name = "日报表-其他药剂费")
    private BigDecimal rbQtyjf;

    /** 日报表-采暖费 */
    @Excel(name = "日报表-采暖费")
    private BigDecimal rbCnf;

    /** 日报表-自来水费 */
    @Excel(name = "日报表-自来水费")
    private BigDecimal rbZlsf;

    /** 日报表-直接成本 */
    @Excel(name = "日报表-直接成本")
    private BigDecimal rbZjcb;

    /** 日报表-单位成本 */
    @Excel(name = "日报表-单位成本")
    private BigDecimal rbDwcb;

    /** 化验表-仪表COD（在线仪表） */
    @Excel(name = "化验表-仪表COD", readConverterExp = "在=线仪表")
    private BigDecimal hyCodYb;

    /** 化验表-化验机器人COD化验有效值（COD生物池进水机器人） */
    @Excel(name = "化验表-化验机器人COD化验有效值", readConverterExp = "C=OD生物池进水机器人")
    private BigDecimal hyCodJqr;

    /** 化验表-化验机器人COD化验计算值（COD生物池进水阈值） */
    @Excel(name = "化验表-化验机器人COD化验计算值", readConverterExp = "C=OD生物池进水阈值")
    private BigDecimal hyCodYz;

    /** 化验表-#1好氧池-正磷酸盐 +  化验机器人正磷化验有效值1（正磷1池回流机器人） */
    @Excel(name = "化验表-#1好氧池-正磷酸盐 +  化验机器人正磷化验有效值1", readConverterExp = "正=磷1池回流机器人")
    private BigDecimal hyTpHl1Jqr;

    /** 化验表-#2好氧池-正磷酸盐 + 化验机器人正磷化验有效值2（正磷2池回流机器人） */
    @Excel(name = "化验表-#2好氧池-正磷酸盐 + 化验机器人正磷化验有效值2", readConverterExp = "正=磷2池回流机器人")
    private BigDecimal hyTpHl2Jqr;

    /** 化验表-二沉池-正磷酸盐 + 化验机器人正磷化验有效值二沉池（正磷二沉池机器人） */
    @Excel(name = "化验表-二沉池-正磷酸盐 + 化验机器人正磷化验有效值二沉池", readConverterExp = "正=磷二沉池机器人")
    private BigDecimal hyTpRccJqr;

    /** 化验表-化验机器人正磷化验计算值1（正磷1池回流阈值） */
    @Excel(name = "化验表-化验机器人正磷化验计算值1", readConverterExp = "正=磷1池回流阈值")
    private BigDecimal hyTp1Yz;

    /** 化验表-化验机器人正磷化验计算值2（正磷2池回流阈值） */
    @Excel(name = "化验表-化验机器人正磷化验计算值2", readConverterExp = "正=磷2池回流阈值")
    private BigDecimal hyTp2Yz;

    /** 化验表-化验机器人正磷化验计算值二沉池（正磷二沉池阈值） */
    @Excel(name = "化验表-化验机器人正磷化验计算值二沉池", readConverterExp = "正=磷二沉池阈值")
    private BigDecimal hyTpRccYz;

    /** 化验表-1#缺氧氨氮 + 化验机器人氨氮化验有效值1（氨氮1池缺氧机器人） */
    @Excel(name = "化验表-1#缺氧氨氮 + 化验机器人氨氮化验有效值1", readConverterExp = "氨=氮1池缺氧机器人")
    private BigDecimal hyNh31Jqr;

    /** 化验表-2#缺氧氨氮 + 化验机器人氨氮化验有效值2（氨氮2池缺氧机器人） */
    @Excel(name = "化验表-2#缺氧氨氮 + 化验机器人氨氮化验有效值2", readConverterExp = "氨=氮2池缺氧机器人")
    private BigDecimal hyNh32Jqr;

    /** 化验表-化验机器人氨氮化验计算值1（氨氮1池缺氧阈值） */
    @Excel(name = "化验表-化验机器人氨氮化验计算值1", readConverterExp = "氨=氮1池缺氧阈值")
    private BigDecimal hyNh31Yz;

    /** 化验表-回流出水计算值1（硝氮1池回流阈值） */
    @Excel(name = "化验表-回流出水计算值1", readConverterExp = "硝=氮1池回流阈值")
    private BigDecimal hyNo3Hlc1Yz;

    /** 化验表-化验机器人氨氮化验计算值2（氨氮2池缺氧阈值） */
    @Excel(name = "化验表-化验机器人氨氮化验计算值2", readConverterExp = "氨=氮2池缺氧阈值")
    private BigDecimal hyNh32Yz;

    /** 化验表-回流出水计算值2（硝氮2池回流阈值） */
    @Excel(name = "化验表-回流出水计算值2", readConverterExp = "硝=氮2池回流阈值")
    private BigDecimal hyNo3Hlc2Yz;

    /** 化验表-1#好氧池硝酸盐（内回流）+ 回流进水化验机器人有效值1（硝氮1池回流机器人） */
    @Excel(name = "化验表-1#好氧池硝酸盐", readConverterExp = "内=回流")
    private BigDecimal hyNo3Hlj1Jqr;

    /** 化验表-2#好氧池硝酸盐（内回流） + 回流进水化验机器人有效值2（硝氮2池回流机器人） */
    @Excel(name = "化验表-2#好氧池硝酸盐", readConverterExp = "内=回流")
    private BigDecimal hyNo3Hlj2Jqr;

    /** 化验表-碳源投加流量（碳源投加流量） */
    @Excel(name = "化验表-碳源投加流量", readConverterExp = "碳=源投加流量")
    private BigDecimal hyTyll;

    /** 化验表-1#缺氧出口硝酸盐 + 缺氧出水化验机器人有效值1（硝氮1池缺氧机器人） */
    @Excel(name = "化验表-1#缺氧出口硝酸盐 + 缺氧出水化验机器人有效值1", readConverterExp = "硝=氮1池缺氧机器人")
    private BigDecimal hyNo3Qyc1Jqr;

    /** 化验表-2#缺氧出-硝酸盐 + 缺氧出水化验机器人有效值2（硝氮2池缺氧机器人） */
    @Excel(name = "化验表-2#缺氧出-硝酸盐 + 缺氧出水化验机器人有效值2", readConverterExp = "硝=氮2池缺氧机器人")
    private BigDecimal hyNo3Qyc2Jqr;

    /** 化验表-缺氧进水计算值1（硝氮1池缺氧阈值） */
    @Excel(name = "化验表-缺氧进水计算值1", readConverterExp = "硝=氮1池缺氧阈值")
    private BigDecimal hyNo3Qyc1Yz;

    /** 化验表-缺氧进水计算值2（硝氮2池缺氧阈值） */
    @Excel(name = "化验表-缺氧进水计算值2", readConverterExp = "硝=氮2池缺氧阈值")
    private BigDecimal hyNo3Qyc2Yz;

    /** 化验表-进水流量（进水流量） */
    @Excel(name = "化验表-进水流量", readConverterExp = "进=水流量")
    private BigDecimal hyJsll;

    /** 化验表-好氧池硝酸盐（多个池子） */
    @Excel(name = "化验表-好氧池硝酸盐", readConverterExp = "多=个池子")
    private String hyHycxsyAll;

    /** 化验表-缺氧氨氮（多个池子） */
    @Excel(name = "化验表-缺氧氨氮", readConverterExp = "多=个池子")
    private String hyQyanAll;

    /** 化验表-缺氧硝酸盐（多个池子） */
    @Excel(name = "化验表-缺氧硝酸盐", readConverterExp = "多=个池子")
    private String hyQyckxsyAll;

    /** 化验表-好氧池正磷酸盐（多个池子） */
    @Excel(name = "化验表-好氧池正磷酸盐", readConverterExp = "多=个池子")
    private String hyHyzlsyAll;

    /** 计算表-进水碳氮比 */
    @Excel(name = "计算表-进水碳氮比")
    private BigDecimal jsJsTdb;

    /** 计算表-进水碳磷比 */
    @Excel(name = "计算表-进水碳磷比")
    private BigDecimal jsJsTlb;

    /** 计算表-进水BOD与COD比值(生化性) */
    @Excel(name = "计算表-进水BOD与COD比值(生化性)")
    private BigDecimal jsJsBodBCod;

    /** 计算表-厌氧区停留时间 */
    @Excel(name = "计算表-厌氧区停留时间")
    private BigDecimal jsYyqHrt;

    /** 计算表-缺氧区停留时间 */
    @Excel(name = "计算表-缺氧区停留时间")
    private BigDecimal jsQyqHrt;

    /** 计算表-好氧区停留时间 */
    @Excel(name = "计算表-好氧区停留时间")
    private BigDecimal jsHyqHrt;

    /** 计算表-挥发性污泥浓度占比 */
    @Excel(name = "计算表-挥发性污泥浓度占比")
    private BigDecimal jsHfxwnndzb;

    /** 计算表-F/M（污泥负荷） */
    @Excel(name = "计算表-F/M", readConverterExp = "污=泥负荷")
    private BigDecimal jsFM;

    /** 计算表-过栅流速 */
    @Excel(name = "计算表-过栅流速")
    private BigDecimal jsGsls;

    /** 计算表-第1道粗格栅过栅流速 */
    @Excel(name = "计算表-第1道粗格栅过栅流速")
    private BigDecimal jsGslsOne;

    /** 计算表-第2道粗格栅过栅流速 */
    @Excel(name = "计算表-第2道粗格栅过栅流速")
    private BigDecimal jsGslsTwo;

    /** 计算表-细格栅过栅流速 */
    @Excel(name = "计算表-细格栅过栅流速")
    private BigDecimal jsXgsGsls;

    /** 计算表-旋流沉砂池表面负荷 */
    @Excel(name = "计算表-旋流沉砂池表面负荷")
    private BigDecimal jsXlcscBmfh;

    /** 计算表-旋流沉砂池停留时间 */
    @Excel(name = "计算表-旋流沉砂池停留时间")
    private BigDecimal jsXlcscHrt;

    /** 计算表-初次沉淀池表面负荷 */
    @Excel(name = "计算表-初次沉淀池表面负荷")
    private BigDecimal jsCccdcBmfh;

    /** 计算表-初次沉淀池停留时间 */
    @Excel(name = "计算表-初次沉淀池停留时间")
    private BigDecimal jsCccdcHrt;

    /** 计算表-二沉池表面负荷 */
    @Excel(name = "计算表-二沉池表面负荷")
    private BigDecimal jsEccBmfh;

    /** 计算表-二沉池停留时间 */
    @Excel(name = "计算表-二沉池停留时间")
    private BigDecimal jsEccHrt;

    /** 计算表-二沉池固体负荷 */
    @Excel(name = "计算表-二沉池固体负荷")
    private BigDecimal jsEccGtfh;

    /** 计算表-次氯酸钠接触时间 */
    @Excel(name = "计算表-次氯酸钠接触时间")
    private BigDecimal jsClsnJcsj;

    /** 计算表-斜管沉淀池清水区上升流速 */
    @Excel(name = "计算表-斜管沉淀池清水区上升流速")
    private BigDecimal jsXgcdcQsqSsls;

    /** 计算表-外回流比 */
    @Excel(name = "计算表-外回流比")
    private BigDecimal jsWhlb;

    @Excel(name = "计算表-外回流比-新的计算方式")
    private BigDecimal jsWhlbRN;

    /** 计算表-内回流比 */
    @Excel(name = "计算表-内回流比")
    private BigDecimal jsNhlb;

    /** 计算表-万吨水产泥率 */
    @Excel(name = "计算表-万吨水产泥率")
    private BigDecimal jsWdscnl;

    /** 计算表-生化池气水比 */
    @Excel(name = "计算表-生化池气水比")
    private BigDecimal jsQsb;

    /** 计算表-反冲洗水量 */
    @Excel(name = "计算表-反冲洗水量")
    private BigDecimal jsFcxsl;

    /** 计算表-反冲洗水量比例 */
    @Excel(name = "计算表-反冲洗水量比例")
    private BigDecimal jsFcxslbl;

    /** 计算-出水COD超污染物限制 */
    @Excel(name = "计算-出水COD超污染物限制")
    private BigDecimal jsCsCodCwrwxz;

    /** 计算-出水SS超污染物限制 */
    @Excel(name = "计算-出水SS超污染物限制")
    private BigDecimal jsCsSsCwrwxz;

    /** 计算-出水总氮超污染物限制 */
    @Excel(name = "计算-出水总氮超污染物限制")
    private BigDecimal jsCsZdCwrwxz;

    /** 计算-出水总磷超污染物限制 */
    @Excel(name = "计算-出水总磷超污染物限制")
    private BigDecimal jsCsZlCwrwxz;

    /** 计算-出水氨氮超污染物限制 */
    @Excel(name = "计算-出水氨氮超污染物限制")
    private BigDecimal jsCsAdCwrwxz;

    /** 计算-进水COD超污染物负荷 */
    @Excel(name = "计算-进水COD超污染物负荷")
    private BigDecimal jsJsCodCwrwfh;

    /** 计算-进水SS超污染物负荷 */
    @Excel(name = "计算-进水SS超污染物负荷")
    private BigDecimal jsJsSsCwrwfh;

    /** 计算-进水总氮超污染物负荷 */
    @Excel(name = "计算-进水总氮超污染物负荷")
    private BigDecimal jsJsZdCwrwfh;

    /** 计算-进水总磷超污染物负荷 */
    @Excel(name = "计算-进水总磷超污染物负荷")
    private BigDecimal jsJsZlCwrwfh;

    /** 计算-进水氨氮超污染物负荷 */
    @Excel(name = "计算-进水氨氮超污染物负荷")
    private BigDecimal jsJsAdCwrwfh;

    /** 计算-进水COD超污染物限制 */
    @Excel(name = "计算-进水COD超污染物限制")
    private BigDecimal jsJsCodCwrwxz;

    /** 计算-进水SS超污染物限制 */
    @Excel(name = "计算-进水SS超污染物限制")
    private BigDecimal jsJsSsCwrwxz;

    /** 计算-进水总氮超污染物限制 */
    @Excel(name = "计算-进水总氮超污染物限制")
    private BigDecimal jsJsZdCwrwxz;

    /** 计算-进水总磷超污染物限制 */
    @Excel(name = "计算-进水总磷超污染物限制")
    private BigDecimal jsJsZlCwrwxz;

    /** 计算-进水氨氮超污染物限制 */
    @Excel(name = "计算-进水氨氮超污染物限制")
    private BigDecimal jsJsAdCwrwxz;

    /** 删除标志（0代表存在 2代表删除） */
    private Long delFlag;

    /** 乐观锁 */
    @Excel(name = "乐观锁")
    private Long revision;

    //2024年09月10日10:47:07 新增的请求参数
    /**  开始时间 */
    private String timeBegin;

    /** 截止时间 */
    private String timeEnd;
}
