package com.slibra.business.domain;

import java.math.BigDecimal;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;

/**
 * 信义计算数据对象 t_xinyi_calculate
 * 
 * @author slibra
 * @date 2024-06-07
 */

@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class TXinyiCalculate extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 日期（2024/05/04格式） */
    @Excel(name = "日期", readConverterExp = "2=024/05/04格式")
    private String testDate;

    /** 小时（2024/05/04 19格式的） */
    @Excel(name = "小时", readConverterExp = "2=024/05/04,1=9格式的")
    private String testHour;

    /** 化验时间（2024/05/29 22:00格式的） */
    @Excel(name = "化验时间", readConverterExp = "2=024/05/29,2=2:00格式的")
    private String testTime;

    /** 进水碳氮比 */
    @Excel(name = "进水碳氮比")
    private BigDecimal jsTdb;

    /** 进水碳磷比 */
    @Excel(name = "进水碳磷比")
    private BigDecimal jsTlb;

    /** 进水BOD与COD比值(生化性) */
    @Excel(name = "进水BOD与COD比值(生化性)")
    private BigDecimal jsBodBCod;

    /** 厌氧区停留时间 */
    @Excel(name = "厌氧区停留时间")
    private BigDecimal yyqHrt;

    /** 缺氧区停留时间 */
    @Excel(name = "缺氧区停留时间")
    private BigDecimal qyqHrt;

    /** 好氧区停留时间 */
    @Excel(name = "好氧区停留时间")
    private BigDecimal hyqHrt;

    /** 挥发性污泥浓度占比 */
    @Excel(name = "挥发性污泥浓度占比")
    private BigDecimal HFXWNNDZB;

    /** F/M（污泥负荷） */
    @Excel(name = "F/M", readConverterExp = "污=泥负荷")
    private BigDecimal fM;

    /** 过栅流速 */
    @Excel(name = "过栅流速")
    private BigDecimal GSLS;

    /** 第1道粗格栅过栅流速 */
    @Excel(name = "第1道粗格栅过栅流速")
    private BigDecimal gslsOne;

    /** 第2道粗格栅过栅流速 */
    @Excel(name = "第2道粗格栅过栅流速")
    private BigDecimal gslsTwo;

    /** 细格栅过栅流速 */
    @Excel(name = "细格栅过栅流速")
    private BigDecimal xgsGsls;

    /** 旋流沉砂池表面负荷 */
    @Excel(name = "旋流沉砂池表面负荷")
    private BigDecimal xlcscBmfh;

    /** 旋流沉砂池停留时间 */
    @Excel(name = "旋流沉砂池停留时间")
    private BigDecimal xlcscHrt;

    /** 初次沉淀池表面负荷 */
    @Excel(name = "初次沉淀池表面负荷")
    private BigDecimal cccdcBmfh;

    /** 初次沉淀池停留时间 */
    @Excel(name = "初次沉淀池停留时间")
    private BigDecimal cccdcHrt;

    /** 二沉池表面负荷 */
    @Excel(name = "二沉池表面负荷")
    private BigDecimal eccBmfh;

    /** 二沉池停留时间 */
    @Excel(name = "二沉池停留时间")
    private BigDecimal eccHrt;

    /** 二沉池固体负荷 */
    @Excel(name = "二沉池固体负荷")
    private BigDecimal eccGtfh;

    /** 次氯酸钠接触时间 */
    @Excel(name = "次氯酸钠接触时间")
    private BigDecimal clsnJcsj;

    /** 斜管沉淀池清水区上升流速 */
    @Excel(name = "斜管沉淀池清水区上升流速")
    private BigDecimal xgcdcQsqSsls;

    /** 外回流比 */
    @Excel(name = "外回流比")
    private BigDecimal WHLB;

    @Excel(name = "外回流比，新的计算方式")
    private BigDecimal whlRN;

    /** 内回流比 */
    @Excel(name = "内回流比")
    private BigDecimal NHLB;

    /** 万吨水产泥率 */
    @Excel(name = "万吨水产泥率")
    private BigDecimal WDSCNL;

    /** 生化池气水比 */
    @Excel(name = "生化池气水比")
    private BigDecimal QSB;

    /** 反冲洗水量 */
    @Excel(name = "反冲洗水量")
    private BigDecimal FCXSL;

    /** 反冲洗水量比例 */
    @Excel(name = "反冲洗水量比例")
    private BigDecimal FCXSLBL;

    /** 出水COD超污染物限制 */
    @Excel(name = "出水COD超污染物限制")
    private BigDecimal csCodCwrwxz;

    /** 出水SS超污染物限制 */
    @Excel(name = "出水SS超污染物限制")
    private BigDecimal csSsCwrwxz;

    /** 出水总氮超污染物限制 */
    @Excel(name = "出水总氮超污染物限制")
    private BigDecimal csZdCwrwxz;

    /** 出水总磷超污染物限制 */
    @Excel(name = "出水总磷超污染物限制")
    private BigDecimal csZlCwrwxz;

    /** 出水氨氮超污染物限制 */
    @Excel(name = "出水氨氮超污染物限制")
    private BigDecimal csAdCwrwxz;

    /** 进水COD超污染物负荷 */
    @Excel(name = "进水COD超污染物负荷")
    private BigDecimal jsCodCwrwfh;

    /** 进水SS超污染物负荷 */
    @Excel(name = "进水SS超污染物负荷")
    private BigDecimal jsSsCwrwfh;

    /** 进水总氮超污染物负荷 */
    @Excel(name = "进水总氮超污染物负荷")
    private BigDecimal jsZdCwrwfh;

    /** 进水总磷超污染物负荷 */
    @Excel(name = "进水总磷超污染物负荷")
    private BigDecimal jsZlCwrwfh;

    /** 进水氨氮超污染物负荷 */
    @Excel(name = "进水氨氮超污染物负荷")
    private BigDecimal jsAdCwrwfh;

    /** 进水COD超污染物限制 */
    @Excel(name = "进水COD超污染物限制")
    private BigDecimal jsCodCwrwxz;

    /** 进水SS超污染物限制 */
    @Excel(name = "进水SS超污染物限制")
    private BigDecimal jsSsCwrwxz;

    /** 进水总氮超污染物限制 */
    @Excel(name = "进水总氮超污染物限制")
    private BigDecimal jsZdCwrwxz;

    /** 进水总磷超污染物限制 */
    @Excel(name = "进水总磷超污染物限制")
    private BigDecimal jsZlCwrwxz;

    /** 进水氨氮超污染物限制 */
    @Excel(name = "进水氨氮超污染物限制")
    private BigDecimal jsAdCwrwxz;

    /** 删除标志（0代表存在 2代表删除） */
    private Long delFlag;

    /** 乐观锁 */
    @Excel(name = "乐观锁")
    private Long revision;

    //2024年09月10日10:47:07 新增的请求参数
    /**  开始时间 */
    private String timeBegin;

    /** 截止时间 */
    private String timeEnd;
}
