package com.slibra.business.domain;

import java.math.BigDecimal;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;

/**
 * 碳排放关联其他计算指标对象 t_xinyi_carbon_extra
 * 
 * @author slibra
 * @date 2024-08-26
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class TXinyiCarbonExtra extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 碳排放主表ID */
    @Excel(name = "碳排放主表ID")
    private Long majorId;

    /** 字典编码（字典ID） */
    @Excel(name = "字典编码", readConverterExp = "字=典ID")
    private Long dictCode;

    /** 字典名称（具体指标值） */
    @Excel(name = "字典名称", readConverterExp = "具=体指标值")
    private String dictLabel;

    /** 类型（0外加碳源矿化产生的化石源CO₂碳排放量  1固定式能源燃料消耗产生的碳排放量 2污水处理阶段药剂消耗产生的碳排放量 3热泵技术-替碳量 4污泥厌氧消化沼气利用的替碳量 5污泥焚烧或热解热能利用的替碳量） */
    @Excel(name = "类型", readConverterExp = "0=外加碳源矿化产生的化石源CO₂碳排放量,1=固定式能源燃料消耗产生的碳排放量,2=污水处理阶段药剂消耗产生的碳排放量,3=热泵技术-替碳量,4=污泥厌氧消化沼气利用的替碳量,5=污泥焚烧或热解热能利用的替碳量")
    private Integer type;

    /** 数量 */
    @Excel(name = "数量")
    private BigDecimal amount;

    /** 厌氧消化沼气富余热能利用量/污泥焚烧或热解热能利用量 */
    @Excel(name = "厌氧消化沼气富余热能利用量/污泥焚烧或热解热能利用量")
    private BigDecimal lyl;

    /** 沼气提纯并网的天然气量/对应焓值 */
    @Excel(name = "沼气提纯并网的天然气量/对应焓值")
    private BigDecimal hz;

    /** 值 */
    @Excel(name = "值")
    private BigDecimal val;

    /** 删除标志（0代表存在 2代表删除） */
    private Long delFlag;

    /** 乐观锁 */
    @Excel(name = "乐观锁")
    private Long revision;
}
