package com.slibra.business.domain;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.List;
import java.util.Map;

import com.slibra.business.res.ChartBasic;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;

/**
 * 碳排放主对象 t_xinyi_carbon_major
 *
 * @author slibra
 * @date 2024-08-24
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class TXinyiCarbonMajor extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 所属水厂 */
    @Excel(name = "所属水厂")
    private String addOwner;

    /** 省市ID */
    @Excel(name = "省市ID")
    private Long provinceId;

    /** 省市名称 */
    @Excel(name = "省市名称")
    private String provinceName;

    /** 所属年份（2024） */
    @Excel(name = "所属年份", readConverterExp = "2024")
    private String addYear;

    /** 所属年月（2024-02） */
    @Excel(name = "所属年月", readConverterExp = "2024-02")
    private String addYearMonth;

    /** 污水处理-化石源碳矿化产生的碳排放量-月处理水量 */
    @Excel(name = "污水处理-化石源碳矿化产生的碳排放量-月处理水量")
    private BigDecimal wsHsytkhClsl;

    /** 污水处理-化石源碳矿化产生的碳排放量-进水cod */
    @Excel(name = "污水处理-化石源碳矿化产生的碳排放量-进水cod")
    private BigDecimal wsHsytkhJsCod;

    /** 污水处理-化石源碳矿化产生的碳排放量-出水cod */
    @Excel(name = "污水处理-化石源碳矿化产生的碳排放量-出水cod")
    private BigDecimal wsHsytkhCsCod;

    /** 污水处理-化石源的CO₂排放量 */
    @Excel(name = "污水处理-化石源的CO₂排放量")
    private BigDecimal wsHsytkhCo2;

    /** 污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-月处理水量 */
    @Excel(name = "污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-月处理水量")
    private BigDecimal wsSjclCh4Clsl;

    /** 污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-进水cod */
    @Excel(name = "污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-进水cod")
    private BigDecimal wsSjclCh4JsCod;

    /** 污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-出水cod */
    @Excel(name = "污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-出水cod")
    private BigDecimal wsSjclCh4CsCod;

    /** 污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-排放因子 */
    @Excel(name = "污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-排放因子")
    private BigDecimal wsSjclCh4Pfyz;

    /** 污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-提升泵 */
    @Excel(name = "污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-提升泵")
    private BigDecimal wsSjclCh4Tsb;

    /** 污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-沉砂池 */
    @Excel(name = "污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量-沉砂池")
    private BigDecimal wsSjclCh4Csc;

    /** 污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量 */
    @Excel(name = "污水处理-污水收集提升和处理阶段排放的CH₄的CO₂当量")
    private BigDecimal wsSjclCh4Co2;

    /** 污水处理-污水生物处理脱氮过程排放的N₂O的CO₂当量-月处理水量 */
    @Excel(name = "污水处理-污水生物处理脱氮过程排放的N₂O的CO₂当量-月处理水量")
    private BigDecimal wsTdN2oClsl;

    /** 污水处理-污水生物处理脱氮过程排放的N₂O的CO₂当量-进水tn */
    @Excel(name = "污水处理-污水生物处理脱氮过程排放的N₂O的CO₂当量-进水tn")
    private BigDecimal wsTdN2oJsTn;

    /** 污水处理-污水生物处理脱氮过程排放的N₂O的CO₂当量-出水tn */
    @Excel(name = "污水处理-污水生物处理脱氮过程排放的N₂O的CO₂当量-出水tn")
    private BigDecimal wsTdN2oCsTn;

    /** 污水处理-污水生物处理脱氮过程排放的N₂O的CO₂当量-排放因子 */
    @Excel(name = "污水处理-污水生物处理脱氮过程排放的N₂O的CO₂当量-排放因子")
    private BigDecimal wsTdN2oPfyz;

    /** 污水处理-污水处理阶段排放的N₂O的CO₂当量 */
    @Excel(name = "污水处理-污水处理阶段排放的N₂O的CO₂当量")
    private BigDecimal wsTdN2oCo2;

    /** 能源、药剂碳排-电量消耗-总耗电 */
    @Excel(name = "能源、药剂碳排-电量消耗-总耗电")
    private BigDecimal nyyjDlxhZhdl;

    /** 能源、药剂碳排-电量消耗-总耗电碳排放量 */
    @Excel(name = "能源、药剂碳排-电量消耗-总耗电碳排放量")
    private BigDecimal nyyjDlxhZhdlCo2;

    /** 能源、药剂碳排-电量消耗-进水泵房 */
    @Excel(name = "能源、药剂碳排-电量消耗-进水泵房")
    private BigDecimal nyyjDlxhJsbf;

    /** 能源、药剂碳排-电量消耗-进水泵房碳排 */
    @Excel(name = "能源、药剂碳排-电量消耗-进水泵房碳排")
    private BigDecimal nyyjDlxhJsbfCo2;

    /** 能源、药剂碳排-电量消耗-鼓风机房 */
    @Excel(name = "能源、药剂碳排-电量消耗-鼓风机房")
    private BigDecimal nyyjDlxhGfjf;

    /** 能源、药剂碳排-电量消耗-鼓风机房碳排 */
    @Excel(name = "能源、药剂碳排-电量消耗-鼓风机房碳排")
    private BigDecimal nyyjDlxhGfjfCo2;

    /** 能源、药剂碳排-电量消耗-脱水机房 */
    @Excel(name = "能源、药剂碳排-电量消耗-脱水机房")
    private BigDecimal nyyjDlxhTsjf;

    /** 能源、药剂碳排-电量消耗-脱水机房碳排 */
    @Excel(name = "能源、药剂碳排-电量消耗-脱水机房碳排")
    private BigDecimal nyyjDlxhTsjfCo2;

    /** 能源、药剂碳排-电量消耗-消毒间 */
    @Excel(name = "能源、药剂碳排-电量消耗-消毒间")
    private BigDecimal nyyjDlxhXdj;

    /** 能源、药剂碳排-电量消耗-消毒间碳排 */
    @Excel(name = "能源、药剂碳排-电量消耗-消毒间碳排")
    private BigDecimal nyyjDlxhXdjCo2;

    /** 能源、药剂碳排-电量消耗-深度处理用电 */
    @Excel(name = "能源、药剂碳排-电量消耗-深度处理用电")
    private BigDecimal nyyjDlxhSdcl;

    /** 能源、药剂碳排-电量消耗-深度处理用电碳排 */
    @Excel(name = "能源、药剂碳排-电量消耗-深度处理用电碳排")
    private BigDecimal nyyjDlxhSdclCo2;

    /** 能源、药剂碳排-电量消耗-污泥处置 */
    @Excel(name = "能源、药剂碳排-电量消耗-污泥处置")
    private BigDecimal nyyjDlxhWncz;

    /** 能源、药剂碳排-电量消耗-污泥处置碳排 */
    @Excel(name = "能源、药剂碳排-电量消耗-污泥处置碳排")
    private BigDecimal nyyjDlxhWnczCo2;

    /** 能源、药剂碳排-电量消耗-生活区 */
    @Excel(name = "能源、药剂碳排-电量消耗-生活区")
    private BigDecimal nyyjDlxhShq;

    /** 能源、药剂碳排-电量消耗-生活区碳排 */
    @Excel(name = "能源、药剂碳排-电量消耗-生活区碳排")
    private BigDecimal nyyjDlxhShqCo2;

    /** 能源、药剂碳排-电量消耗-其他耗电区 */
    @Excel(name = "能源、药剂碳排-电量消耗-其他耗电区")
    private BigDecimal nyyjDlxhQt;

    /** 能源、药剂碳排-电量消耗-其他耗电区碳排 */
    @Excel(name = "能源、药剂碳排-电量消耗-其他耗电区碳排")
    private BigDecimal nyyjDlxhQtCo2;

    /** 能源、药剂碳排-净购入热力消耗产生的碳排放量-蒸汽 */
    @Excel(name = "能源、药剂碳排-净购入热力消耗产生的碳排放量-蒸汽")
    private BigDecimal nyyjGrrlZq;

    /** 能源、药剂碳排-净购入热力消耗产生的碳排放量-对应焓值 */
    @Excel(name = "能源、药剂碳排-净购入热力消耗产生的碳排放量-对应焓值")
    private BigDecimal nyyjGrrlDyhz;

    /** 能源、药剂碳排-净购入热力消耗产生的碳排放量-热力 */
    @Excel(name = "能源、药剂碳排-净购入热力消耗产生的碳排放量-热力")
    private BigDecimal nyyjGrrlRl;

    /** 能源、药剂碳排-净购入热力消耗产生的碳排放量-燃料消耗产生的碳排放量 */
    @Excel(name = "能源、药剂碳排-净购入热力消耗产生的碳排放量-燃料消耗产生的碳排放量")
    private BigDecimal nyyjGrrlCo2;

    /** 污泥处理-污泥厌氧消化沼气收集管路无意泄露的CH₄或沼气火炬燃烧不充分导致的碳排放-沼气产量 */
    @Excel(name = "污泥处理-污泥厌氧消化沼气收集管路无意泄露的CH₄或沼气火炬燃烧不充分导致的碳排放-沼气产量")
    private BigDecimal wnclYyzqZqcl;

    /** 污泥处理-污泥厌氧消化沼气收集管路无意泄露的CH₄或沼气火炬燃烧不充分导致的碳排放-ch-质量分数 */
    @Excel(name = "污泥处理-污泥厌氧消化沼气收集管路无意泄露的CH₄或沼气火炬燃烧不充分导致的碳排放-ch-质量分数")
    private BigDecimal wnclYyzqChZlfs;

    /** 污泥处理-污泥厌氧消化沼气收集管路无意泄露的CH₄或沼气火炬燃烧不充分导致的碳排放-污泥厌氧消化过程排放的CH₄的CO₂当量（t CO₂-eq/月） */
    @Excel(name = "污泥处理-污泥厌氧消化沼气收集管路无意泄露的CH₄或沼气火炬燃烧不充分导致的碳排放-污泥厌氧消化过程排放的CH₄的CO₂当量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal wnclYyzqCo2;

    /** 污泥处理-单独处理污泥厌氧消化过程产生的碳排放量-沼液处理量 （m³/月） */
    @Excel(name = "污泥处理-单独处理污泥厌氧消化过程产生的碳排放量-沼液处理量 ", readConverterExp = "m=³/月")
    private BigDecimal wnclDdclZycll;

    /** 污泥处理-单独处理污泥厌氧消化过程产生的碳排放量-沼液处理前TN浓度 */
    @Excel(name = "污泥处理-单独处理污泥厌氧消化过程产生的碳排放量-沼液处理前TN浓度")
    private BigDecimal wnclDdclClqnd;

    /** 污泥处理-单独处理污泥厌氧消化过程产生的碳排放量-沼液处理后TN浓度 */
    @Excel(name = "污泥处理-单独处理污泥厌氧消化过程产生的碳排放量-沼液处理后TN浓度")
    private BigDecimal wnclDdclClhnd;

    /** 污泥处理-单独处理污泥厌氧消化过程产生的碳排放量-处理阶段N₂O的排放因子（kg N₂O-N/kg N） */
    @Excel(name = "污泥处理-单独处理污泥厌氧消化过程产生的碳排放量-处理阶段N₂O的排放因子", readConverterExp = "k=g,N=₂O-N/kg,N=")
    private BigDecimal wnclDdclPfyz;

    /** 污泥处理-单独处理污泥厌氧消化过程产生的碳排放量-单独处理污泥厌氧消化产生沼液的CO₂当量（t CO₂-eq/月） */
    @Excel(name = "污泥处理-单独处理污泥厌氧消化过程产生的碳排放量-单独处理污泥厌氧消化产生沼液的CO₂当量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal wnclDdclCo2;

    /** 污泥处理-污泥好氧发酵过程生化反应的碳排放-污泥处理好氧发酵量 （kg干污泥/月） */
    @Excel(name = "污泥处理-污泥好氧发酵过程生化反应的碳排放-污泥处理好氧发酵量 ", readConverterExp = "k=g干污泥/月")
    private BigDecimal wnclHyfjFjl;

    /** 污泥处理-污泥好氧发酵过程生化反应的碳排放-污泥好氧发酵过程排放的CH₄的CO₂当量（t CO₂-eq/月） */
    @Excel(name = "污泥处理-污泥好氧发酵过程生化反应的碳排放-污泥好氧发酵过程排放的CH₄的CO₂当量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal wnclHyfjCh4Co2;

    /** 污泥处理-污泥好氧发酵过程生化反应的碳排放-污泥好氧发酵过程排放的N₂O的CO₂当量（t CO₂-eq/月） */
    @Excel(name = "污泥处理-污泥好氧发酵过程生化反应的碳排放-污泥好氧发酵过程排放的N₂O的CO₂当量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal wnclHyfjN2oCo2;

    /** 污泥处理-污泥干化焚烧或协同焚烧过程，化石源碳被氧化产生的化石源CO₂碳排放量-燃料消耗量 （m3/月） */
    @Excel(name = "污泥处理-污泥干化焚烧或协同焚烧过程，化石源碳被氧化产生的化石源CO₂碳排放量-燃料消耗量 ", readConverterExp = "m=3/月")
    private BigDecimal wnclWnfsXhl;

    /** 污泥处理-污泥干化焚烧或协同焚烧过程，化石源碳被氧化产生的化石源CO₂碳排放量-污泥干物质中含碳比例 （%） */
    @Excel(name = "污泥处理-污泥干化焚烧或协同焚烧过程，化石源碳被氧化产生的化石源CO₂碳排放量-污泥干物质中含碳比例 ", readConverterExp = "%=")
    private BigDecimal wnclWnfsHtbl;

    /** 污泥处理-污泥干化焚烧或协同焚烧过程，化石源碳被氧化产生的化石源CO₂碳排放量-污泥好氧发酵过程排放的CH₄的CO₂当量（t CO₂-eq/月） */
    @Excel(name = "污泥处理-污泥干化焚烧或协同焚烧过程，化石源碳被氧化产生的化石源CO₂碳排放量-污泥好氧发酵过程排放的CH₄的CO₂当量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal wnclWnfsCo2;

    /** 污泥处理-污泥焚烧过程不完全燃烧产生的CH₄和N₂O的CO₂排放当量-燃烧类型 */
    @Excel(name = "污泥处理-污泥焚烧过程不完全燃烧产生的CH₄和N₂O的CO₂排放当量-燃烧类型 0半连续-加煤机  1半连续-流化床 2间歇性-加煤机 3间歇性-流化床 4连续燃烧")
    private Integer wnclBwqrsRslx;

    /** 污泥处理-污泥焚烧过程不完全燃烧产生的CH₄和N₂O的CO₂排放当量-污泥处理焚烧量 （t干污泥/月） */
    @Excel(name = "污泥处理-污泥焚烧过程不完全燃烧产生的CH₄和N₂O的CO₂排放当量-污泥处理焚烧量 ", readConverterExp = "t=干污泥/月")
    private BigDecimal wnclBwqrsFsl;

    /** 污泥处理-污泥焚烧过程不完全燃烧产生的CH₄和N₂O的CO₂排放当量-污泥焚烧过程N₂O的排放因子（kg N₂O/t 干污泥） */
    @Excel(name = "污泥处理-污泥焚烧过程不完全燃烧产生的CH₄和N₂O的CO₂排放当量-污泥焚烧过程N₂O的排放因子", readConverterExp = "k=g,N=₂O/t,干=污泥")
    private BigDecimal wnclBwqrsPfyz;

    /** 污泥处理-污泥焚烧过程不完全燃烧产生的CH₄和N₂O的CO₂排放当量-污泥焚烧过程排放的CH₄的CO₂当量（t CO₂-eq/月） */
    @Excel(name = "污泥处理-污泥焚烧过程不完全燃烧产生的CH₄和N₂O的CO₂排放当量-污泥焚烧过程排放的CH₄的CO₂当量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal wnclBwqrsCh4Co2;

    /** 污泥处理-污泥焚烧过程不完全燃烧产生的CH₄和N₂O的CO₂排放当量-污泥焚烧过程排放的N₂O的CO₂当量（t CO₂-eq/月） */
    @Excel(name = "污泥处理-污泥焚烧过程不完全燃烧产生的CH₄和N₂O的CO₂排放当量-污泥焚烧过程排放的N₂O的CO₂当量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal wnclBwqrsN2oCo2;

    /** 污泥处理-污泥热解碳化或气化过程化石源CO-污泥热解消耗量 （kg干污泥/月） */
    @Excel(name = "污泥处理-污泥热解碳化或气化过程化石源CO-污泥热解消耗量 ", readConverterExp = "k=g干污泥/月")
    private BigDecimal wnclWnrjByhXhl;

    /** 污泥处理-污泥热解碳化或气化过程化石源CO-污泥干物质中含碳比例 （%） */
    @Excel(name = "污泥处理-污泥热解碳化或气化过程化石源CO-污泥干物质中含碳比例 ", readConverterExp = "%=")
    private BigDecimal wnclWnrjByhHtbl;

    /** 污泥处理-污泥热解碳化或气化过程化石源CO-污泥热解过程排放的CH₄的CO₂当量（t CO₂-eq/月） */
    @Excel(name = "污泥处理-污泥热解碳化或气化过程化石源CO-污泥热解过程排放的CH₄的CO₂当量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal wnclWnrjByhCo2;

    /** 污泥处理-污泥热解碳化或气化过程产生的CH₄和N₂O的CO₂排放当量-CH₄和N₂O的CO₂排放当量-反应堆类型 */
    @Excel(name = "污泥处理-污泥热解碳化或气化过程产生的CH₄和N₂O的CO₂排放当量-CH₄和N₂O的CO₂排放当量-反应堆类型  0竖井类型  1流化床式 2回转窑式")
    private Integer wnclWnrjQtLx;

    /** 污泥处理-污泥热解碳化或气化过程产生的CH₄和N₂O的CO₂排放当量-CH₄和N₂O的CO₂排放当量-污泥热解消耗量 （t干污泥/月） */
    @Excel(name = "污泥处理-污泥热解碳化或气化过程产生的CH₄和N₂O的CO₂排放当量-CH₄和N₂O的CO₂排放当量-污泥热解消耗量 ", readConverterExp = "t=干污泥/月")
    private BigDecimal wnclWnrjQtXhl;

    /** 污泥处理-污泥热解碳化或气化过程产生的CH₄和N₂O的CO₂排放当量-CH₄和N₂O的CO₂排放当量-污泥热解过程N₂O的排放因子（kg N₂O/t 干污泥） */
    @Excel(name = "污泥处理-污泥热解碳化或气化过程产生的CH₄和N₂O的CO₂排放当量-CH₄和N₂O的CO₂排放当量-污泥热解过程N₂O的排放因子", readConverterExp = "k=g,N=₂O/t,干=污泥")
    private BigDecimal wnclWnrjQtPfyz;

    /** 污泥处理-污泥热解碳化或气化过程产生的CH₄和N₂O的CO₂排放当量-污泥热解过程排放的CH₄的CO₂当量（t CO₂-eq/月） */
    @Excel(name = "污泥处理-污泥热解碳化或气化过程产生的CH₄和N₂O的CO₂排放当量-污泥热解过程排放的CH₄的CO₂当量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal wnclWnrjQtCh4Co2;

    /** 污泥处理-污泥热解碳化或气化过程产生的CH₄和N₂O的CO₂排放当量-污泥热解过程排放的N₂O的CO₂当量（t CO₂-eq/月） */
    @Excel(name = "污泥处理-污泥热解碳化或气化过程产生的CH₄和N₂O的CO₂排放当量-污泥热解过程排放的N₂O的CO₂当量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal wnclWnrjQtN2oCo2;

    /** 替碳、碳汇-光伏-替碳量-总耗电量 （kW·h/月） */
    @Excel(name = "替碳、碳汇-光伏-替碳量-总耗电量 ", readConverterExp = "k=W·h/月")
    private BigDecimal thGfZhdl;

    /** 替碳、碳汇-光伏-替碳量-光伏发电替碳量（t CO₂-eq/月） */
    @Excel(name = "替碳、碳汇-光伏-替碳量-光伏发电替碳量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal thGfCo2;

    /** 替碳、碳汇-再生水回用的替碳量（宜按替代的商业供水的取水、生产和输送的碳排放量计算）-水厂规模 */
    @Excel(name = "替碳、碳汇-再生水回用的替碳量", readConverterExp = "宜=按替代的商业供水的取水、生产和输送的碳排放量计算 0小型  1中型 2大型")
    private Integer thZssScgm;

    /** 替碳、碳汇-再生水回用的替碳量（宜按替代的商业供水的取水、生产和输送的碳排放量计算）-回用水供应量 （m³/月） */
    @Excel(name = "替碳、碳汇-再生水回用的替碳量", readConverterExp = "宜=按替代的商业供水的取水、生产和输送的碳排放量计算")
    private BigDecimal thZssGyl;

    /** 替碳、碳汇-再生水回用的替碳量（宜按替代的商业供水的取水、生产和输送的碳排放量计算）-回用水替代供水的替碳量（t CO₂-eq/月） */
    @Excel(name = "替碳、碳汇-再生水回用的替碳量", readConverterExp = "宜=按替代的商业供水的取水、生产和输送的碳排放量计算")
    private BigDecimal thZssCo2;

    /** 替碳、碳汇-污泥经过厌氧、好氧或碳化处理后，产生的替碳量-回收作为肥料的污泥量 （kg 干污泥/d） */
    @Excel(name = "替碳、碳汇-污泥经过厌氧、好氧或碳化处理后，产生的替碳量-回收作为肥料的污泥量 ", readConverterExp = "k=g,干=污泥/d")
    private BigDecimal thWnClhFlwnl;

    /** 替碳、碳汇-污泥经过厌氧、好氧或碳化处理后，产生的替碳量-污泥产物土地利用的替碳量（t CO₂-eq/月） */
    @Excel(name = "替碳、碳汇-污泥经过厌氧、好氧或碳化处理后，产生的替碳量-污泥产物土地利用的替碳量", readConverterExp = "t=,C=O₂-eq/月")
    private BigDecimal thWnClhCo2;

    /** 污水处理碳排放量 */
    @Excel(name = "污水处理碳排放量")
    private BigDecimal wsclTotalCo2;

    /** 能源、药剂碳排量 */
    @Excel(name = "能源、药剂碳排量")
    private BigDecimal nyyjTotalCo2;

    /** 污泥处理碳排量 */
    @Excel(name = "污泥处理碳排量")
    private BigDecimal wnclTotalCo2;

    /** 替碳、碳汇替碳量 */
    @Excel(name = "替碳、碳汇替碳量")
    private BigDecimal ttthTotalCo2;

    /** 总碳排放量 */
    @Excel(name = "总碳排放量")
    private BigDecimal ztTotalCo2;

    /** 删除标志（0代表存在 2代表删除） */
    private Long delFlag;

    /** 乐观锁 */
    @Excel(name = "乐观锁")
    private Long revision;


    /** 污水厂行业碳排放强度
     * 月碳排放强度 = 月碳排放总量 /  月进水量
     * */

    /** 污水厂行业碳排放强度 */
    @Excel(name = "污水厂行业碳排放强度")
    private BigDecimal wschytpfqd;

    /** 污水厂行业碳排放强度-和同行业平均水平对比: -1:低于；0持平；1:高于 */
    @Excel(name = "污水厂行业碳排放强度-和同行业平均水平对比: -1:低于；0持平；1:高于")
    private Integer exceedAvgHY;

    //下面是一对多的计算结果

    /** 外加碳源矿化产生的化石源CO₂碳排放量 */
    @Excel(name = "外加碳源矿化产生的化石源CO₂碳排放量")
    private BigDecimal wjtykuCo2;

    /** 固定式能源燃料消耗产生的碳排放量 (燃料消耗) */
    @Excel(name = "固定式能源燃料消耗产生的碳排放量 (燃料消耗)")
    private BigDecimal gdsnyrlCo2;

    /** 污水处理阶段药剂消耗产生的碳排放量(药剂消耗) */
    @Excel(name = "污水处理阶段药剂消耗产生的碳排放量(药剂消耗)")
    private BigDecimal wscljdyjxhCo2;

    /** 热泵技术-替碳量 */
    @Excel(name = "热泵技术-替碳量")
    private BigDecimal rbjsTTL;

    /** 污泥厌氧消化沼气利用的替碳量 */
    @Excel(name = "污泥厌氧消化沼气利用的替碳量")
    private BigDecimal wnyyxhzqlyTTL;

    /** 污泥焚烧或热解热能利用的替碳量 */
    @Excel(name = "污泥焚烧或热解热能利用的替碳量")
    private BigDecimal wnfshrjnlyTTL;

    //能源药剂百分比
    /** 能源药剂百分比-电力消耗 */
    @Excel(name = "能源药剂百分比-电力消耗")
    private BigDecimal dlxhPercent;

    /** 能源药剂百分比-药剂消耗 */
    @Excel(name = "能源药剂百分比-药剂消耗")
    private BigDecimal yjxhPercent;

    /** 能源药剂百分比-净购入热力 */
    @Excel(name = "能源药剂百分比-净购入热力")
    private BigDecimal jgrrlPercent;

    /** 能源药剂百分比-燃料消耗 */
    @Excel(name = "能源药剂百分比-燃料消耗")
    private BigDecimal rlxhPercent;



    //下面是查询条件或者是需要每次展示的时候，临时查询使用的


    /**  填报开始时间 */
//    @JsonFormat(pattern = "yyyy-MM-dd")
    private String timeBegin;

    /** 填报截止时间 */
//    @JsonFormat(pattern = "yyyy-MM-dd")
    private String timeEnd;


    /**  核算开始时间 */
//    @JsonFormat(pattern = "yyyy-MM-dd")
    private String hsTimeBegin;

    /** 核算截止时间 */
//    @JsonFormat(pattern = "yyyy-MM-dd")
    private String hsTimeEnd;

    //2024年08月26日10:04:06  新增字段（统计相关）

    /** 污水处理碳排放量-环比上个月 */
    @Excel(name = "污水处理碳排放量-环比上个月")
    private BigDecimal wsclTotalCo2Hb;

    /** 能源、药剂碳排量-环比上个月 */
    @Excel(name = "能源、药剂碳排量-环比上个月")
    private BigDecimal nyyjTotalCo2Hb;

    /** 污泥处理碳排量-环比上个月 */
    @Excel(name = "污泥处理碳排量-环比上个月")
    private BigDecimal wnclTotalCo2Hb;

    /** 替碳、碳汇替碳量-环比上个月 */
    @Excel(name = "替碳、碳汇替碳量-环比上个月")
    private BigDecimal ttthTotalCo2Hb;

    /** 总碳排放量-环比上个月 */
    @Excel(name = "总碳排放量-环比上个月")
    private BigDecimal ztTotalCo2Hb;

    //近七个月的趋势(碳排放量 + 污水厂行业碳排放强度)
    private List<ChartBasic> recent7Datas;


    /*//污泥热解碳化或气化  =
    private BigDecimal wnrjthqhCo2;*/


    //额外的关联多条数据的集合
    private List<TXinyiCarbonExtra> extraList;

    private Map<Integer, List<TXinyiCarbonExtra>> extraMap;







}
