package com.slibra.business.domain;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;

import static com.slibra.common.constant.MyConstants.NUMBER_SCALE_2;

/**
 * 信义化验数据对象 t_xinyi_robot
 * 
 * @author slibra
 * @date 2024-03-30
 */

@Builder
@Data
@AllArgsConstructor
@NoArgsConstructor
public class TXinyiRobot
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long ID;

    /** 日期 */
    @Excel(name = "日期")
    private String vDate;

    /** 时间 */
    @Excel(name = "时间")
    private String vTime;

    /** 时间日期 */
    @Excel(name = "时间日期")
    private String vDateTime;

    /** 化验时间 精确到天 */
    @Excel(name = "化验时间 精确到天")
    private String testDate;

    /** 化验时间 精确到小时 */
    @Excel(name = "化验时间 精确到小时")
    private String testHour;

    /** 化验时间 精确到分钟 */
    @Excel(name = "化验时间 精确到分钟")
    private String testTime;

    /** 仪表COD（在线仪表） */
    @Excel(name = "仪表COD", readConverterExp = "在=线仪表")
    private BigDecimal codYb;

    /** 化验机器人COD化验有效值（COD生物池进水机器人） */
    @Excel(name = "化验机器人COD化验有效值", readConverterExp = "C=OD生物池进水机器人")
    private BigDecimal codJqr;

    /** 化验机器人COD化验计算值（COD生物池进水阈值） */
    @Excel(name = "化验机器人COD化验计算值", readConverterExp = "C=OD生物池进水阈值")
    private BigDecimal codYz;

    /** #1好氧池-正磷酸盐 +  化验机器人正磷化验有效值1（正磷1池回流机器人） */
    @Excel(name = "#1好氧池-正磷酸盐 +  化验机器人正磷化验有效值1", readConverterExp = "正=磷1池回流机器人")
    private BigDecimal tpHl1Jqr;

    /** #2好氧池-正磷酸盐 + 化验机器人正磷化验有效值2（正磷2池回流机器人） */
    @Excel(name = "#2好氧池-正磷酸盐 + 化验机器人正磷化验有效值2", readConverterExp = "正=磷2池回流机器人")
    private BigDecimal tpHl2Jqr;

    /** 二沉池-正磷酸盐 + 化验机器人正磷化验有效值二沉池（正磷二沉池机器人） */
    @Excel(name = "二沉池-正磷酸盐 + 化验机器人正磷化验有效值二沉池", readConverterExp = "正=磷二沉池机器人")
    private BigDecimal tpRccJqr;

    /** 化验机器人正磷化验计算值1（正磷1池回流阈值） */
    @Excel(name = "化验机器人正磷化验计算值1", readConverterExp = "正=磷1池回流阈值")
    private BigDecimal tp1Yz;

    /** 化验机器人正磷化验计算值2（正磷2池回流阈值） */
    @Excel(name = "化验机器人正磷化验计算值2", readConverterExp = "正=磷2池回流阈值")
    private BigDecimal tp2Yz;

    /** 化验机器人正磷化验计算值二沉池（正磷二沉池阈值） */
    @Excel(name = "化验机器人正磷化验计算值二沉池", readConverterExp = "正=磷二沉池阈值")
    private BigDecimal tpRccYz;

    /** 1#缺氧氨氮 + 化验机器人氨氮化验有效值1（氨氮1池缺氧机器人） */
    @Excel(name = "1#缺氧氨氮 + 化验机器人氨氮化验有效值1", readConverterExp = "氨=氮1池缺氧机器人")
    private BigDecimal nh31Jqr;

    /** 2#缺氧氨氮 + 化验机器人氨氮化验有效值2（氨氮2池缺氧机器人） */
    @Excel(name = "2#缺氧氨氮 + 化验机器人氨氮化验有效值2", readConverterExp = "氨=氮2池缺氧机器人")
    private BigDecimal nh32Jqr;

    /** 化验机器人氨氮化验计算值1（氨氮1池缺氧阈值） */
    @Excel(name = "化验机器人氨氮化验计算值1", readConverterExp = "氨=氮1池缺氧阈值")
    private BigDecimal nh31Yz;

    /** 回流出水计算值1（硝氮1池回流阈值） */
    @Excel(name = "回流出水计算值1", readConverterExp = "硝=氮1池回流阈值")
    private BigDecimal no3Hlc1Yz;

    /** 化验机器人氨氮化验计算值2（氨氮2池缺氧阈值） */
    @Excel(name = "化验机器人氨氮化验计算值2", readConverterExp = "氨=氮2池缺氧阈值")
    private BigDecimal nh32Yz;

    /** 回流出水计算值2（硝氮2池回流阈值） */
    @Excel(name = "回流出水计算值2", readConverterExp = "硝=氮2池回流阈值")
    private BigDecimal no3Hlc2Yz;

    /** 1#好氧池硝酸盐（内回流）+ 回流进水化验机器人有效值1（硝氮1池回流机器人） */
    @Excel(name = "1#好氧池硝酸盐", readConverterExp = "内=回流")
    private BigDecimal no3Hlj1Jqr;

    /** 2#好氧池硝酸盐（内回流） + 回流进水化验机器人有效值2（硝氮2池回流机器人） */
    @Excel(name = "2#好氧池硝酸盐", readConverterExp = "内=回流")
    private BigDecimal no3Hlj2Jqr;

    /** 碳源投加流量（碳源投加流量） */
    @Excel(name = "碳源投加流量", readConverterExp = "碳=源投加流量")
    private BigDecimal TYLL;

    /** 1#缺氧出口硝酸盐 + 缺氧出水化验机器人有效值1（硝氮1池缺氧机器人） */
    @Excel(name = "1#缺氧出口硝酸盐 + 缺氧出水化验机器人有效值1", readConverterExp = "硝=氮1池缺氧机器人")
    private BigDecimal no3Qyc1Jqr;

    /** 2#缺氧出-硝酸盐 + 缺氧出水化验机器人有效值2（硝氮2池缺氧机器人） */
    @Excel(name = "2#缺氧出-硝酸盐 + 缺氧出水化验机器人有效值2", readConverterExp = "硝=氮2池缺氧机器人")
    private BigDecimal no3Qyc2Jqr;

    /** 缺氧进水计算值1（硝氮1池缺氧阈值） */
    @Excel(name = "缺氧进水计算值1", readConverterExp = "硝=氮1池缺氧阈值")
    private BigDecimal no3Qyc1Yz;

    /** 缺氧进水计算值2（硝氮2池缺氧阈值） */
    @Excel(name = "缺氧进水计算值2", readConverterExp = "硝=氮2池缺氧阈值")
    private BigDecimal no3Qyc2Yz;

    /** 进水流量（进水流量） */
    @Excel(name = "进水流量", readConverterExp = "进=水流量")
    private BigDecimal JSLL;

    /** 创建时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "创建时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date createdTime;

    //2024年5月29日10:32:26  新增的字段  多个池子合并一个

    /** 好氧池硝酸盐（多个池子） */
    @Excel(name = "好氧池硝酸盐", readConverterExp = "多=个池子")
    private String hycxsyAll;

    /** 缺氧氨氮（多个池子） */
    @Excel(name = "缺氧氨氮", readConverterExp = "多=个池子")
    private String qyanAll;

    /** 缺氧硝酸盐（多个池子） */
    @Excel(name = "缺氧硝酸盐", readConverterExp = "多=个池子")
    private String qyckxsyAll;

    /** 好氧池正磷酸盐（多个池子） */
    @Excel(name = "好氧池正磷酸盐", readConverterExp = "多=个池子")
    private String hyzlsyAll;

    //2024年09月10日10:47:07 新增的请求参数
    /**  开始时间 */
    private String timeBegin;

    /** 截止时间 */
    private String timeEnd;

    public static void main(String[] args) {
        BigDecimal y1 = new BigDecimal("1");
        BigDecimal a = new BigDecimal("2");
        BigDecimal x = new BigDecimal("6");
        BigDecimal x1 = new BigDecimal("4");
        BigDecimal b = new BigDecimal("5");
        System.out.println(y1.add(a.multiply(x.subtract(x1).divide(b,NUMBER_SCALE_2, RoundingMode.HALF_UP))));
        System.out.println(y1.add(a.multiply(x.subtract(x1)).divide(b,NUMBER_SCALE_2, RoundingMode.HALF_UP)));
    }

}
