package com.slibra.business.domain;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.Objects;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.annotation.TableField;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.slibra.common.enums.BusinessEnum;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;

/**
 * 信义告警记录对象 t_xinyi_warning_record
 * 
 * @author slibra
 * @date 2024-05-17
 */
@Builder
@Data
@AllArgsConstructor
@NoArgsConstructor
public class TXinyiWarningRecord extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 类型（0水质报警  1生化报警 2预测报警） */
    @Excel(name = "类型", readConverterExp = "0=水质报警,1=生化报警,2=预测报警")
    private Integer type;

    /** 报警指标（存储字符串） */
    @Excel(name = "报警指标", readConverterExp = "存=储字符串")
    private String category;

    /** 发生时间/预计超标时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm")
    @Excel(name = "发生时间/预计超标时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date time;

    /** 报警原因 */
    @Excel(name = "报警原因")
    private String reason;

    /** 报警值（当前值） */
    @Excel(name = "报警值", readConverterExp = "当=前值")
    private BigDecimal warningVal;

    /** 设计值/标准值 */
    @Excel(name = "设计值/标准值")
    private BigDecimal designVal;

    /** 管控值 */
    @Excel(name = "管控值")
    private BigDecimal controlVal;

    /** 预测值 */
    @Excel(name = "预测值")
    private BigDecimal forecastVal;


    /** 算法来源（0红杉自研  1跃渊） */
    @Excel(name = "算法来源", readConverterExp = "0=红杉自研,1=跃渊")
    private Long functionWay;

    /** 报警级别 */
    @Excel(name = "报警级别")
    private String level;

    /** 报警状态（告警：0报警中 1用户关闭 2系统自动关闭 3用户转为应急处理中  预警：0预警中 1已完成） */
    @Excel(name = "报警状态", readConverterExp = "告=警：0报警中,1=用户关闭,2=系统自动关闭,3=用户转为应急处理中,预=警：0预警中,1=已完成")
    private Integer status;

    /** 是否转为了应急（0否  1是） */
    @Excel(name = "是否转为了应急", readConverterExp = "0=否,1=是")
    private Integer isEmergency;

    /** 关闭报警时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "关闭报警时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date offTime;

    /** 操作人 */
    @Excel(name = "操作人")
    private String operator;

    /** 复盘档案/应急方案Excel的URL */
    @Excel(name = "复盘档案/应急方案Excel的URL")
    private String review;

    /** 是否使用了大模型推送的决策方案（0否 1是） */
    @Excel(name = "是否使用了大模型推送的决策方案", readConverterExp = "0=否,1=是")
    private Integer useRecommend;

    /** 进出水类型：0进水  1出水 */
    @Excel(name = "进出水类型：0进水  1出水")
    private Integer waterType;

    /** 报警类型：0超标准值、 1超管控值、 2仪表故障（断点、连续）、 3数据异常（突变、异常） */
    @Excel(name = "报警类型：0超标准值、 1超管控值、 2仪表故障", readConverterExp = "断=点、连续")
    private Integer symbol;

    /** 超污染物限制：计算公式为：当前氨氮/氨氮设计值 或者 当前氨氮/氨氮管控值（智能工单使用） */
    @Excel(name = "超污染物限制：计算公式为：当前氨氮/氨氮设计值 或者 当前氨氮/氨氮管控值", readConverterExp = "智=能工单使用")
    private BigDecimal cwrwxz;

    /** 超污染物负荷值：计算公式为：当前水量与氨氮乘积  /  设计水量与设计进水氨氮的乘积（智能工单使用） */
    @Excel(name = "超污染物负荷值：计算公式为：当前水量与氨氮乘积  /  设计水量与设计进水氨氮的乘积", readConverterExp = "智=能工单使用")
    private BigDecimal cwrwfhz;

    /** 删除标志（0代表存在 2代表删除） */
    private Integer delFlag;

    /** 乐观锁 */
    @Excel(name = "乐观锁")
    private Long revision;


    //2024年5月26日18:17:45  额外返回给前端的字段
    //2025年02月13日13:49:45 改成字符串 如果超过30次，就显示30+
    private String counts;//报警次数。

    //2024年7月11日13:37:40 额外返回给前端的字段
    private String warningValStr;

    //请求参数
    private Integer warningStatus;//告警状态 0告警中  1历史告警


    @JsonFormat(pattern = "yyyy-MM-dd HH:mm")
    private Date createTime;


    /** 更新时间 */
    @TableField(exist = false)
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm")
    private Date updateTime;


    private String symbolDesc;

    public String getSymbolDesc() {
        if(Objects.isNull(symbol))
            return null;
        return BusinessEnum.WarningSymbolEnum.getMsgByCode(symbol);
    }

    //2025年03月04日10:33:30 新增的请求参数 时间段范围内的报警
    //开始时间
    private String timeBegin;

    //截止时间
    private String timeEnd;

    public static void main(String[] args) {
        System.out.println(BusinessEnum.WarningSymbolEnum.getMsgByCode(1));
        TXinyiWarningRecord build1 = TXinyiWarningRecord.builder().id(1L).category("a").build();
        TXinyiWarningRecord build2 = TXinyiWarningRecord.builder().id(2L).category("b").build();
        TXinyiWarningRecord build3 = TXinyiWarningRecord.builder().id(1L).category("c").build();
        TXinyiWarningRecord build4 = TXinyiWarningRecord.builder().id(2L).category("a").build();
        ArrayList<TXinyiWarningRecord> list1 = new ArrayList<>();
        list1.add(build1);
        list1.add(build2);
        ArrayList<TXinyiWarningRecord> list2 = new ArrayList<>();
        list2.add(build3);
        list2.add(build4);

        ArrayList<Object> list1Only = new ArrayList<>(list1);
        list1Only.removeAll(list2);
        System.out.println(JSON.toJSONString(list1Only));

        ArrayList<Object> list2Only = new ArrayList<>(list2);
        list2Only.removeAll(list1);
        System.out.println(JSON.toJSONString(list2Only));

    }

    public void setCategory() {
    }


    //重写 equals 和 hashCode  默认只要报警分类一样，就算是相同的报警
    @Override
    public final boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof TXinyiWarningRecord)) return false;

        TXinyiWarningRecord that = (TXinyiWarningRecord) o;
        return Objects.equals(category, that.category);
    }

    @Override
    public int hashCode() {
        return Objects.hash(category);
    }
}
