package com.slibra.business.mapper;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

import com.slibra.business.domain.TXinyiIndustry;
import com.slibra.business.res.ChartBasic;
import com.slibra.business.res.MedicineChart;
import com.slibra.common.core.domain.DecisionReq;
import org.apache.ibatis.annotations.Param;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 信义工业数据Mapper接口
 *
 * @author slibra
 * @date 2024-03-23
 */
public interface TXinyiIndustryMapper
{
    /**
     * 查询信义工业数据
     *
     * @param ID 信义工业数据主键
     * @return 信义工业数据
     */
    public TXinyiIndustry selectTXinyiIndustryByID(Long ID);

    /**
     * 查询信义工业数据列表
     *
     * @param tXinyiIndustry 信义工业数据
     * @return 信义工业数据集合
     */
    public List<TXinyiIndustry> selectTXinyiIndustryList(TXinyiIndustry tXinyiIndustry);

    /**
     * 新增信义工业数据
     *
     * @param tXinyiIndustry 信义工业数据
     * @return 结果
     */
    public int insertTXinyiIndustry(TXinyiIndustry tXinyiIndustry);

    /**
     * 修改信义工业数据
     *
     * @param tXinyiIndustry 信义工业数据
     * @return 结果
     */
    public int updateTXinyiIndustry(TXinyiIndustry tXinyiIndustry);

    /**
     * 删除信义工业数据
     *
     * @param ID 信义工业数据主键
     * @return 结果
     */
    public int deleteTXinyiIndustryByID(Long ID);

    /**
     * 批量删除信义工业数据
     *
     * @param IDs 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTXinyiIndustryByIDs(Long[] IDs);

    //通过时间获取唯一的一条记录
    TXinyiIndustry getUniqueTXinyiIndustry(String testTime);

    Integer updateTXinyiIndustryCLByBetweenTime(@Param("beginTime") String beginTime, @Param("endTime") String endTime, @Param("cljyssll") BigDecimal cljyssll);
    Integer updateTXinyiIndustrySJByBetweenTime(@Param("beginTime") String beginTime, @Param("endTime") String endTime, @Param("sjtyjly") BigDecimal sjtyjly);

    String getLastHour();

    String getLastMinute();

    List<HashMap<String, Object>> selectLast10RecordsForDecision();

    List<DecisionReq> selectLast10RecordsForDecisionOnlyIndustry();

    List<DecisionReq> selectLast10RecordsForDecisionOnlyIndustryByHour(String hour);

    TXinyiIndustry selectTXinyiIndustryNewest();

    List<TXinyiIndustry> selectNIndustry(int size);

    List<TXinyiIndustry> selectNIndustryBeforeHour(@Param("size") int int8, @Param("testHour") String testHour);

    TXinyiIndustry selectIndustryAvgByDate(String date);


    /**
     * 查询信义工业数据
     *
     * @return 总条数
     */
    int getCount();

    List<TXinyiIndustry> selectTXinyiIndustryListByPage(@Param("start")  int i, @Param("end")  int size);

    List<ChartBasic> selectJSLByDate(@Param("start") String dayBefore3Str, @Param("end") String nowDateStr);

    List<ChartBasic> selectJsCodByDate(@Param("start") String dayBefore3Str, @Param("end") String nowDateStr);

    List<ChartBasic> selectJsTnByDate(@Param("start") String dayBefore3Str, @Param("end") String nowDateStr);

    List<ChartBasic> selectTytzjlByDate(@Param("start") String dayBefore3Str, @Param("end") String nowDateStr);

    BigDecimal getTotalTodayCSL(String date);

    BigDecimal getAvgJSCodByDate(@Param("dateBegin") String dateBegin, @Param("dateEnd") String dateEnd);

    BigDecimal getAvgCSCodByDate(@Param("dateBegin") String dateBegin, @Param("dateEnd") String dateEnd);

    BigDecimal getAvgJSTnByDate(@Param("dateBegin") String dateBegin, @Param("dateEnd") String dateEnd);

    BigDecimal getAvgJSNh3ByDate(@Param("dateBegin") String dateBegin, @Param("dateEnd") String dateEnd);

    List<MedicineChart> smartAddCharListNew(@Param("dateBegin") String dateBegin, @Param("dateEnd") String dateEnd);

    List<TXinyiIndustry> selectTXinyiIndustryListNew(TXinyiIndustry build);
}
