package com.slibra.business.mapper;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;

import com.slibra.business.domain.TXinyiLaboratory;
import com.slibra.business.domain.TXinyiRobot;
import com.slibra.business.res.ChartBasic;
import org.apache.ibatis.annotations.Param;

/**
 * 信义化验数据Mapper接口
 * 
 * @author slibra
 * @date 2024-03-30
 */
public interface TXinyiRobotMapper 
{
    /**
     * 查询信义化验数据
     * 
     * @param ID 信义化验数据主键
     * @return 信义化验数据
     */
    public TXinyiRobot selectTXinyiRobotByID(Long ID);

    /**
     * 查询信义化验数据列表
     * 
     * @param tXinyiRobot 信义化验数据
     * @return 信义化验数据集合
     */
    public List<TXinyiRobot> selectTXinyiRobotList(TXinyiRobot tXinyiRobot);

    /**
     * 新增信义化验数据
     * 
     * @param tXinyiRobot 信义化验数据
     * @return 结果
     */
    public int insertTXinyiRobot(TXinyiRobot tXinyiRobot);

    /**
     * 修改信义化验数据
     * 
     * @param tXinyiRobot 信义化验数据
     * @return 结果
     */
    public int updateTXinyiRobot(TXinyiRobot tXinyiRobot);

    /**
     * 删除信义化验数据
     * 
     * @param ID 信义化验数据主键
     * @return 结果
     */
    public int deleteTXinyiRobotByID(Long ID);

    /**
     * 批量删除信义化验数据
     * 
     * @param IDs 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTXinyiRobotByIDs(Long[] IDs);

    String selectLastTime();

    List<TXinyiRobot> selectTXinyiRobotListByTime(String lastTime);

    TXinyiRobot selectNewest();

    List<TXinyiRobot> selectNRobot(int size);

    List<TXinyiRobot> selectNRobotAfterHour(@Param("size") int size, @Param("testHour") String testHour);

    TXinyiRobot selectRebotAvgByDate(String date);

    TXinyiRobot selectTXinyiRobotByAvg(TXinyiRobot tXinyiRobot);

    List<HashMap<String, Object>> selectAvg7Datas();

    List<ChartBasic> selectXSY1ByDate(@Param("start") String dayBefore3Str, @Param("end") String nowDateStr);

    List<ChartBasic> selectXSY2ByDate(@Param("start") String dayBefore3Str, @Param("end") String nowDateStr);

    List<ChartBasic> selectAD1ByDate(@Param("start") String dayBefore3Str, @Param("end") String nowDateStr);

    List<ChartBasic> selectAD2ByDate(@Param("start") String dayBefore3Str, @Param("end") String nowDateStr);

    List<ChartBasic> selectCodByDate(@Param("start") String dayBefore3Str, @Param("end") String nowDateStr);

    BigDecimal getAvgCSXsy1ByDate(@Param("dateBegin") String dateBegin, @Param("dateEnd") String dateEnd);

    BigDecimal getAvgCSXsy2ByDate(@Param("dateBegin") String dateBegin, @Param("dateEnd") String dateEnd);

    BigDecimal getAvgQyNh31ByDate(@Param("dateBegin") String dateBegin, @Param("dateEnd") String dateEnd);

    BigDecimal getAvgQyNh32ByDate(@Param("dateBegin") String dateBegin, @Param("dateEnd") String dateEnd);

    List<TXinyiRobot> selectTXinyiRobotListNew(TXinyiRobot build);
}
