package com.slibra.business.service.impl;

import java.util.List;
import java.util.Objects;

import com.slibra.common.exception.ServiceException;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TPredictConfMapper;
import com.slibra.business.domain.TPredictConf;
import com.slibra.business.service.ITPredictConfService;
import org.springframework.util.CollectionUtils;

/**
 * 机理模型预测配置Service业务层处理
 * 
 * @author slibra
 * @date 2025-02-11
 */
@Service
public class TPredictConfServiceImpl implements ITPredictConfService 
{
    @Autowired
    private TPredictConfMapper tPredictConfMapper;

    /**
     * 查询机理模型预测配置
     * 
     * @param id 机理模型预测配置主键
     * @return 机理模型预测配置
     */
    @Override
    public TPredictConf selectTPredictConfById(Long id)
    {
        return tPredictConfMapper.selectTPredictConfById(id);
    }

    /**
     * 查询机理模型预测配置列表
     * 
     * @param tPredictConf 机理模型预测配置
     * @return 机理模型预测配置
     */
    @Override
    public List<TPredictConf> selectTPredictConfList(TPredictConf tPredictConf)
    {
        return tPredictConfMapper.selectTPredictConfList(tPredictConf);
    }

    /**
     * 新增机理模型预测配置
     * 
     * @param tPredictConf 机理模型预测配置
     * @return 结果
     */
    @Override
    public int insertTPredictConf(TPredictConf tPredictConf)
    {
        tPredictConf.setCreateTime(DateUtils.getNowDate());
        //校验类型
        Integer type = tPredictConf.getType();
        if(Objects.isNull(type))
            throw new ServiceException("必须选择对应的类型");
        //查询同类型的是否已经添加过了
        TPredictConf tPredictConfReq = new TPredictConf();
        tPredictConfReq.setType(type);
        List<TPredictConf> tPredictConfList = this.tPredictConfMapper.selectTPredictConfList(tPredictConfReq);
        if(!CollectionUtils.isEmpty(tPredictConfList))
            throw new ServiceException("对应的预测类型已经有了，不可以重复添加");
        return tPredictConfMapper.insertTPredictConf(tPredictConf);
    }

    /**
     * 修改机理模型预测配置
     * 
     * @param tPredictConf 机理模型预测配置
     * @return 结果
     */
    @Override
    public int updateTPredictConf(TPredictConf tPredictConf)
    {
        Integer type = tPredictConf.getType();
        if(Objects.isNull(type))
            throw new ServiceException("必须选择对应的类型");
        //查询同类型的是否已经添加过了
        TPredictConf tPredictConfReq = new TPredictConf();
        tPredictConfReq.setType(type);
        List<TPredictConf> tPredictConfList = this.tPredictConfMapper.selectTPredictConfList(tPredictConfReq);
        if(!CollectionUtils.isEmpty(tPredictConfList)){
            int size = tPredictConfList.size();
            if(size > 1)
                throw new ServiceException("存在重复的预测类型数据，请检查！");
            //只有一条 判断是不是当前的，如果不是，提示重复
            TPredictConf tPredictConfExists = tPredictConfList.get(0);
            if(!Objects.equals(tPredictConfExists.getId(), tPredictConf.getId()))
                throw new ServiceException("当前要修改的预测类型已经存在了，请检查！");
        }
        tPredictConf.setUpdateTime(DateUtils.getNowDate());
        return tPredictConfMapper.updateTPredictConf(tPredictConf);
    }

    /**
     * 批量删除机理模型预测配置
     * 
     * @param ids 需要删除的机理模型预测配置主键
     * @return 结果
     */
    @Override
    public int deleteTPredictConfByIds(Long[] ids)
    {
        return tPredictConfMapper.deleteTPredictConfByIds(ids);
    }

    /**
     * 删除机理模型预测配置信息
     * 
     * @param id 机理模型预测配置主键
     * @return 结果
     */
    @Override
    public int deleteTPredictConfById(Long id)
    {
        return tPredictConfMapper.deleteTPredictConfById(id);
    }
}
