package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TXinyiAgentAssistantMapper;
import com.slibra.business.domain.TXinyiAgentAssistant;
import com.slibra.business.service.ITXinyiAgentAssistantService;

/**
 * 信义智能体助手配置Service业务层处理
 * 
 * @author slibra
 * @date 2024-05-17
 */
@Service
public class TXinyiAgentAssistantServiceImpl implements ITXinyiAgentAssistantService 
{
    @Autowired
    private TXinyiAgentAssistantMapper tXinyiAgentAssistantMapper;

    /**
     * 查询信义智能体助手配置
     * 
     * @param id 信义智能体助手配置主键
     * @return 信义智能体助手配置
     */
    @Override
    public TXinyiAgentAssistant selectTXinyiAgentAssistantById(Long id)
    {
        return tXinyiAgentAssistantMapper.selectTXinyiAgentAssistantById(id);
    }

    /**
     * 查询信义智能体助手配置列表
     * 
     * @param tXinyiAgentAssistant 信义智能体助手配置
     * @return 信义智能体助手配置
     */
    @Override
    public List<TXinyiAgentAssistant> selectTXinyiAgentAssistantList(TXinyiAgentAssistant tXinyiAgentAssistant)
    {
        return tXinyiAgentAssistantMapper.selectTXinyiAgentAssistantList(tXinyiAgentAssistant);
    }

    /**
     * 新增信义智能体助手配置
     * 
     * @param tXinyiAgentAssistant 信义智能体助手配置
     * @return 结果
     */
    @Override
    public int insertTXinyiAgentAssistant(TXinyiAgentAssistant tXinyiAgentAssistant)
    {
        tXinyiAgentAssistant.setCreateTime(DateUtils.getNowDate());
        return tXinyiAgentAssistantMapper.insertTXinyiAgentAssistant(tXinyiAgentAssistant);
    }

    /**
     * 修改信义智能体助手配置
     * 
     * @param tXinyiAgentAssistant 信义智能体助手配置
     * @return 结果
     */
    @Override
    public int updateTXinyiAgentAssistant(TXinyiAgentAssistant tXinyiAgentAssistant)
    {
        tXinyiAgentAssistant.setUpdateTime(DateUtils.getNowDate());
        return tXinyiAgentAssistantMapper.updateTXinyiAgentAssistant(tXinyiAgentAssistant);
    }

    /**
     * 批量删除信义智能体助手配置
     * 
     * @param ids 需要删除的信义智能体助手配置主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiAgentAssistantByIds(Long[] ids)
    {
        return tXinyiAgentAssistantMapper.deleteTXinyiAgentAssistantByIds(ids);
    }

    /**
     * 删除信义智能体助手配置信息
     * 
     * @param id 信义智能体助手配置主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiAgentAssistantById(Long id)
    {
        return tXinyiAgentAssistantMapper.deleteTXinyiAgentAssistantById(id);
    }
}
