package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TXinyiCarbonExtraMapper;
import com.slibra.business.domain.TXinyiCarbonExtra;
import com.slibra.business.service.ITXinyiCarbonExtraService;

/**
 * 碳排放关联其他计算指标Service业务层处理
 * 
 * @author slibra
 * @date 2024-08-26
 */
@Service
public class TXinyiCarbonExtraServiceImpl implements ITXinyiCarbonExtraService 
{
    @Autowired
    private TXinyiCarbonExtraMapper tXinyiCarbonExtraMapper;

    /**
     * 查询碳排放关联其他计算指标
     * 
     * @param id 碳排放关联其他计算指标主键
     * @return 碳排放关联其他计算指标
     */
    @Override
    public TXinyiCarbonExtra selectTXinyiCarbonExtraById(Long id)
    {
        return tXinyiCarbonExtraMapper.selectTXinyiCarbonExtraById(id);
    }

    /**
     * 查询碳排放关联其他计算指标列表
     * 
     * @param tXinyiCarbonExtra 碳排放关联其他计算指标
     * @return 碳排放关联其他计算指标
     */
    @Override
    public List<TXinyiCarbonExtra> selectTXinyiCarbonExtraList(TXinyiCarbonExtra tXinyiCarbonExtra)
    {
        return tXinyiCarbonExtraMapper.selectTXinyiCarbonExtraList(tXinyiCarbonExtra);
    }

    /**
     * 新增碳排放关联其他计算指标
     * 
     * @param tXinyiCarbonExtra 碳排放关联其他计算指标
     * @return 结果
     */
    @Override
    public int insertTXinyiCarbonExtra(TXinyiCarbonExtra tXinyiCarbonExtra)
    {
        tXinyiCarbonExtra.setCreateTime(DateUtils.getNowDate());
        return tXinyiCarbonExtraMapper.insertTXinyiCarbonExtra(tXinyiCarbonExtra);
    }

    /**
     * 修改碳排放关联其他计算指标
     * 
     * @param tXinyiCarbonExtra 碳排放关联其他计算指标
     * @return 结果
     */
    @Override
    public int updateTXinyiCarbonExtra(TXinyiCarbonExtra tXinyiCarbonExtra)
    {
        tXinyiCarbonExtra.setUpdateTime(DateUtils.getNowDate());
        return tXinyiCarbonExtraMapper.updateTXinyiCarbonExtra(tXinyiCarbonExtra);
    }

    /**
     * 批量删除碳排放关联其他计算指标
     * 
     * @param ids 需要删除的碳排放关联其他计算指标主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiCarbonExtraByIds(Long[] ids)
    {
        return tXinyiCarbonExtraMapper.deleteTXinyiCarbonExtraByIds(ids);
    }

    /**
     * 删除碳排放关联其他计算指标信息
     * 
     * @param id 碳排放关联其他计算指标主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiCarbonExtraById(Long id)
    {
        return tXinyiCarbonExtraMapper.deleteTXinyiCarbonExtraById(id);
    }
}
