package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import com.slibra.common.utils.SecurityUtils;
import com.slibra.common.utils.uuid.IdUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TXinyiChatRecordMapper;
import com.slibra.business.domain.TXinyiChatRecord;
import com.slibra.business.service.ITXinyiChatRecordService;

/**
 * 信义大模型问答记录Service业务层处理
 * 
 * @author slibra
 * @date 2024-05-15
 */
@Service
public class TXinyiChatRecordServiceImpl implements ITXinyiChatRecordService 
{
    @Autowired
    private TXinyiChatRecordMapper tXinyiChatRecordMapper;

    /**
     * 查询信义大模型问答记录
     * 
     * @param id 信义大模型问答记录主键
     * @return 信义大模型问答记录
     */
    @Override
    public TXinyiChatRecord selectTXinyiChatRecordById(Long id)
    {
        return tXinyiChatRecordMapper.selectTXinyiChatRecordById(id);
    }

    /**
     * 查询信义大模型问答记录列表
     * 
     * @param tXinyiChatRecord 信义大模型问答记录
     * @return 信义大模型问答记录
     */
    @Override
    public List<TXinyiChatRecord> selectTXinyiChatRecordList(TXinyiChatRecord tXinyiChatRecord)
    {
        return tXinyiChatRecordMapper.selectTXinyiChatRecordList(tXinyiChatRecord);
    }

    /**
     * 新增信义大模型问答记录
     * 
     * @param tXinyiChatRecord 信义大模型问答记录
     * @return 结果
     */
    @Override
    public int insertTXinyiChatRecord(TXinyiChatRecord tXinyiChatRecord)
    {
        //2025年04月17日10:22:35 前端主动调用接口，模拟调用工单
        tXinyiChatRecord.setSessionId(IdUtils.simpleUUID());
        tXinyiChatRecord.setUserId(String.valueOf(SecurityUtils.getUserId()));
        tXinyiChatRecord.setCreateTime(DateUtils.getNowDate());
        return tXinyiChatRecordMapper.insertTXinyiChatRecord(tXinyiChatRecord);
    }

    /**
     * 修改信义大模型问答记录
     * 
     * @param tXinyiChatRecord 信义大模型问答记录
     * @return 结果
     */
    @Override
    public int updateTXinyiChatRecord(TXinyiChatRecord tXinyiChatRecord)
    {
        tXinyiChatRecord.setUpdateTime(DateUtils.getNowDate());
        return tXinyiChatRecordMapper.updateTXinyiChatRecord(tXinyiChatRecord);
    }

    /**
     * 批量删除信义大模型问答记录
     * 
     * @param ids 需要删除的信义大模型问答记录主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiChatRecordByIds(Long[] ids)
    {
        return tXinyiChatRecordMapper.deleteTXinyiChatRecordByIds(ids);
    }

    /**
     * 删除信义大模型问答记录信息
     * 
     * @param id 信义大模型问答记录主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiChatRecordById(Long id)
    {
        return tXinyiChatRecordMapper.deleteTXinyiChatRecordById(id);
    }
}
