package com.slibra.business.service.impl;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Objects;

import com.alibaba.fastjson2.JSON;
import com.slibra.business.domain.TXinyiBigTableDay;
import com.slibra.business.domain.TXinyiBigTableHour;
import com.slibra.business.mapper.TXinyiBigTableDayMapper;
import com.slibra.common.core.domain.TXinyiDaily;
import com.slibra.business.mapper.TXinyiBigTableHourMapper;
import com.slibra.business.mapper.TXinyiDailyMapper;
import com.slibra.business.res.XinyiDailySimple;
import com.slibra.business.service.ITXinyiDailyService;
import com.slibra.common.exception.ServiceException;
import com.slibra.common.utils.DateUtils;
import com.slibra.common.utils.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import static com.slibra.common.constant.MyConstants.DAILY_RECORDS_TOTAL;
import static com.slibra.common.utils.DateUtils.getAllDatesBetween;

/**
 * 信义日报数据Service业务层处理
 * 
 * @author slibra
 * @date 2024-04-13
 */
@Service
public class TXinyiDailyServiceImpl implements ITXinyiDailyService
{
    private static final Logger log = LoggerFactory.getLogger(TXinyiDailyServiceImpl.class);
    @Autowired
    private TXinyiDailyMapper tXinyiDailyMapper;

    @Autowired
    private TXinyiBigTableHourMapper xinyiBigTableHourMapper;

    @Autowired
    private TXinyiBigTableDayMapper xinyiBigTableDayMapper;

    /**
     * 查询信义日报数据
     * 
     * @param ID 信义日报数据主键
     * @return 信义日报数据
     */
    @Override
    public TXinyiDaily selectTXinyiDailyByID(Long ID)
    {
        return tXinyiDailyMapper.selectTXinyiDailyByID(ID);
    }

    /**
     * 查询信义日报数据列表
     * 
     * @param tXinyiDaily 信义日报数据
     * @return 信义日报数据
     */
    @Override
    public List<TXinyiDaily> selectTXinyiDailyList(TXinyiDaily tXinyiDaily)
    {
        return tXinyiDailyMapper.selectTXinyiDailyList(tXinyiDaily);
    }

    /**
     * 新增信义日报数据
     * 
     * @param tXinyiDaily 信义日报数据
     * @return 结果
     */
    @Override
    public int insertTXinyiDaily(TXinyiDaily tXinyiDaily)
    {
        //2024年6月5日15:28:13 一些额外的字段处理
        //2024年6月9日11:11:49 编辑和新增接口改成一个
        Long id = tXinyiDaily.getID();
        this.addExtra(tXinyiDaily, id);
        //2024年7月6日11:13:35 大宽表的数据处理
        this.updateBigTableHourByDaily(tXinyiDaily);
        if(Objects.isNull(id))//新增
            return tXinyiDailyMapper.insertTXinyiDaily(tXinyiDaily);
        return tXinyiDailyMapper.updateTXinyiDaily(tXinyiDaily);
    }

    private void updateBigTableHourByDaily(TXinyiDaily tXinyiDaily) {
        List<TXinyiBigTableHour> tXinyiBigTableHours = this.xinyiBigTableHourMapper.selectTXinyiBigTableHourList(TXinyiBigTableHour.builder().testDate(tXinyiDaily.getTestDate()).build());
        if(!CollectionUtils.isEmpty(tXinyiBigTableHours)){
            for (TXinyiBigTableHour tXinyiBigTableHour : tXinyiBigTableHours) {
                addDailyData(tXinyiDaily, tXinyiBigTableHour);
                //更新数据库
                this.xinyiBigTableHourMapper.updateTXinyiBigTableHour(tXinyiBigTableHour);
            }
        }
        //2024年08月13日14:23:37 兜底处理：如果定时任务生成昨日的大表-天数据的时候，还没有填写周报，则会一直没有周报数据了，这时候需要再这里查询是否存在，如果有，就更新它（化验室的数据操作起来就太复杂，暂时没有这种问题 todo）
        List<TXinyiBigTableDay> tXinyiBigTableDays = this.xinyiBigTableDayMapper.selectTXinyiBigTableDayList(TXinyiBigTableDay.builder().testDate(tXinyiDaily.getTestDate()).build());
        if(!CollectionUtils.isEmpty(tXinyiBigTableDays)){
            log.info("~~~~进入了兜底处理因为定时任务生成大表天维度时，还没有填写日报的问题@@@###");
            TXinyiBigTableDay tXinyiBigTableDay = tXinyiBigTableDays.get(0);
            addDailyData2Day(tXinyiDaily, tXinyiBigTableDay);
            this.xinyiBigTableDayMapper.updateTXinyiBigTableDay(tXinyiBigTableDay);
        }
    }

    @Override
    public void addDailyData(TXinyiDaily tXinyiDaily, TXinyiBigTableHour tXinyiBigTableHour) {
        //更新数据
        tXinyiBigTableHour.setRbJsCod(tXinyiDaily.getJsCod());
        tXinyiBigTableHour.setRbJsPh(tXinyiDaily.getJsPh());
        tXinyiBigTableHour.setRbJsBod5(tXinyiDaily.getJsBod5());
        tXinyiBigTableHour.setRbJsSs(tXinyiDaily.getJsSs());
        tXinyiBigTableHour.setRbJsNh3(tXinyiDaily.getJsNh3());
        tXinyiBigTableHour.setRbJsTn(tXinyiDaily.getJsTn());
        tXinyiBigTableHour.setRbJsTp(tXinyiDaily.getJsTp());
        tXinyiBigTableHour.setRbJsDcgj(tXinyiDaily.getJsDcgj());
        tXinyiBigTableHour.setRbCsCod(tXinyiDaily.getCsCod());
        tXinyiBigTableHour.setRbCsPh(tXinyiDaily.getCsPh());
        tXinyiBigTableHour.setRbCsBod5(tXinyiDaily.getCsBod5());
        tXinyiBigTableHour.setRbCsSs(tXinyiDaily.getCsSs());
        tXinyiBigTableHour.setRbCsNh3(tXinyiDaily.getCsNh3());
        tXinyiBigTableHour.setRbCsTn(tXinyiDaily.getCsTn());
        tXinyiBigTableHour.setRbCsTp(tXinyiDaily.getCsTp());
        tXinyiBigTableHour.setRbCsDcgj(tXinyiDaily.getCsDcgj());
        tXinyiBigTableHour.setRbJsSw(tXinyiDaily.getJsSw());
        tXinyiBigTableHour.setRbCsSw(tXinyiDaily.getCsSw());
        tXinyiBigTableHour.setRbShcOnePh(tXinyiDaily.getShcOnePh());
        tXinyiBigTableHour.setRbShcTwoPh(tXinyiDaily.getShcTwoPh());
        tXinyiBigTableHour.setRbShcHyOneSv(tXinyiDaily.getShcHyOneSv());
        tXinyiBigTableHour.setRbShcHyTwoSv(tXinyiDaily.getShcHyTwoSv());
        tXinyiBigTableHour.setRbShcHyOneSvi(tXinyiDaily.getShcHyOneSvi());
        tXinyiBigTableHour.setRbShcHyTwoSvi(tXinyiDaily.getShcHyTwoSvi());
        tXinyiBigTableHour.setRbShcHyOneMlss(tXinyiDaily.getShcHyOneMlss());
        tXinyiBigTableHour.setRbShcHyTwoMlss(tXinyiDaily.getShcHyTwoMlss());
        tXinyiBigTableHour.setRbShcHyOneMlvss(tXinyiDaily.getShcHyOneMlvss());
        tXinyiBigTableHour.setRbShcHyTwoMlvss(tXinyiDaily.getShcHyTwoMlvss());
        tXinyiBigTableHour.setRbShcYyOneDo(tXinyiDaily.getShcYyOneDo());
        tXinyiBigTableHour.setRbShcYyTwoDo(tXinyiDaily.getShcYyTwoDo());
        tXinyiBigTableHour.setRbShcQyOneDo(tXinyiDaily.getShcQyOneDo());
        tXinyiBigTableHour.setRbShcQyTwoDo(tXinyiDaily.getShcQyTwoDo());
        tXinyiBigTableHour.setRbShcHyOneDo(tXinyiDaily.getShcHyOneDo());
        tXinyiBigTableHour.setRbShcHyTwoDo(tXinyiDaily.getShcHyTwoDo());
        tXinyiBigTableHour.setRbJsl(tXinyiDaily.getJSL());
        tXinyiBigTableHour.setRbCsl(tXinyiDaily.getCSL());
        tXinyiBigTableHour.setRbSdclcxsl(tXinyiDaily.getSDCLCXSL());
        tXinyiBigTableHour.setRbQsb(tXinyiDaily.getQSB());
        tXinyiBigTableHour.setRbFM(tXinyiDaily.getFM());
        tXinyiBigTableHour.setRbYyHrt(tXinyiDaily.getYyHrt());
        tXinyiBigTableHour.setRbHyHrt(tXinyiDaily.getHyHrt());
        tXinyiBigTableHour.setRbQyHrt(tXinyiDaily.getQyHrt());
        tXinyiBigTableHour.setRbNhlR(tXinyiDaily.getNhlR());
        tXinyiBigTableHour.setRbWhlR(tXinyiDaily.getWhlR());
        tXinyiBigTableHour.setRbSrt(tXinyiDaily.getSRT());
        tXinyiBigTableHour.setRbCnl(tXinyiDaily.getCNL());
        tXinyiBigTableHour.setRbTyqBod5Tn(tXinyiDaily.getTyqBod5Tn());
        tXinyiBigTableHour.setRbTyhBod5Tn(tXinyiDaily.getTyhBod5Tn());
        tXinyiBigTableHour.setRbHycRjyAll(tXinyiDaily.getHycRjyAll());
        tXinyiBigTableHour.setRbHycWnndAll(tXinyiDaily.getHycWnndAll());
        tXinyiBigTableHour.setRbYycRjyAll(tXinyiDaily.getYycRjyAll());
        tXinyiBigTableHour.setRbQycRjyAll(tXinyiDaily.getQycRjyAll());
        tXinyiBigTableHour.setRbWncjbAll(tXinyiDaily.getWncjbAll());
        tXinyiBigTableHour.setRbWntjzsAll(tXinyiDaily.getWntjzsAll());
        tXinyiBigTableHour.setRbHfxwnndAll(tXinyiDaily.getHfxwnndAll());
        tXinyiBigTableHour.setRbChuniliang(tXinyiDaily.getCHUNILIANG());
        tXinyiBigTableHour.setRbCnhsl(tXinyiDaily.getCNHSL());
        tXinyiBigTableHour.setRbGwnl(tXinyiDaily.getGWNL());
        tXinyiBigTableHour.setRbDf(tXinyiDaily.getDF());
        tXinyiBigTableHour.setRbXnjf(tXinyiDaily.getXNJF());
        tXinyiBigTableHour.setRbClf(tXinyiDaily.getCLF());
        tXinyiBigTableHour.setRbTyf(tXinyiDaily.getTYF());
        tXinyiBigTableHour.setRbXdjf(tXinyiDaily.getXDJF());
        tXinyiBigTableHour.setRbQtyjf(tXinyiDaily.getQTYJF());
        tXinyiBigTableHour.setRbCnf(tXinyiDaily.getCNF());
        tXinyiBigTableHour.setRbZlsf(tXinyiDaily.getZLSF());
        tXinyiBigTableHour.setRbZjcb(tXinyiDaily.getZJCB());
        tXinyiBigTableHour.setRbDwcb(tXinyiDaily.getDWCB());
    }


    public void addDailyData2Day(TXinyiDaily tXinyiDaily, TXinyiBigTableDay tXinyiBigTableDay) {
        //更新数据
        tXinyiBigTableDay.setRbJsCod(tXinyiDaily.getJsCod());
        tXinyiBigTableDay.setRbJsPh(tXinyiDaily.getJsPh());
        tXinyiBigTableDay.setRbJsBod5(tXinyiDaily.getJsBod5());
        tXinyiBigTableDay.setRbJsSs(tXinyiDaily.getJsSs());
        tXinyiBigTableDay.setRbJsNh3(tXinyiDaily.getJsNh3());
        tXinyiBigTableDay.setRbJsTn(tXinyiDaily.getJsTn());
        tXinyiBigTableDay.setRbJsTp(tXinyiDaily.getJsTp());
        tXinyiBigTableDay.setRbJsDcgj(tXinyiDaily.getJsDcgj());
        tXinyiBigTableDay.setRbCsCod(tXinyiDaily.getCsCod());
        tXinyiBigTableDay.setRbCsPh(tXinyiDaily.getCsPh());
        tXinyiBigTableDay.setRbCsBod5(tXinyiDaily.getCsBod5());
        tXinyiBigTableDay.setRbCsSs(tXinyiDaily.getCsSs());
        tXinyiBigTableDay.setRbCsNh3(tXinyiDaily.getCsNh3());
        tXinyiBigTableDay.setRbCsTn(tXinyiDaily.getCsTn());
        tXinyiBigTableDay.setRbCsTp(tXinyiDaily.getCsTp());
        tXinyiBigTableDay.setRbCsDcgj(tXinyiDaily.getCsDcgj());
        tXinyiBigTableDay.setRbJsSw(tXinyiDaily.getJsSw());
        tXinyiBigTableDay.setRbCsSw(tXinyiDaily.getCsSw());
        tXinyiBigTableDay.setRbShcOnePh(tXinyiDaily.getShcOnePh());
        tXinyiBigTableDay.setRbShcTwoPh(tXinyiDaily.getShcTwoPh());
        tXinyiBigTableDay.setRbShcHyOneSv(tXinyiDaily.getShcHyOneSv());
        tXinyiBigTableDay.setRbShcHyTwoSv(tXinyiDaily.getShcHyTwoSv());
        tXinyiBigTableDay.setRbShcHyOneSvi(tXinyiDaily.getShcHyOneSvi());
        tXinyiBigTableDay.setRbShcHyTwoSvi(tXinyiDaily.getShcHyTwoSvi());
        tXinyiBigTableDay.setRbShcHyOneMlss(tXinyiDaily.getShcHyOneMlss());
        tXinyiBigTableDay.setRbShcHyTwoMlss(tXinyiDaily.getShcHyTwoMlss());
        tXinyiBigTableDay.setRbShcHyOneMlvss(tXinyiDaily.getShcHyOneMlvss());
        tXinyiBigTableDay.setRbShcHyTwoMlvss(tXinyiDaily.getShcHyTwoMlvss());
        tXinyiBigTableDay.setRbShcYyOneDo(tXinyiDaily.getShcYyOneDo());
        tXinyiBigTableDay.setRbShcYyTwoDo(tXinyiDaily.getShcYyTwoDo());
        tXinyiBigTableDay.setRbShcQyOneDo(tXinyiDaily.getShcQyOneDo());
        tXinyiBigTableDay.setRbShcQyTwoDo(tXinyiDaily.getShcQyTwoDo());
        tXinyiBigTableDay.setRbShcHyOneDo(tXinyiDaily.getShcHyOneDo());
        tXinyiBigTableDay.setRbShcHyTwoDo(tXinyiDaily.getShcHyTwoDo());
        tXinyiBigTableDay.setRbJsl(tXinyiDaily.getJSL());
        tXinyiBigTableDay.setRbCsl(tXinyiDaily.getCSL());
        tXinyiBigTableDay.setRbSdclcxsl(tXinyiDaily.getSDCLCXSL());
        tXinyiBigTableDay.setRbQsb(tXinyiDaily.getQSB());
        tXinyiBigTableDay.setRbFM(tXinyiDaily.getFM());
        tXinyiBigTableDay.setRbYyHrt(tXinyiDaily.getYyHrt());
        tXinyiBigTableDay.setRbHyHrt(tXinyiDaily.getHyHrt());
        tXinyiBigTableDay.setRbQyHrt(tXinyiDaily.getQyHrt());
        tXinyiBigTableDay.setRbNhlR(tXinyiDaily.getNhlR());
        tXinyiBigTableDay.setRbWhlR(tXinyiDaily.getWhlR());
        tXinyiBigTableDay.setRbSrt(tXinyiDaily.getSRT());
        tXinyiBigTableDay.setRbCnl(tXinyiDaily.getCNL());
        tXinyiBigTableDay.setRbTyqBod5Tn(tXinyiDaily.getTyqBod5Tn());
        tXinyiBigTableDay.setRbTyhBod5Tn(tXinyiDaily.getTyhBod5Tn());
        tXinyiBigTableDay.setRbHycRjyAll(tXinyiDaily.getHycRjyAll());
        tXinyiBigTableDay.setRbHycWnndAll(tXinyiDaily.getHycWnndAll());
        tXinyiBigTableDay.setRbYycRjyAll(tXinyiDaily.getYycRjyAll());
        tXinyiBigTableDay.setRbQycRjyAll(tXinyiDaily.getQycRjyAll());
        tXinyiBigTableDay.setRbWncjbAll(tXinyiDaily.getWncjbAll());
        tXinyiBigTableDay.setRbWntjzsAll(tXinyiDaily.getWntjzsAll());
        tXinyiBigTableDay.setRbHfxwnndAll(tXinyiDaily.getHfxwnndAll());
        tXinyiBigTableDay.setRbChuniliang(tXinyiDaily.getCHUNILIANG());
        tXinyiBigTableDay.setRbCnhsl(tXinyiDaily.getCNHSL());
        tXinyiBigTableDay.setRbGwnl(tXinyiDaily.getGWNL());
        tXinyiBigTableDay.setRbDf(tXinyiDaily.getDF());
        tXinyiBigTableDay.setRbXnjf(tXinyiDaily.getXNJF());
        tXinyiBigTableDay.setRbClf(tXinyiDaily.getCLF());
        tXinyiBigTableDay.setRbTyf(tXinyiDaily.getTYF());
        tXinyiBigTableDay.setRbXdjf(tXinyiDaily.getXDJF());
        tXinyiBigTableDay.setRbQtyjf(tXinyiDaily.getQTYJF());
        tXinyiBigTableDay.setRbCnf(tXinyiDaily.getCNF());
        tXinyiBigTableDay.setRbZlsf(tXinyiDaily.getZLSF());
        tXinyiBigTableDay.setRbZjcb(tXinyiDaily.getZJCB());
        tXinyiBigTableDay.setRbDwcb(tXinyiDaily.getDWCB());
    }

    private void addExtra(TXinyiDaily tXinyiDaily, Long id) {

        String testDate = tXinyiDaily.getTestDate();
        if(StringUtils.isBlank(testDate))
            throw new ServiceException("日报填写必须要填写日期！");
//        String username = SecurityUtils.getUsername();
        Date nowDate = DateUtils.getNowDate();
        if(Objects.isNull(id)){//新增
            //检查日期是否已经填写过了
            TXinyiDaily detailByDay = this.tXinyiDailyMapper.getDetailByDay(testDate);
            if(!Objects.isNull(detailByDay))
                throw new ServiceException("该日期对应的日报已经填写过了，不可重复填写！");
            tXinyiDaily.setTestTime(testDate);
//            tXinyiDaily.setCreateBy(username);
            tXinyiDaily.setCreateTime(nowDate);
            tXinyiDaily.setCreatedTime(nowDate);
        }else{//编辑
//            tXinyiDaily.setUpdateBy(username);
            tXinyiDaily.setUpdateTime(nowDate);
        }

        List<BigDecimal> extraList = new ArrayList<>();
        extraList.add(tXinyiDaily.getShcHyOneDo());
        extraList.add(tXinyiDaily.getShcHyTwoDo());
        tXinyiDaily.setHycRjyAll(JSON.toJSONString(extraList));
        extraList.clear();
        extraList.add(tXinyiDaily.getShcHyOneMlss());
        extraList.add(tXinyiDaily.getShcHyTwoMlss());
        tXinyiDaily.setHycWnndAll(JSON.toJSONString(extraList));
        extraList.clear();
        extraList.add(tXinyiDaily.getShcYyOneDo());
        extraList.add(tXinyiDaily.getShcYyTwoDo());
        tXinyiDaily.setYycRjyAll(JSON.toJSONString(extraList));
        extraList.clear();
        extraList.add(tXinyiDaily.getShcQyOneDo());
        extraList.add(tXinyiDaily.getShcQyTwoDo());
        tXinyiDaily.setQycRjyAll(JSON.toJSONString(extraList));
        extraList.clear();
        extraList.add(tXinyiDaily.getShcHyOneSv());
        extraList.add(tXinyiDaily.getShcHyTwoSv());
        tXinyiDaily.setWncjbAll(JSON.toJSONString(extraList));
        extraList.clear();
        extraList.add(tXinyiDaily.getShcHyOneSvi());
        extraList.add(tXinyiDaily.getShcHyTwoSvi());
        tXinyiDaily.setWntjzsAll(JSON.toJSONString(extraList));
        extraList.clear();
        extraList.add(tXinyiDaily.getShcHyOneMlvss());
        extraList.add(tXinyiDaily.getShcHyTwoMlvss());
        tXinyiDaily.setHfxwnndAll(JSON.toJSONString(extraList));
    }

    /**
     * 修改信义日报数据
     * 
     * @param tXinyiDaily 信义日报数据
     * @return 结果
     */
    @Override
    public int updateTXinyiDaily(TXinyiDaily tXinyiDaily)
    {
        return tXinyiDailyMapper.updateTXinyiDaily(tXinyiDaily);
    }

    /**
     * 批量删除信义日报数据
     * 
     * @param IDs 需要删除的信义日报数据主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiDailyByIDs(Long[] IDs)
    {
        return tXinyiDailyMapper.deleteTXinyiDailyByIDs(IDs);
    }

    /**
     * 删除信义日报数据信息
     * 
     * @param ID 信义日报数据主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiDailyByID(Long ID)
    {
        return tXinyiDailyMapper.deleteTXinyiDailyByID(ID);
    }

    @Override
    public List<XinyiDailySimple> getRecently30CountInfo() {
        //获取最近30天的日期
        //今天的日期
        LocalDate end = LocalDate.now();
        //获取N天之前的日期
        LocalDate begin = end.plusDays(-DAILY_RECORDS_TOTAL);
        //两个日期之间所有的时间-天
        List<String> allDatesBetween = getAllDatesBetween(begin, end);
        List<XinyiDailySimple> result = new ArrayList<>(allDatesBetween.size());
        for (String testDate : allDatesBetween) {
            XinyiDailySimple xinyiDailySimple = new XinyiDailySimple();
            xinyiDailySimple.setTestDate(testDate);
            TXinyiDaily detailByDay = this.tXinyiDailyMapper.getDetailByDay(testDate);
            if(!Objects.isNull(detailByDay)){
                xinyiDailySimple.setExists(true);
                xinyiDailySimple.setID(detailByDay.getID());
            }
            result.add(xinyiDailySimple);
        }
        return result;
    }



}
