package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TXinyiFeedbackMapper;
import com.slibra.business.domain.TXinyiFeedback;
import com.slibra.business.service.ITXinyiFeedbackService;

/**
 * 信义意见反馈Service业务层处理
 * 
 * @author slibra
 * @date 2024-05-27
 */
@Service
public class TXinyiFeedbackServiceImpl implements ITXinyiFeedbackService 
{
    @Autowired
    private TXinyiFeedbackMapper tXinyiFeedbackMapper;

    /**
     * 查询信义意见反馈
     * 
     * @param id 信义意见反馈主键
     * @return 信义意见反馈
     */
    @Override
    public TXinyiFeedback selectTXinyiFeedbackById(Long id)
    {
        return tXinyiFeedbackMapper.selectTXinyiFeedbackById(id);
    }

    /**
     * 查询信义意见反馈列表
     * 
     * @param tXinyiFeedback 信义意见反馈
     * @return 信义意见反馈
     */
    @Override
    public List<TXinyiFeedback> selectTXinyiFeedbackList(TXinyiFeedback tXinyiFeedback)
    {
        return tXinyiFeedbackMapper.selectTXinyiFeedbackList(tXinyiFeedback);
    }

    /**
     * 新增信义意见反馈
     * 
     * @param tXinyiFeedback 信义意见反馈
     * @return 结果
     */
    @Override
    public int insertTXinyiFeedback(TXinyiFeedback tXinyiFeedback)
    {
        tXinyiFeedback.setCreateTime(DateUtils.getNowDate());
        return tXinyiFeedbackMapper.insertTXinyiFeedback(tXinyiFeedback);
    }

    /**
     * 修改信义意见反馈
     * 
     * @param tXinyiFeedback 信义意见反馈
     * @return 结果
     */
    @Override
    public int updateTXinyiFeedback(TXinyiFeedback tXinyiFeedback)
    {
        tXinyiFeedback.setUpdateTime(DateUtils.getNowDate());
        return tXinyiFeedbackMapper.updateTXinyiFeedback(tXinyiFeedback);
    }

    /**
     * 批量删除信义意见反馈
     * 
     * @param ids 需要删除的信义意见反馈主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiFeedbackByIds(Long[] ids)
    {
        return tXinyiFeedbackMapper.deleteTXinyiFeedbackByIds(ids);
    }

    /**
     * 删除信义意见反馈信息
     * 
     * @param id 信义意见反馈主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiFeedbackById(Long id)
    {
        return tXinyiFeedbackMapper.deleteTXinyiFeedbackById(id);
    }
}
