package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TXinyiMedicineAddRecordMapper;
import com.slibra.business.domain.TXinyiMedicineAddRecord;
import com.slibra.business.service.ITXinyiMedicineAddRecordService;

/**
 * 信义碳源投加记录Service业务层处理
 * 
 * @author slibra
 * @date 2025-04-24
 */
@Service
public class TXinyiMedicineAddRecordServiceImpl implements ITXinyiMedicineAddRecordService 
{
    @Autowired
    private TXinyiMedicineAddRecordMapper tXinyiMedicineAddRecordMapper;

    /**
     * 查询信义碳源投加记录
     * 
     * @param id 信义碳源投加记录主键
     * @return 信义碳源投加记录
     */
    @Override
    public TXinyiMedicineAddRecord selectTXinyiMedicineAddRecordById(Long id)
    {
        return tXinyiMedicineAddRecordMapper.selectTXinyiMedicineAddRecordById(id);
    }

    /**
     * 查询信义碳源投加记录列表
     * 
     * @param tXinyiMedicineAddRecord 信义碳源投加记录
     * @return 信义碳源投加记录
     */
    @Override
    public List<TXinyiMedicineAddRecord> selectTXinyiMedicineAddRecordList(TXinyiMedicineAddRecord tXinyiMedicineAddRecord)
    {
        return tXinyiMedicineAddRecordMapper.selectTXinyiMedicineAddRecordList(tXinyiMedicineAddRecord);
    }

    /**
     * 新增信义碳源投加记录
     * 
     * @param tXinyiMedicineAddRecord 信义碳源投加记录
     * @return 结果
     */
    @Override
    public int insertTXinyiMedicineAddRecord(TXinyiMedicineAddRecord tXinyiMedicineAddRecord)
    {
        tXinyiMedicineAddRecord.setCreateTime(DateUtils.getNowDate());
        return tXinyiMedicineAddRecordMapper.insertTXinyiMedicineAddRecord(tXinyiMedicineAddRecord);
    }

    /**
     * 修改信义碳源投加记录
     * 
     * @param tXinyiMedicineAddRecord 信义碳源投加记录
     * @return 结果
     */
    @Override
    public int updateTXinyiMedicineAddRecord(TXinyiMedicineAddRecord tXinyiMedicineAddRecord)
    {
        tXinyiMedicineAddRecord.setUpdateTime(DateUtils.getNowDate());
        return tXinyiMedicineAddRecordMapper.updateTXinyiMedicineAddRecord(tXinyiMedicineAddRecord);
    }

    /**
     * 批量删除信义碳源投加记录
     * 
     * @param ids 需要删除的信义碳源投加记录主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiMedicineAddRecordByIds(Long[] ids)
    {
        return tXinyiMedicineAddRecordMapper.deleteTXinyiMedicineAddRecordByIds(ids);
    }

    /**
     * 删除信义碳源投加记录信息
     * 
     * @param id 信义碳源投加记录主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiMedicineAddRecordById(Long id)
    {
        return tXinyiMedicineAddRecordMapper.deleteTXinyiMedicineAddRecordById(id);
    }
}
