package com.slibra.business.service.impl;

import java.util.Arrays;
import java.util.List;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.slibra.business.req.MedicineParamsDetail;
import com.slibra.common.utils.DateUtils;
import com.slibra.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TXinyiMedicineRemoteMapper;
import com.slibra.business.domain.TXinyiMedicineRemote;
import com.slibra.business.service.ITXinyiMedicineRemoteService;

/**
 * 调参逻辑设定Service业务层处理
 * 
 * @author slibra
 * @date 2025-04-23
 */
@Service
public class TXinyiMedicineRemoteServiceImpl implements ITXinyiMedicineRemoteService 
{
    @Autowired
    private TXinyiMedicineRemoteMapper tXinyiMedicineRemoteMapper;

    /**
     * 查询调参逻辑设定
     * 
     * @param id 调参逻辑设定主键
     * @return 调参逻辑设定
     */
    @Override
    public TXinyiMedicineRemote selectTXinyiMedicineRemoteById(Long id)
    {
        return tXinyiMedicineRemoteMapper.selectTXinyiMedicineRemoteById(id);
    }

    /**
     * 查询调参逻辑设定列表
     * 
     * @param tXinyiMedicineRemote 调参逻辑设定
     * @return 调参逻辑设定
     */
    @Override
    public List<TXinyiMedicineRemote> selectTXinyiMedicineRemoteList(TXinyiMedicineRemote tXinyiMedicineRemote)
    {
        return tXinyiMedicineRemoteMapper.selectTXinyiMedicineRemoteList(tXinyiMedicineRemote);
    }

    /**
     * 新增调参逻辑设定
     * 
     * @param tXinyiMedicineRemote 调参逻辑设定
     * @return 结果
     */
    @Override
    public int insertTXinyiMedicineRemote(TXinyiMedicineRemote tXinyiMedicineRemote)
    {
        tXinyiMedicineRemote.setCreateTime(DateUtils.getNowDate());
        return tXinyiMedicineRemoteMapper.insertTXinyiMedicineRemote(tXinyiMedicineRemote);
    }

    /**
     * 修改调参逻辑设定
     * 
     * @param medicineParamsDetail 调参逻辑设定
     * @return 结果
     */
    @Override
    public int updateTXinyiMedicineRemote(MedicineParamsDetail medicineParamsDetail)
    {
        TXinyiMedicineRemote tXinyiMedicineRemote = new TXinyiMedicineRemote();
        tXinyiMedicineRemote.setUpdateTime(DateUtils.getNowDate());
        tXinyiMedicineRemote.setCreateBy(SecurityUtils.getUsername());
        //只有一条值，只能编辑，不能新增
        tXinyiMedicineRemote.setId(1L);
        //前端数据转JSON
        tXinyiMedicineRemote.setOriginContent(JSON.toJSONString(medicineParamsDetail));
        //创哥的业务数据拼接
        tXinyiMedicineRemote.setHandleContent(this.parseContent(medicineParamsDetail));
        return tXinyiMedicineRemoteMapper.updateTXinyiMedicineRemote(tXinyiMedicineRemote);
    }

    /**
     * 拼接创哥需要的JSON数据
     * @param medicineParamsDetail
     * @return
     */
    private String parseContent(MedicineParamsDetail medicineParamsDetail) {
        JSONObject result = new JSONObject();
        //处理业务数据，拼接
        JSONObject setfeedback = new JSONObject();
        setfeedback.put("para", Arrays.asList(medicineParamsDetail.getA1(), medicineParamsDetail.getA2(), medicineParamsDetail.getA3(), medicineParamsDetail.getA4()));
        setfeedback.put("hour", medicineParamsDetail.getA5());
        setfeedback.put("max_hour", medicineParamsDetail.getA6());
        result.put("setfeedback", setfeedback);

        //返回最终的数据
        return JSON.toJSONString(result);
    }

    /**
     * 批量删除调参逻辑设定
     * 
     * @param ids 需要删除的调参逻辑设定主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiMedicineRemoteByIds(Long[] ids)
    {
        return tXinyiMedicineRemoteMapper.deleteTXinyiMedicineRemoteByIds(ids);
    }

    /**
     * 删除调参逻辑设定信息
     * 
     * @param id 调参逻辑设定主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiMedicineRemoteById(Long id)
    {
        return tXinyiMedicineRemoteMapper.deleteTXinyiMedicineRemoteById(id);
    }







    @Override
    public TXinyiMedicineRemote getLatestRecord() {
        return tXinyiMedicineRemoteMapper.getLatestRecord();
    }
}
