package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TXinyiWarningRecordMapper;
import com.slibra.business.domain.TXinyiWarningRecord;
import com.slibra.business.service.ITXinyiWarningRecordService;

/**
 * 信义告警记录Service业务层处理
 * 
 * @author slibra
 * @date 2024-05-17
 */
@Service
public class TXinyiWarningRecordServiceImpl implements ITXinyiWarningRecordService 
{
    @Autowired
    private TXinyiWarningRecordMapper tXinyiWarningRecordMapper;

    /**
     * 查询信义告警记录
     * 
     * @param id 信义告警记录主键
     * @return 信义告警记录
     */
    @Override
    public TXinyiWarningRecord selectTXinyiWarningRecordById(Long id)
    {
        return tXinyiWarningRecordMapper.selectTXinyiWarningRecordById(id);
    }

    /**
     * 查询信义告警记录列表
     * 
     * @param tXinyiWarningRecord 信义告警记录
     * @return 信义告警记录
     */
    @Override
    public List<TXinyiWarningRecord> selectTXinyiWarningRecordList(TXinyiWarningRecord tXinyiWarningRecord)
    {
        return tXinyiWarningRecordMapper.selectTXinyiWarningRecordList(tXinyiWarningRecord);
    }

    /**
     * 新增信义告警记录
     * 
     * @param tXinyiWarningRecord 信义告警记录
     * @return 结果
     */
    @Override
    public int insertTXinyiWarningRecord(TXinyiWarningRecord tXinyiWarningRecord)
    {
        tXinyiWarningRecord.setCreateTime(DateUtils.getNowDate());
        return tXinyiWarningRecordMapper.insertTXinyiWarningRecord(tXinyiWarningRecord);
    }

    /**
     * 修改信义告警记录
     * 
     * @param tXinyiWarningRecord 信义告警记录
     * @return 结果
     */
    @Override
    public int updateTXinyiWarningRecord(TXinyiWarningRecord tXinyiWarningRecord)
    {
        tXinyiWarningRecord.setUpdateTime(DateUtils.getNowDate());
        return tXinyiWarningRecordMapper.updateTXinyiWarningRecord(tXinyiWarningRecord);
    }

    /**
     * 批量删除信义告警记录
     * 
     * @param ids 需要删除的信义告警记录主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiWarningRecordByIds(Long[] ids)
    {
        return tXinyiWarningRecordMapper.deleteTXinyiWarningRecordByIds(ids);
    }

    /**
     * 删除信义告警记录信息
     * 
     * @param id 信义告警记录主键
     * @return 结果
     */
    @Override
    public int deleteTXinyiWarningRecordById(Long id)
    {
        return tXinyiWarningRecordMapper.deleteTXinyiWarningRecordById(id);
    }
}
